@@ -23,10 +23,10 @@
 #include <commctrl.h>
 #include <tchar.h>
 
-#include "xchat-plugin.h"
+#include "hexchat-plugin.h"
 #include "utility.h"
-#include "xtray.h"
-#include "xchat.h"
+#include "hextray.h"
+#include "hexchat.h"
 #include "callbacks.h"
 #include "resource.h"
 #include "sdTray.h"
@@ -45,7 +45,7 @@ BOOL CALLBACK EnumWindowsProc(HWND hWnd, LPARAM lParam)
 	TCHAR szTitle[10];
 	GetWindowText(hWnd, szTitle, 9);
 
-	if(_tcsstr(szTitle, _T("XChat [")))
+	if(_tcsstr(szTitle, _T("HexChat [")))
 	{
 		g_hXchatWnd = hWnd;
 		return false;
@@ -55,15 +55,15 @@ BOOL CALLBACK EnumWindowsProc(HWND hWnd, LPARAM lParam)
 }
 
 /***********************************************************************************************/
-/******* our xchat event call back, get the name and info for each event and save it ***********/
-/******* for our alerts later														***********/
+/******* our HexChat event call back, get the name and info for each event and save it *********/
+/******* for our alerts later ******************************************************************/
 /***********************************************************************************************/
 int event_cb(char *word[], void *userdata)
 {
 	int iEvent = (int)userdata;
 
 	if(iEvent > 10 && iEvent != 21)
-		return XCHAT_EAT_NONE;
+		return HEXCHAT_EAT_NONE;
 
 	/***************************************************************************************/
 	/***** if the window is minimized or if we're allowed to show alerts when its not	 **/
@@ -90,12 +90,12 @@ int event_cb(char *word[], void *userdata)
 		{
 		case CHAN_HILIGHT:
 			_snprintf(szInfo, 512, "%s:\r\n%s", word[1], word[2]);
-			_snprintf(szName, 64, "Highlight: %s", xchat_get_info (ph, "channel"));
+			_snprintf(szName, 64, "Highlight: %s", hexchat_get_info (ph, "channel"));
 			dwInfoFlags = NIIF_INFO;
 			break;
 		case CHAN_MESSAGE:
 			_snprintf(szInfo, 512, "%s:\r\n%s", word[1], word[2]);
-			_snprintf(szName, 64, "Channel Message: %s", xchat_get_info (ph, "channel"));
+			_snprintf(szName, 64, "Channel Message: %s", hexchat_get_info (ph, "channel"));
 			dwInfoFlags = NIIF_INFO;
 			break;
 		case CHAN_TOPIC_CHANGE:
@@ -152,9 +152,9 @@ int event_cb(char *word[], void *userdata)
 
 		/**************************************************************************************/
 		/***** Use windows instead of balloons, and if its a window should we keep it open ****/
-		/***** indefinately?															   ****/
+		/***** indefinitely?															   ****/
 		/**************************************************************************************/
-		szTemp = xchat_strip_color(szInfo);
+		szTemp = hexchat_strip_color(szInfo);
 
 		if(g_dwPrefs & (1<<PREF_UWIOB))
 		{
@@ -174,9 +174,9 @@ int event_cb(char *word[], void *userdata)
 	}
 
 	/***********************************/
-	/***** pass the events to xchat ****/
+	/***** pass the events to HexChat **/
 	/***********************************/
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 int command_cb(char *word[], char *word_eol[], void *userdata)
@@ -186,7 +186,7 @@ int command_cb(char *word[], char *word_eol[], void *userdata)
 	int iTime		= g_iTime*1000;
 
 	_snprintf(szInfo, 512, word_eol[2]);
-	szTemp = xchat_strip_color(szInfo);
+	szTemp = hexchat_strip_color(szInfo);
 
 	if(g_dwPrefs & (1<<PREF_KAOI))
 	{
@@ -207,7 +207,7 @@ int command_cb(char *word[], char *word_eol[], void *userdata)
 
 	free(szTemp);
 
-	return XCHAT_EAT_ALL;
+	return HEXCHAT_EAT_ALL;
 }
 
 LRESULT CALLBACK WindowProc(HWND hWnd, UINT msg, WPARAM wparam, LPARAM lparam)
@@ -223,7 +223,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd, UINT msg, WPARAM wparam, LPARAM lparam)
 				/*******************************************/
 				if(g_dwPrefs & (1<<PREF_AOM))
 				{
-					xchat_globally_away(g_szAway);
+					hexchat_globally_away(g_szAway);
 				}
 
 				/**************************************************/
@@ -256,7 +256,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd, UINT msg, WPARAM wparam, LPARAM lparam)
 	case WM_SIZE:
 		{
 			/******************************************/
-			/***** User wants to minimize xChat, ******/
+			/***** User wants to minimize HexChat, ****/
 			/***** are we allowed to go to tray? ******/
 			/******************************************/
 			if((g_dwPrefs & (1<<PREF_TOT)) && (wparam == SIZE_MINIMIZED))
@@ -266,7 +266,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd, UINT msg, WPARAM wparam, LPARAM lparam)
 				/*******************************************/
 				if(g_dwPrefs & (1<<PREF_AOM))
 				{
-					xchat_globally_away(g_szAway);
+					hexchat_globally_away(g_szAway);
 				}
 
 				/**************************************************/
@@ -299,7 +299,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd, UINT msg, WPARAM wparam, LPARAM lparam)
 
 						if(g_dwPrefs & (1<<PREF_AOM))
 						{
-							xchat_globally_back();
+							hexchat_globally_back();
 						}
 					}
 					else
@@ -344,7 +344,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd, UINT msg, WPARAM wparam, LPARAM lparam)
 			if(msg == RegisterWindowMessage(_T("TaskbarCreated")))
 			{
 				char szVersion[64];
-				_snprintf(szVersion, 64, "HexChat [%s]", xchat_get_info(ph, "version"));
+				_snprintf(szVersion, 64, "HexChat [%s]", hexchat_get_info(ph, "version"));
 				AddIcon(g_hXchatWnd, 1, g_hIcons[0], szVersion, (NIF_ICON | NIF_MESSAGE | NIF_TIP), WM_TRAYMSG);
 			}
 		}
@@ -369,16 +369,16 @@ LRESULT CALLBACK sdTrayProc(HWND hWnd, int msg)
 		break;
 	case ACT_RESTORE:
 		{
-			/***********************************************/
-			/** user wants us to restore the xchat window **/
-			/** and of autoaway is on, set as back		**/
-			/***********************************************/
+			/*************************************************/
+			/** user wants us to restore the HexChat window **/
+			/** and of autoaway is on, set as back ******** **/
+			/*************************************************/
 			SendMessage(g_hXchatWnd, WM_SYSCOMMAND, SC_RESTORE, 0);
 			SetForegroundWindow(hWnd);
 			
 			if((!g_iIsActive) && (g_dwPrefs & (1<<PREF_AOM)))
 			{
-				xchat_globally_back();
+				hexchat_globally_back();
 				g_iIsActive = 1;
 			}
 		}
@@ -390,27 +390,27 @@ LRESULT CALLBACK sdTrayProc(HWND hWnd, int msg)
 		break;
 	case ACT_AWAY:
 		{
-			xchat_globally_away(g_szAway);
+			hexchat_globally_away(g_szAway);
 		}
 		break;
 	case ACT_BACK:
 		{
-			xchat_globally_back();
+			hexchat_globally_back();
 		}
 		break;
 	default:
 		{
 			if(msg > 0)
 			{
-				xchat_set_context(ph, xchat_find_server(msg-1));
+				hexchat_set_context(ph, hexchat_find_server(msg-1));
 
-				if(!xchat_get_info(ph, "away"))
+				if(!hexchat_get_info(ph, "away"))
 				{
-					xchat_away(g_szAway);
+					hexchat_away(g_szAway);
 				}
 				else
 				{
-					xchat_back();
+					hexchat_back();
 				}
 			}
 		}
