@@ -32,10 +32,14 @@
 #endif
 
 #undef PACKAGE
-#include "../../config.h"		  /* for #define OLD_PERL */
-#include "xchat-plugin.h"
+#ifdef WIN32
+#include "../../config-win32.h"		  /* for #define OLD_PERL */
+#else
+#include "../../config.h"
+#endif
+#include "hexchat-plugin.h"
 
-static xchat_plugin *ph;		  /* plugin handle */
+static hexchat_plugin *ph;		  /* plugin handle */
 
 static int perl_load_file (char *script_name);
 
@@ -140,9 +144,7 @@ perl_auto_load (void *unused)
 #endif
 
 	/* get the dir in local filesystem encoding (what opendir() expects!) */
-	xdir = xchat_get_info (ph, "xchatdirfs");
-	if (!xdir)			/* xchatdirfs is new for 2.0.9, will fail on older */
-		xdir = xchat_get_info (ph, "xchatdir");
+	xdir = hexchat_get_info (ph, "configdir");
 
 	/* don't pollute the filesystem with script files, this only causes misuse of the folders
 	 * only use ~/.config/hexchat/addons/ and %APPDATA%\HexChat\addons */
@@ -183,8 +185,8 @@ typedef struct
 {
 	SV *callback;
 	SV *userdata;
-	xchat_hook *hook;   /* required for timers */
-	xchat_context *ctx; /* allow timers to remember their context */
+	hexchat_hook *hook;   /* required for timers */
+	hexchat_context *ctx; /* allow timers to remember their context */
 	SV *package;      /* need to track the package name when removing hooks
 	                       by returning REMOVE
 							   */
@@ -214,10 +216,10 @@ execute_perl (SV * function, char *args)
 	count = call_sv (function, G_EVAL | G_SCALAR);
 	SPAGAIN;
 	if (SvTRUE (ERRSV)) {
-		xchat_printf(ph, "Perl error: %s\n", SvPV_nolen (ERRSV));
+		hexchat_printf(ph, "Perl error: %s\n", SvPV_nolen (ERRSV));
 		if (!SvOK (POPs)) {}		/* remove undef from the top of the stack */
 	} else if (count != 1) {
-		xchat_printf (ph, "Perl error: expected 1 value from %s, "
+		hexchat_printf (ph, "Perl error: expected 1 value from %s, "
 						  "got: %d\n", SvPV_nolen (function), count);
 	} else {
 		ret_value = POPi;
@@ -259,7 +261,7 @@ get_filename (char *word[], char *word_eol[])
 }
 
 static SV *
-list_item_to_sv ( xchat_list *list, const char *const *fields )
+list_item_to_sv ( hexchat_list *list, const char *const *fields )
 {
 	HV *hash = newHV();
 	SV *field_value;
@@ -274,7 +276,7 @@ list_item_to_sv ( xchat_list *list, const char *const *fields )
 
 		switch (fields[field_index][0]) {
 		case 's':
-			field = xchat_list_str (ph, list, field_name);
+			field = hexchat_list_str (ph, list, field_name);
 			if (field != NULL) {
 				field_value = newSVpvn (field, strlen (field));
 			} else {
@@ -282,14 +284,14 @@ list_item_to_sv ( xchat_list *list, const char *const *fields )
 			}
 			break;
 		case 'p':
-			field_value = newSViv (PTR2IV (xchat_list_str (ph, list,
+			field_value = newSViv (PTR2IV (hexchat_list_str (ph, list,
 																	 field_name)));
 			break;
 		case 'i':
-			field_value = newSVuv (xchat_list_int (ph, list, field_name));
+			field_value = newSVuv (hexchat_list_int (ph, list, field_name));
 			break;
 		case 't':
-			field_value = newSVnv (xchat_list_time (ph, list, field_name));
+			field_value = newSVnv (hexchat_list_time (ph, list, field_name));
 			break;
 		default:
 			field_value = &PL_sv_undef;
@@ -350,13 +352,13 @@ fd_cb (int fd, int flags, void *userdata)
 	SPAGAIN;
 
 	if (SvTRUE (ERRSV)) {
-		xchat_printf (ph, "Error in fd callback %s", SvPV_nolen (ERRSV));
+		hexchat_printf (ph, "Error in fd callback %s", SvPV_nolen (ERRSV));
 		if (!SvOK (POPs)) {}		  /* remove undef from the top of the stack */
-		retVal = XCHAT_EAT_ALL;
+		retVal = HEXCHAT_EAT_ALL;
 	} else {
 		if (count != 1) {
-			xchat_print (ph, "Fd handler should only return 1 value.");
-			retVal = XCHAT_EAT_NONE;
+			hexchat_print (ph, "Fd handler should only return 1 value.");
+			retVal = HEXCHAT_EAT_NONE;
 		} else {
 			retVal = POPi;
 			if (retVal == 0) {
@@ -402,7 +404,7 @@ timer_cb (void *userdata)
 	PUTBACK;
 
 	if (data->ctx) {
-		xchat_set_context (ph, data->ctx);
+		hexchat_set_context (ph, data->ctx);
 	}
 
 	set_current_package (data->package);
@@ -411,13 +413,13 @@ timer_cb (void *userdata)
 	SPAGAIN;
 
 	if (SvTRUE (ERRSV)) {
-		xchat_printf (ph, "Error in timer callback %s", SvPV_nolen (ERRSV));
+		hexchat_printf (ph, "Error in timer callback %s", SvPV_nolen (ERRSV));
 		if (!SvOK (POPs)) {}		  /* remove undef from the top of the stack */
-		retVal = XCHAT_EAT_ALL;
+		retVal = HEXCHAT_EAT_ALL;
 	} else {
 		if (count != 1) {
-			xchat_print (ph, "Timer handler should only return 1 value.");
-			retVal = XCHAT_EAT_NONE;
+			hexchat_print (ph, "Timer handler should only return 1 value.");
+			retVal = HEXCHAT_EAT_NONE;
 		} else {
 			retVal = POPi;
 			if (retVal == 0) {
@@ -453,9 +455,9 @@ server_cb (char *word[], char *word_eol[], void *userdata)
 	SAVETMPS;
 
 	if (data->depth)
-		return XCHAT_EAT_NONE;
+		return HEXCHAT_EAT_NONE;
 
-	/*               xchat_printf (ph, */
+	/*               hexchat_printf (ph, */
 	/*                               "Recieved %d words in server callback", av_len (wd)); */
 	PUSHMARK (SP);
 	XPUSHs (newRV_noinc ((SV *) array2av (word)));
@@ -470,13 +472,13 @@ server_cb (char *word[], char *word_eol[], void *userdata)
 	data->depth--;
 	SPAGAIN;
 	if (SvTRUE (ERRSV)) {
-		xchat_printf (ph, "Error in server callback %s", SvPV_nolen (ERRSV));
+		hexchat_printf (ph, "Error in server callback %s", SvPV_nolen (ERRSV));
 		if (!SvOK (POPs)) {}		  /* remove undef from the top of the stack */
-		retVal = XCHAT_EAT_NONE;
+		retVal = HEXCHAT_EAT_NONE;
 	} else {
 		if (count != 1) {
-			xchat_print (ph, "Server handler should only return 1 value.");
-			retVal = XCHAT_EAT_NONE;
+			hexchat_print (ph, "Server handler should only return 1 value.");
+			retVal = HEXCHAT_EAT_NONE;
 		} else {
 			retVal = POPi;
 		}
@@ -502,9 +504,9 @@ command_cb (char *word[], char *word_eol[], void *userdata)
 	SAVETMPS;
 	
 	if (data->depth)
-		return XCHAT_EAT_NONE;
+		return HEXCHAT_EAT_NONE;
 
-	/*               xchat_printf (ph, "Recieved %d words in command callback", */
+	/*               hexchat_printf (ph, "Recieved %d words in command callback", */
 	/*                               av_len (wd)); */
 	PUSHMARK (SP);
 	XPUSHs (newRV_noinc ((SV *) array2av (word)));
@@ -519,13 +521,13 @@ command_cb (char *word[], char *word_eol[], void *userdata)
 	data->depth--;
 	SPAGAIN;
 	if (SvTRUE (ERRSV)) {
-		xchat_printf (ph, "Error in command callback %s", SvPV_nolen (ERRSV));
+		hexchat_printf (ph, "Error in command callback %s", SvPV_nolen (ERRSV));
 		if (!SvOK (POPs)) {}		  /* remove undef from the top of the stack */
-		retVal = XCHAT_EAT_XCHAT;
+		retVal = HEXCHAT_EAT_HEXCHAT;
 	} else {
 		if (count != 1) {
-			xchat_print (ph, "Command handler should only return 1 value.");
-			retVal = XCHAT_EAT_NONE;
+			hexchat_print (ph, "Command handler should only return 1 value.");
+			retVal = HEXCHAT_EAT_NONE;
 		} else {
 			retVal = POPi;
 		}
@@ -556,7 +558,7 @@ print_cb (char *word[], void *userdata)
 	SAVETMPS;
 
 	if (data->depth)
-		return XCHAT_EAT_NONE;
+		return HEXCHAT_EAT_NONE;
 
 	wd = newAV ();
 	sv_2mortal ((SV *) wd);
@@ -582,7 +584,7 @@ print_cb (char *word[], void *userdata)
 		}
 	}
 
-	/*xchat_printf (ph, "Recieved %d words in print callback", av_len (wd)+1); */
+	/*hexchat_printf (ph, "Recieved %d words in print callback", av_len (wd)+1); */
 	PUSHMARK (SP);
 	XPUSHs (newRV_noinc ((SV *) wd));
 	XPUSHs (data->userdata);
@@ -595,13 +597,13 @@ print_cb (char *word[], void *userdata)
 	data->depth--;
 	SPAGAIN;
 	if (SvTRUE (ERRSV)) {
-		xchat_printf (ph, "Error in print callback %s", SvPV_nolen (ERRSV));
+		hexchat_printf (ph, "Error in print callback %s", SvPV_nolen (ERRSV));
 		if (!SvOK (POPs)) {}		  /* remove undef from the top of the stack */
-		retVal = XCHAT_EAT_NONE;
+		retVal = HEXCHAT_EAT_NONE;
 	} else {
 		if (count != 1) {
-			xchat_print (ph, "Print handler should only return 1 value.");
-			retVal = XCHAT_EAT_NONE;
+			hexchat_print (ph, "Print handler should only return 1 value.");
+			retVal = HEXCHAT_EAT_NONE;
 		} else {
 			retVal = POPi;
 		}
@@ -628,7 +630,7 @@ XS (XS_Xchat_register)
 	void *gui_entry;
 	dXSARGS;
 	if (items != 4) {
-		xchat_printf (ph,
+		hexchat_printf (ph,
 						  "Usage: Xchat::Internal::register(scriptname, version, desc, filename)");
 	} else {
 		name = SvPV_nolen (ST (0));
@@ -636,7 +638,7 @@ XS (XS_Xchat_register)
 		desc = SvPV_nolen (ST (2));
 		filename = SvPV_nolen (ST (3));
 
-		gui_entry = xchat_plugingui_add (ph, filename, name,
+		gui_entry = hexchat_plugingui_add (ph, filename, name,
 													desc, version, NULL);
 
 		XSRETURN_IV (PTR2IV (gui_entry));
@@ -654,10 +656,10 @@ XS (XS_Xchat_print)
 
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::Internal::print(text)");
+		hexchat_print (ph, "Usage: Xchat::Internal::print(text)");
 	} else {
 		text = SvPV_nolen (ST (0));
-		xchat_print (ph, text);
+		hexchat_print (ph, text);
 	}
 	XSRETURN_EMPTY;
 }
@@ -671,7 +673,7 @@ XS (XS_Xchat_emit_print)
 
 	dXSARGS;
 	if (items < 1) {
-		xchat_print (ph, "Usage: Xchat::emit_print(event_name, ...)");
+		hexchat_print (ph, "Usage: Xchat::emit_print(event_name, ...)");
 	} else {
 		event_name = (char *) SvPV_nolen (ST (0));
 		RETVAL = 0;
@@ -685,25 +687,25 @@ XS (XS_Xchat_emit_print)
 
 		switch (count) {
 		case 1:
-			RETVAL = xchat_emit_print (ph, event_name, NULL);
+			RETVAL = hexchat_emit_print (ph, event_name, NULL);
 			break;
 		case 2:
-			RETVAL = xchat_emit_print (ph, event_name,
+			RETVAL = hexchat_emit_print (ph, event_name,
 												SvPV_nolen (ST (1)), NULL);
 			break;
 		case 3:
-			RETVAL = xchat_emit_print (ph, event_name,
+			RETVAL = hexchat_emit_print (ph, event_name,
 												SvPV_nolen (ST (1)),
 												SvPV_nolen (ST (2)), NULL);
 			break;
 		case 4:
-			RETVAL = xchat_emit_print (ph, event_name,
+			RETVAL = hexchat_emit_print (ph, event_name,
 												SvPV_nolen (ST (1)),
 												SvPV_nolen (ST (2)),
 												SvPV_nolen (ST (3)), NULL);
 			break;
 		case 5:
-			RETVAL = xchat_emit_print (ph, event_name,
+			RETVAL = hexchat_emit_print (ph, event_name,
 												SvPV_nolen (ST (1)),
 												SvPV_nolen (ST (2)),
 												SvPV_nolen (ST (3)),
@@ -730,7 +732,7 @@ XS (XS_Xchat_send_modes)
 
 	dXSARGS;
 	if (items < 3 || items > 4) {
-		xchat_print (ph,
+		hexchat_print (ph,
 			"Usage: Xchat::send_modes( targets, sign, mode, modes_per_line)"
 		);
 	} else {
@@ -764,7 +766,7 @@ XS (XS_Xchat_send_modes)
 			modes_per_line = (int) SvIV (ST (3)); 
 		}
 
-		xchat_send_modes (ph, targets, target_count, modes_per_line, sign, mode);
+		hexchat_send_modes (ph, targets, target_count, modes_per_line, sign, mode);
 		free (targets);
 	}
 }
@@ -774,12 +776,12 @@ XS (XS_Xchat_get_info)
 	SV *temp = NULL;
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::get_info(id)");
+		hexchat_print (ph, "Usage: Xchat::get_info(id)");
 	} else {
 		SV *id = ST (0);
 		const char *RETVAL;
 
-		RETVAL = xchat_get_info (ph, SvPV_nolen (id));
+		RETVAL = hexchat_get_info (ph, SvPV_nolen (id));
 		if (RETVAL == NULL) {
 			XSRETURN_UNDEF;
 		}
@@ -792,7 +794,8 @@ XS (XS_Xchat_get_info)
 			
 			if (
 				!strncmp ("libdirfs", SvPV_nolen (id), 8) ||
-				!strncmp ("xchatdirfs", SvPV_nolen (id), 10)
+				!strncmp ("xchatdirfs", SvPV_nolen (id), 10) ||
+				!strncmp ("configdir", SvPV_nolen (id), 9)
 			) {
 				XSRETURN_PV (RETVAL);
 			} else {
@@ -813,9 +816,9 @@ XS (XS_Xchat_context_info)
 	dXSARGS;
 
 	if (items > 0 ) {
-		xchat_print (ph, "Usage: Xchat::Internal::context_info()");
+		hexchat_print (ph, "Usage: Xchat::Internal::context_info()");
 	}
-	fields = xchat_list_fields (ph, "channels" );
+	fields = hexchat_list_fields (ph, "channels" );
 	XPUSHs (list_item_to_sv (NULL, fields));
 	XSRETURN (1);
 }
@@ -828,11 +831,11 @@ XS (XS_Xchat_get_prefs)
 	SV *temp = NULL;
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::get_prefs(name)");
+		hexchat_print (ph, "Usage: Xchat::get_prefs(name)");
 	} else {
 
 
-		switch (xchat_get_prefs (ph, SvPV_nolen (ST (0)), &str, &integer)) {
+		switch (hexchat_get_prefs (ph, SvPV_nolen (ST (0)), &str, &integer)) {
 		case 0:
 			XSRETURN_UNDEF;
 			break;
@@ -867,13 +870,13 @@ XS (XS_Xchat_hook_server)
 	SV *callback;
 	SV *userdata;
 	SV *package;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	HookData *data;
 
 	dXSARGS;
 
 	if (items != 5) {
-		xchat_print (ph,
+		hexchat_print (ph,
 						 "Usage: Xchat::Internal::hook_server(name, priority, callback, userdata, package)");
 	} else {
 		name = SvPV_nolen (ST (0));
@@ -892,7 +895,7 @@ XS (XS_Xchat_hook_server)
 		data->depth = 0;
 		data->package = newSVsv (package);
 
-		hook = xchat_hook_server (ph, name, pri, server_cb, data);
+		hook = hexchat_hook_server (ph, name, pri, server_cb, data);
 
 		XSRETURN_IV (PTR2IV (hook));
 	}
@@ -908,13 +911,13 @@ XS (XS_Xchat_hook_command)
 	char *help_text = NULL;
 	SV *userdata;
 	SV *package;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	HookData *data;
 
 	dXSARGS;
 
 	if (items != 6) {
-		xchat_print (ph,
+		hexchat_print (ph,
 						 "Usage: Xchat::Internal::hook_command(name, priority, callback, help_text, userdata, package)");
 	} else {
 		name = SvPV_nolen (ST (0));
@@ -940,7 +943,7 @@ XS (XS_Xchat_hook_command)
 		data->userdata = newSVsv (userdata);
 		data->depth = 0;
 		data->package = newSVsv (package);
-		hook = xchat_hook_command (ph, name, pri, command_cb, help_text, data);
+		hook = hexchat_hook_command (ph, name, pri, command_cb, help_text, data);
 
 		XSRETURN_IV (PTR2IV (hook));
 	}
@@ -957,11 +960,11 @@ XS (XS_Xchat_hook_print)
 	SV *callback;
 	SV *userdata;
 	SV *package;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	HookData *data;
 	dXSARGS;
 	if (items != 5) {
-		xchat_print (ph,
+		hexchat_print (ph,
 						 "Usage: Xchat::Internal::hook_print(name, priority, callback, userdata, package)");
 	} else {
 		name = SvPV_nolen (ST (0));
@@ -980,7 +983,7 @@ XS (XS_Xchat_hook_print)
 		data->userdata = newSVsv (userdata);
 		data->depth = 0;
 		data->package = newSVsv (package);
-		hook = xchat_hook_print (ph, name, pri, print_cb, data);
+		hook = hexchat_hook_print (ph, name, pri, print_cb, data);
 
 		XSRETURN_IV (PTR2IV (hook));
 	}
@@ -993,14 +996,14 @@ XS (XS_Xchat_hook_timer)
 	int timeout;
 	SV *callback;
 	SV *userdata;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	SV *package;
 	HookData *data;
 
 	dXSARGS;
 
 	if (items != 4) {
-		xchat_print (ph,
+		hexchat_print (ph,
 						 "Usage: Xchat::Internal::hook_timer(timeout, callback, userdata, package)");
 	} else {
 		timeout = (int) SvIV (ST (0));
@@ -1016,9 +1019,9 @@ XS (XS_Xchat_hook_timer)
 
 		data->callback = newSVsv (callback);
 		data->userdata = newSVsv (userdata);
-		data->ctx = xchat_get_context (ph);
+		data->ctx = hexchat_get_context (ph);
 		data->package = newSVsv (package);
-		hook = xchat_hook_timer (ph, timeout, timer_cb, data);
+		hook = hexchat_hook_timer (ph, timeout, timer_cb, data);
 		data->hook = hook;
 
 		XSRETURN_IV (PTR2IV (hook));
@@ -1034,13 +1037,13 @@ XS (XS_Xchat_hook_fd)
 	int flags;
 	SV *userdata;
 	SV *package;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	HookData *data;
 
 	dXSARGS;
 
 	if (items != 4) {
-		xchat_print (ph,
+		hexchat_print (ph,
 						 "Usage: Xchat::Internal::hook_fd(fd, callback, flags, userdata)");
 	} else {
 		fd = (int) SvIV (ST (0));
@@ -1051,13 +1054,13 @@ XS (XS_Xchat_hook_fd)
 		data = NULL;
 
 #ifdef WIN32
-		if ((flags & XCHAT_FD_NOTSOCKET) == 0) {
+		if ((flags & HEXCHAT_FD_NOTSOCKET) == 0) {
 			/* this _get_osfhandle if from win32iop.h in the perl distribution,
 			 *  not the one provided by Windows
 			 */ 
 			fd = _get_osfhandle(fd);
 			if (fd < 0) {
-				xchat_print(ph, "Invalid file descriptor");
+				hexchat_print(ph, "Invalid file descriptor");
 				XSRETURN_UNDEF;
 			}
 		}
@@ -1072,7 +1075,7 @@ XS (XS_Xchat_hook_fd)
 		data->userdata = newSVsv (userdata);
 		data->depth = 0;
 		data->package = newSVsv (package);
-		hook = xchat_hook_fd (ph, fd, flags, fd_cb, data);
+		hook = hexchat_hook_fd (ph, fd, flags, fd_cb, data);
 		data->hook = hook;
 
 		XSRETURN_IV (PTR2IV (hook));
@@ -1082,15 +1085,15 @@ XS (XS_Xchat_hook_fd)
 static
 XS (XS_Xchat_unhook)
 {
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	HookData *userdata;
 	int retCount = 0;
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::unhook(hook)");
+		hexchat_print (ph, "Usage: Xchat::unhook(hook)");
 	} else {
-		hook = INT2PTR (xchat_hook *, SvUV (ST (0)));
-		userdata = (HookData *) xchat_unhook (ph, hook);
+		hook = INT2PTR (hexchat_hook *, SvUV (ST (0)));
+		userdata = (HookData *) hexchat_unhook (ph, hook);
 
 		if (userdata != NULL) {
 			if (userdata->callback != NULL) {
@@ -1122,10 +1125,10 @@ XS (XS_Xchat_command)
 
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::Internal::command(command)");
+		hexchat_print (ph, "Usage: Xchat::Internal::command(command)");
 	} else {
 		cmd = SvPV_nolen (ST (0));
-		xchat_command (ph, cmd);
+		hexchat_command (ph, cmd);
 
 	}
 	XSRETURN_EMPTY;
@@ -1136,11 +1139,11 @@ XS (XS_Xchat_find_context)
 {
 	char *server = NULL;
 	char *chan = NULL;
-	xchat_context *RETVAL;
+	hexchat_context *RETVAL;
 
 	dXSARGS;
 	if (items > 2)
-		xchat_print (ph, "Usage: Xchat::find_context ([channel, [server]])");
+		hexchat_print (ph, "Usage: Xchat::find_context ([channel, [server]])");
 	{
 
 		switch (items) {
@@ -1152,9 +1155,9 @@ XS (XS_Xchat_find_context)
 			/* otherwise leave it as null */
 			if (SvTRUE (ST (0)) || SvNIOK (ST (0))) {
 				chan = SvPV_nolen (ST (0));
-				/*                               xchat_printf( ph, "XSUB - find_context( %s, NULL )", chan ); */
+				/*                               hexchat_printf( ph, "XSUB - find_context( %s, NULL )", chan ); */
 			}
-			/* else { xchat_print( ph, "XSUB - find_context( NULL, NULL )" ); } */
+			/* else { hexchat_print( ph, "XSUB - find_context( NULL, NULL )" ); } */
 			/* chan is already NULL */
 			break;
 		case 2:						  /* server and channel */
@@ -1162,26 +1165,26 @@ XS (XS_Xchat_find_context)
 			/* otherwise leave it as NULL */
 			if (SvTRUE (ST (0)) || SvNIOK (ST (0))) {
 				chan = SvPV_nolen (ST (0));
-				/*                               xchat_printf( ph, "XSUB - find_context( %s, NULL )", SvPV_nolen(ST(0) )); */
+				/*                               hexchat_printf( ph, "XSUB - find_context( %s, NULL )", SvPV_nolen(ST(0) )); */
 			}
 
-			/* else { xchat_print( ph, "XSUB - 2 arg NULL chan" ); } */
+			/* else { hexchat_print( ph, "XSUB - 2 arg NULL chan" ); } */
 			/* change server value only if it is true or 0 */
 			/* otherwise leave it as NULL */
 			if (SvTRUE (ST (1)) || SvNIOK (ST (1))) {
 				server = SvPV_nolen (ST (1));
-				/*                               xchat_printf( ph, "XSUB - find_context( NULL, %s )", SvPV_nolen(ST(1) )); */
+				/*                               hexchat_printf( ph, "XSUB - find_context( NULL, %s )", SvPV_nolen(ST(1) )); */
 			}
-			/*  else { xchat_print( ph, "XSUB - 2 arg NULL server" ); } */
+			/*  else { hexchat_print( ph, "XSUB - 2 arg NULL server" ); } */
 			break;
 		}
 
-		RETVAL = xchat_find_context (ph, server, chan);
+		RETVAL = hexchat_find_context (ph, server, chan);
 		if (RETVAL != NULL) {
-			/*                      xchat_print (ph, "XSUB - context found"); */
+			/*                      hexchat_print (ph, "XSUB - context found"); */
 			XSRETURN_IV (PTR2IV (RETVAL));
 		} else {
-			/*           xchat_print (ph, "XSUB - context not found"); */
+			/*           hexchat_print (ph, "XSUB - context not found"); */
 			XSRETURN_UNDEF;
 		}
 	}
@@ -1192,22 +1195,22 @@ XS (XS_Xchat_get_context)
 {
 	dXSARGS;
 	if (items != 0) {
-		xchat_print (ph, "Usage: Xchat::get_context()");
+		hexchat_print (ph, "Usage: Xchat::get_context()");
 	} else {
-		XSRETURN_IV (PTR2IV (xchat_get_context (ph)));
+		XSRETURN_IV (PTR2IV (hexchat_get_context (ph)));
 	}
 }
 
 static
 XS (XS_Xchat_set_context)
 {
-	xchat_context *ctx;
+	hexchat_context *ctx;
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::set_context(ctx)");
+		hexchat_print (ph, "Usage: Xchat::set_context(ctx)");
 	} else {
-		ctx = INT2PTR (xchat_context *, SvUV (ST (0)));
-		XSRETURN_IV ((IV) xchat_set_context (ph, ctx));
+		ctx = INT2PTR (hexchat_context *, SvUV (ST (0)));
+		XSRETURN_IV ((IV) hexchat_set_context (ph, ctx));
 	}
 }
 
@@ -1216,9 +1219,9 @@ XS (XS_Xchat_nickcmp)
 {
 	dXSARGS;
 	if (items != 2) {
-		xchat_print (ph, "Usage: Xchat::nickcmp(s1, s2)");
+		hexchat_print (ph, "Usage: Xchat::nickcmp(s1, s2)");
 	} else {
-		XSRETURN_IV ((IV) xchat_nickcmp (ph, SvPV_nolen (ST (0)),
+		XSRETURN_IV ((IV) hexchat_nickcmp (ph, SvPV_nolen (ST (0)),
 													SvPV_nolen (ST (1))));
 	}
 }
@@ -1227,37 +1230,37 @@ static
 XS (XS_Xchat_get_list)
 {
 	SV *name;
-	xchat_list *list;
+	hexchat_list *list;
 	const char *const *fields;
 	int count = 0;					  /* return value for scalar context */
 	dXSARGS;
 
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::get_list(name)");
+		hexchat_print (ph, "Usage: Xchat::get_list(name)");
 	} else {
 		SP -= items;				  /*remove the argument list from the stack */
 
 		name = ST (0);
 
-		list = xchat_list_get (ph, SvPV_nolen (name));
+		list = hexchat_list_get (ph, SvPV_nolen (name));
 
 		if (list == NULL) {
 			XSRETURN_EMPTY;
 		}
 
 		if (GIMME_V == G_SCALAR) {
-			while (xchat_list_next (ph, list)) {
+			while (hexchat_list_next (ph, list)) {
 				count++;
 			}
-			xchat_list_free (ph, list);
+			hexchat_list_free (ph, list);
 			XSRETURN_IV ((IV) count);
 		}
 
-		fields = xchat_list_fields (ph, SvPV_nolen (name));
-		while (xchat_list_next (ph, list)) {
+		fields = hexchat_list_fields (ph, SvPV_nolen (name));
+		while (hexchat_list_next (ph, list)) {
 			XPUSHs (list_item_to_sv (list, fields));
 		}
-		xchat_list_free (ph, list);
+		hexchat_list_free (ph, list);
 
 		PUTBACK;
 		return;
@@ -1270,10 +1273,10 @@ XS (XS_Xchat_Embed_plugingui_remove)
 	void *gui_entry;
 	dXSARGS;
 	if (items != 1) {
-		xchat_print (ph, "Usage: Xchat::Embed::plugingui_remove(handle)");
+		hexchat_print (ph, "Usage: Xchat::Embed::plugingui_remove(handle)");
 	} else {
 		gui_entry = INT2PTR (void *, SvUV (ST (0)));
-		xchat_plugingui_remove (ph, gui_entry);
+		hexchat_plugingui_remove (ph, gui_entry);
 	}
 	XSRETURN_EMPTY;
 }
@@ -1318,20 +1321,20 @@ xs_init (pTHX)
 		exit (1);
 	}
 
-	newCONSTSUB (stash, "PRI_HIGHEST", newSViv (XCHAT_PRI_HIGHEST));
-	newCONSTSUB (stash, "PRI_HIGH", newSViv (XCHAT_PRI_HIGH));
-	newCONSTSUB (stash, "PRI_NORM", newSViv (XCHAT_PRI_NORM));
-	newCONSTSUB (stash, "PRI_LOW", newSViv (XCHAT_PRI_LOW));
-	newCONSTSUB (stash, "PRI_LOWEST", newSViv (XCHAT_PRI_LOWEST));
+	newCONSTSUB (stash, "PRI_HIGHEST", newSViv (HEXCHAT_PRI_HIGHEST));
+	newCONSTSUB (stash, "PRI_HIGH", newSViv (HEXCHAT_PRI_HIGH));
+	newCONSTSUB (stash, "PRI_NORM", newSViv (HEXCHAT_PRI_NORM));
+	newCONSTSUB (stash, "PRI_LOW", newSViv (HEXCHAT_PRI_LOW));
+	newCONSTSUB (stash, "PRI_LOWEST", newSViv (HEXCHAT_PRI_LOWEST));
 
-	newCONSTSUB (stash, "EAT_NONE", newSViv (XCHAT_EAT_NONE));
-	newCONSTSUB (stash, "EAT_XCHAT", newSViv (XCHAT_EAT_XCHAT));
-	newCONSTSUB (stash, "EAT_PLUGIN", newSViv (XCHAT_EAT_PLUGIN));
-	newCONSTSUB (stash, "EAT_ALL", newSViv (XCHAT_EAT_ALL));
-	newCONSTSUB (stash, "FD_READ", newSViv (XCHAT_FD_READ));
-	newCONSTSUB (stash, "FD_WRITE", newSViv (XCHAT_FD_WRITE));
-	newCONSTSUB (stash, "FD_EXCEPTION", newSViv (XCHAT_FD_EXCEPTION));
-	newCONSTSUB (stash, "FD_NOTSOCKET", newSViv (XCHAT_FD_NOTSOCKET));
+	newCONSTSUB (stash, "EAT_NONE", newSViv (HEXCHAT_EAT_NONE));
+	newCONSTSUB (stash, "EAT_XCHAT", newSViv (HEXCHAT_EAT_HEXCHAT));
+	newCONSTSUB (stash, "EAT_PLUGIN", newSViv (HEXCHAT_EAT_PLUGIN));
+	newCONSTSUB (stash, "EAT_ALL", newSViv (HEXCHAT_EAT_ALL));
+	newCONSTSUB (stash, "FD_READ", newSViv (HEXCHAT_FD_READ));
+	newCONSTSUB (stash, "FD_WRITE", newSViv (HEXCHAT_FD_WRITE));
+	newCONSTSUB (stash, "FD_EXCEPTION", newSViv (HEXCHAT_FD_EXCEPTION));
+	newCONSTSUB (stash, "FD_NOTSOCKET", newSViv (HEXCHAT_FD_NOTSOCKET));
 	newCONSTSUB (stash, "KEEP", newSViv (1));
 	newCONSTSUB (stash, "REMOVE", newSViv (0));
 
@@ -1347,7 +1350,7 @@ perl_init (void)
 	char *perl_args[] = { "", "-e", "0", "-w" };
 	char *env[] = { "" };
 	static const char xchat_definitions[] = {
-		/* Redefine the $SIG{__WARN__} handler to have XChat
+		/* Redefine the $SIG{__WARN__} handler to have HexChat
 		   printing warnings in the main window. (TheHobbit) */
 #include "xchat.pm.h"
 	};
@@ -1372,7 +1375,7 @@ perl_init (void)
 #endif
 
 	warn = 0;
-	xchat_get_prefs (ph, "perl_warnings", NULL, &warn);
+	hexchat_get_prefs (ph, "perl_warnings", NULL, &warn);
 	arg_count = warn ? 4 : 3;
 
 	PERL_SYS_INIT3 (&arg_count, (char ***)&perl_args, (char ***)&env);
@@ -1471,10 +1474,10 @@ perl_command_unloadall (char *word[], char *word_eol[], void *userdata)
 {
 	if (my_perl != NULL) {
 		execute_perl (sv_2mortal (newSVpv ("Xchat::Embed::unload_all", 0)), "");
-		return XCHAT_EAT_XCHAT;
+		return HEXCHAT_EAT_HEXCHAT;
 	}
 
-	return XCHAT_EAT_XCHAT;
+	return HEXCHAT_EAT_HEXCHAT;
 }
 
 static int
@@ -1483,11 +1486,11 @@ perl_command_reloadall (char *word[], char *word_eol[], void *userdata)
 	if (my_perl != NULL) {
 		execute_perl (sv_2mortal (newSVpv ("Xchat::Embed::reload_all", 0)), "");
 
-		return XCHAT_EAT_XCHAT;
+		return HEXCHAT_EAT_HEXCHAT;
 	} else {
 		perl_auto_load( NULL );
 	}
-	return XCHAT_EAT_XCHAT;
+	return HEXCHAT_EAT_HEXCHAT;
 }
 
 static int
@@ -1498,10 +1501,10 @@ perl_command_load (char *word[], char *word_eol[], void *userdata)
 	if (file != NULL )
 	{
 		perl_load_file (file);
-		return XCHAT_EAT_XCHAT;
+		return HEXCHAT_EAT_HEXCHAT;
 	}
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static int
@@ -1511,10 +1514,10 @@ perl_command_unload (char *word[], char *word_eol[], void *userdata)
 	
 	if (my_perl != NULL && file != NULL) {
 		execute_perl (sv_2mortal (newSVpv ("Xchat::Embed::unload", 0)), file);
-		return XCHAT_EAT_XCHAT;
+		return HEXCHAT_EAT_HEXCHAT;
 	}
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static int
@@ -1524,14 +1527,14 @@ perl_command_reload (char *word[], char *word_eol[], void *userdata)
 	
 	if (my_perl != NULL && file != NULL) {
 		execute_perl (sv_2mortal (newSVpv ("Xchat::Embed::reload", 0)), file);
-		return XCHAT_EAT_XCHAT;
+		return HEXCHAT_EAT_HEXCHAT;
 	}
 	
-	return XCHAT_EAT_XCHAT;
+	return HEXCHAT_EAT_HEXCHAT;
 }
 
 void
-xchat_plugin_get_info (char **name, char **desc, char **version,
+hexchat_plugin_get_info (char **name, char **desc, char **version,
 							  void **reserved)
 {
 	*name = "Perl";
@@ -1547,11 +1550,11 @@ xchat_plugin_get_info (char **name, char **desc, char **version,
 static int initialized = 0;
 
 int
-xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name,
+hexchat_plugin_init (hexchat_plugin * plugin_handle, char **plugin_name,
 						 char **plugin_desc, char **plugin_version, char *arg)
 {
 	if (initialized != 0) {
-		xchat_print (plugin_handle, "Perl interface already loaded\n");
+		hexchat_print (plugin_handle, "Perl interface already loaded\n");
 		return 0;
 	}
 
@@ -1562,33 +1565,33 @@ xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name,
 	*plugin_desc = "Perl scripting interface";
 	*plugin_version = PACKAGE_VERSION;
 
-	xchat_hook_command (ph, "load", XCHAT_PRI_NORM, perl_command_load, 0, 0);
-	xchat_hook_command (ph, "unload", XCHAT_PRI_NORM, perl_command_unload, 0,
+	hexchat_hook_command (ph, "load", HEXCHAT_PRI_NORM, perl_command_load, 0, 0);
+	hexchat_hook_command (ph, "unload", HEXCHAT_PRI_NORM, perl_command_unload, 0,
 							  0);
-	xchat_hook_command (ph, "reload", XCHAT_PRI_NORM, perl_command_reload, 0,
+	hexchat_hook_command (ph, "reload", HEXCHAT_PRI_NORM, perl_command_reload, 0,
 							  0);
-	xchat_hook_command (ph, "pl_reload", XCHAT_PRI_NORM, perl_command_reload, 0,
+	hexchat_hook_command (ph, "pl_reload", HEXCHAT_PRI_NORM, perl_command_reload, 0,
 							  0);
-	xchat_hook_command (ph, "unloadall", XCHAT_PRI_NORM,
+	hexchat_hook_command (ph, "unloadall", HEXCHAT_PRI_NORM,
 							  perl_command_unloadall, 0, 0);
-	xchat_hook_command (ph, "reloadall", XCHAT_PRI_NORM,
+	hexchat_hook_command (ph, "reloadall", HEXCHAT_PRI_NORM,
 							  perl_command_reloadall, 0, 0);
 
 	/*perl_init (); */
-	xchat_hook_timer (ph, 0, perl_auto_load, NULL );
+	hexchat_hook_timer (ph, 0, perl_auto_load, NULL );
 
-	xchat_print (ph, "Perl interface loaded\n");
+	hexchat_print (ph, "Perl interface loaded\n");
 
 	return 1;
 }
 
 int
-xchat_plugin_deinit (xchat_plugin * plugin_handle)
+hexchat_plugin_deinit (hexchat_plugin * plugin_handle)
 {
 	perl_end ();
 
 	initialized = 0;
-	xchat_print (plugin_handle, "Perl interface unloaded\n");
+	hexchat_print (plugin_handle, "Perl interface unloaded\n");
 
 	return 1;
 }
