@@ -38,18 +38,18 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include "xchat.h"
+#include "hexchat.h"
 #include "plugin.h"
 #include "ignore.h"
 #include "util.h"
 #include "fe.h"
-#include "cfgfiles.h"			  /* xchat_fopen_file() */
+#include "cfgfiles.h"			  /* hexchat_fopen_file() */
 #include "network.h"				/* net_ip() */
 #include "modes.h"
 #include "notify.h"
 #include "inbound.h"
 #include "text.h"
-#include "xchatc.h"
+#include "hexchatc.h"
 #include "servlist.h"
 #include "server.h"
 #include "tree.h"
@@ -88,7 +88,7 @@ random_line (char *file_name)
 	if (!file_name[0])
 		goto nofile;
 
-	fh = xchat_fopen_file (file_name, "r", 0);
+	fh = hexchat_fopen_file (file_name, "r", 0);
 	if (!fh)
 	{
 	 nofile:
@@ -123,7 +123,7 @@ server_sendpart (server * serv, char *channel, char *reason)
 {
 	if (!reason)
 	{
-		reason = random_line (prefs.partreason);
+		reason = random_line (prefs.hex_irc_part_reason);
 		serv->p_part (serv, channel, reason);
 		free (reason);
 	} else
@@ -140,7 +140,7 @@ server_sendquit (session * sess)
 
 	if (!sess->quitreason)
 	{
-		colrea = strdup (prefs.quitreason);
+		colrea = strdup (prefs.hex_irc_quit_reason);
 		check_special_chars (colrea, FALSE);
 		rea = random_line (colrea);
 		free (colrea);
@@ -258,6 +258,41 @@ cmd_addbutton (struct session *sess, char *tbuf, char *word[],
 	return FALSE;
 }
 
+/* ADDSERVER <networkname> <serveraddress>, add a new network and server to the network list */
+static int
+cmd_addserver (struct session *sess, char *tbuf, char *word[], char *word_eol[])
+{
+	ircnet *network;
+
+	/* do we have enough arguments given? */
+	if (*word[2] && *word_eol[3])
+	{
+		network = servlist_net_find (word[2], NULL, strcmp);
+
+		/* if the given network doesn't exist yet, add it */
+		if (!network)
+		{
+			network = servlist_net_add (word[2], "", TRUE);
+			network->encoding = strdup (IRC_DEFAULT_CHARSET);
+		}
+		/* if we had the network already, check if the given server already exists */
+		else if (servlist_server_find (network, word_eol[3], NULL))
+		{
+			PrintTextf (sess, _("Server %s already exists on network %s.\n"), word_eol[3], word[2]);
+			return TRUE;	/* unsuccessful, but the syntax was correct so we don't want to show the help */
+		}
+
+		/* server added to new or existing network, doesn't make any difference */
+		servlist_server_add (network, word_eol[3]);
+		PrintTextf (sess, _("Added server %s to network %s.\n"), word_eol[3], word[2]);
+		return TRUE;		/* success */
+	}
+	else
+	{
+		return FALSE;		/* print help */
+	}
+}
+
 static int
 cmd_allchannels (session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -343,11 +378,11 @@ cmd_away (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 			reason = sess->server->last_away_reason;
 		else
 			/* must manage memory pointed to by random_line() */
-			reason = random_line (prefs.awayreason);
+			reason = random_line (prefs.hex_away_reason);
 	}
 	sess->server->p_set_away (sess->server, reason);
 
-	if (prefs.show_away_message)
+	if (prefs.hex_away_show_message)
 	{
 		snprintf (tbuf, TBUFSIZE, "me is away: %s", reason);
 		for (list = sess_list; list; list = list->next)
@@ -389,7 +424,7 @@ cmd_back (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	{
 		sess->server->p_set_back (sess->server);
 
-		if (prefs.show_away_message)
+		if (prefs.hex_away_show_message)
 		{
 			gone = time (NULL) - sess->server->away_time;
 			sprintf (tbuf, "me is back (gone %.2d:%.2d:%.2d)", gone / 3600,
@@ -478,7 +513,7 @@ ban (session * sess, char *tbuf, char *mask, char *bantypestr, int deop)
 		if (*bantypestr)
 			bantype = atoi (bantypestr);
 		else
-			bantype = prefs.bantype;
+			bantype = prefs.hex_irc_ban_type;
 
 		tbuf[0] = 0;
 		if (inet_addr (fullhost) != -1)	/* "fullhost" is really a IP number */
@@ -830,7 +865,7 @@ cmd_dcc (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 			if (!*nick)
 				return FALSE;
 
-			maxcps = prefs.dcc_max_send_cps;
+			maxcps = prefs.hex_dcc_max_send_cps;
 			if (!g_ascii_strncasecmp(nick, "-maxcps=", 8))
 			{
 				maxcps = atoi(nick + 8);
@@ -1415,7 +1450,7 @@ cmd_dns (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 			}
 		} else
 		{
-			snprintf (tbuf, TBUFSIZE, "exec -d %s %s", prefs.dnsprogram, nick);
+			snprintf (tbuf, TBUFSIZE, "exec -d %s %s", prefs.hex_dnsprogram, nick);
 			handle_command (sess, tbuf, FALSE);
 		}
 		return TRUE;
@@ -1690,10 +1725,10 @@ exec_data (GIOChannel *source, GIOCondition condition, struct nbexec *s)
 			if (s->tochannel)
 			{
 				/* must turn off auto-completion temporarily */
-				unsigned int old = prefs.nickcompletion;
-				prefs.nickcompletion = 0;
+				unsigned int old = prefs.hex_completion_auto;
+				prefs.hex_completion_auto = 0;
 				handle_multiline (s->sess, buf, FALSE, TRUE);
-				prefs.nickcompletion = old;
+				prefs.hex_completion_auto = old;
 			}
 			else
 				PrintText (s->sess, buf);
@@ -1856,6 +1891,28 @@ cmd_exec (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 
 #endif
 
+#if 0
+/* export config stub */
+static int
+cmd_exportconf (struct session *sess, char *tbuf, char *word[], char *word_eol[])
+{
+	/* this is pretty much the same as in hexchat_exit() */
+	save_config ();
+	if (prefs.save_pevents)
+	{
+		pevent_save (NULL);
+	}
+	sound_save ();
+	notify_save ();
+	ignore_save ();
+	free_sessions ();
+	chanopt_save_all ();
+
+	return TRUE;		/* success */
+	return FALSE;		/* fail */
+}
+#endif
+
 static int
 cmd_flushq (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -2350,7 +2407,7 @@ cmd_kickban (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_killall (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	xchat_exit();
+	hexchat_exit();
 	return 2;
 }
 
@@ -2362,7 +2419,7 @@ cmd_lagcheck (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 }
 
 static void
-lastlog (session *sess, char *search, gboolean regexp)
+lastlog (session *sess, char *search, gtk_xtext_search_flags flags)
 {
 	session *lastlog_sess;
 
@@ -2374,29 +2431,50 @@ lastlog (session *sess, char *search, gboolean regexp)
 		lastlog_sess = new_ircwindow (sess->server, "(lastlog)", SESS_DIALOG, 0);
 
 	lastlog_sess->lastlog_sess = sess;
-	lastlog_sess->lastlog_regexp = regexp;	/* remember the search type */
+	lastlog_sess->lastlog_flags = flags;
 
 	fe_text_clear (lastlog_sess, 0);
-	fe_lastlog (sess, lastlog_sess, search, regexp);
+	fe_lastlog (sess, lastlog_sess, search, flags);
 }
 
 static int
 cmd_lastlog (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	if (*word_eol[2])
+	int j = 2;
+	gtk_xtext_search_flags flags = 0;
+	gboolean doublehyphen = FALSE;
+
+	while (word_eol[j] != NULL && word_eol [j][0] == '-' && !doublehyphen)
 	{
-		if (!strcmp (word[2], "-r"))
+		switch (word_eol [j][1])
 		{
-			lastlog (sess, word_eol[3], TRUE);
-		}
-		else
-		{
-			lastlog (sess, word_eol[2], FALSE);
+			case 'r':
+				flags |= regexp;
+				break;
+			case 'm':
+				flags |= case_match;
+				break;
+			case 'h':
+				flags |= highlight;
+				break;
+			case '-':
+				doublehyphen = TRUE;
+				break;
+			default:
+				break;
+				/* O dear whatever shall we do here? */
 		}
+		j++;
+	}
+	if (*word_eol[j])
+	{
+		lastlog (sess, word_eol[j], flags);
 		return TRUE;
 	}
-
-	return FALSE;
+	else
+	{	
+		return FALSE;
+	}
 }
 
 static int
@@ -2414,7 +2492,7 @@ load_perform_file (session *sess, char *file)
 	char *nl;
 	FILE *fp;
 
-	fp = xchat_fopen_file (file, "r", XOF_FULLPATH);
+	fp = hexchat_fopen_file (file, "r", XOF_FULLPATH);
 	if (!fp)
 		return FALSE;
 
@@ -2426,7 +2504,7 @@ load_perform_file (session *sess, char *file)
 			continue;
 		if (nl)
 			*nl = 0;
-		if (tbuf[0] == prefs.cmdchar[0])
+		if (tbuf[0] == prefs.hex_input_command_char[0])
 			handle_command (sess, tbuf + 1, TRUE);
 		else
 			handle_command (sess, tbuf, TRUE);
@@ -2822,11 +2900,11 @@ cmd_quote (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	int tmp = prefs.recon_delay;
+	int tmp = prefs.hex_net_reconnect_delay;
 	GSList *list;
 	server *serv = sess->server;
 
-	prefs.recon_delay = 0;
+	prefs.hex_net_reconnect_delay = 0;
 
 	if (!g_ascii_strcasecmp (word[2], "ALL"))
 	{
@@ -2867,7 +2945,7 @@ cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	{
 		serv->auto_reconnect (serv, TRUE, -1);
 	}
-	prefs.recon_delay = tmp;
+	prefs.hex_net_reconnect_delay = tmp;
 
 	return TRUE;
 }
@@ -2884,23 +2962,6 @@ cmd_recv (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	return FALSE;
 }
 
-#if 0 /* manual command for flushing prefs to disk, but we use an autosave-upon-set approach instead */
-static int
-cmd_saveconf (struct session *sess, char *tbuf, char *word[], char *word_eol[])
-{
-	if (save_config ())
-	{
-		PrintText (sess, "Settings have been saved successfully.\n");
-	}
-	else
-	{
-		PrintText (sess, "Error saving settings.\n");
-	}
-
-	return TRUE;
-}
-#endif
-
 static int
 cmd_say (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -3184,7 +3245,7 @@ cmd_tray (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 
 	if (!word[3][0])
 	{
-		fe_tray_set_file (NULL);	/* default xchat icon */
+		fe_tray_set_file (NULL);	/* default HexChat icon */
 		return TRUE;
 	}
 
@@ -3513,6 +3574,7 @@ cmd_voice (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 const struct commands xc_cmds[] = {
 	{"ADDBUTTON", cmd_addbutton, 0, 0, 1,
 	 N_("ADDBUTTON <name> <action>, adds a button under the user-list")},
+	{"ADDSERVER", cmd_addserver, 0, 0, 1, N_("ADDSERVER <NewNetwork> <newserver/6667>, adds a new network with a new server to the network list")},
 	{"ALLCHAN", cmd_allchannels, 0, 0, 1,
 	 N_("ALLCHAN <cmd>, sends a command to all channels you're in")},
 	{"ALLCHANL", cmd_allchannelslocal, 0, 0, 1,
@@ -3569,6 +3631,9 @@ const struct commands xc_cmds[] = {
 	{"EXECSTOP", cmd_execs, 0, 0, 1, N_("EXECSTOP, sends the process SIGSTOP")},
 	{"EXECWRITE", cmd_execw, 0, 0, 1, N_("EXECWRITE, sends data to the processes stdin")},
 #endif
+#endif
+#if 0
+	{"EXPORTCONF", cmd_exportconf, 0, 0, 1, N_("EXPORTCONF, exports HexChat settings")},
 #endif
 	{"FLUSHQ", cmd_flushq, 0, 0, 1,
 	 N_("FLUSHQ, flushes the current server's send queue")},
@@ -3602,7 +3667,11 @@ const struct commands xc_cmds[] = {
 	{"LAGCHECK", cmd_lagcheck, 0, 0, 1,
 	 N_("LAGCHECK, forces a new lag check")},
 	{"LASTLOG", cmd_lastlog, 0, 0, 1,
-	 N_("LASTLOG [-r] <string>, searches for a string in the buffer")},
+	 N_("LASTLOG [-h] [-m] [-r] [--] <string>, searches for a string in the buffer\n"
+	 "    Use -h to highlight the found string(s)\n"
+	 "    Use -m to match case\n"
+	 "    Use -r when string is a Regular Expression\n"
+	 "    Use -- (double hyphen) to end options when searching for, say, the string '-r'")},
 	{"LIST", cmd_list, 1, 0, 1, 0},
 	{"LOAD", cmd_load, 0, 0, 1, N_("LOAD [-e] <file>, loads a plugin or script")},
 
@@ -3651,11 +3720,8 @@ const struct commands xc_cmds[] = {
 	{"RECONNECT", cmd_reconnect, 0, 0, 1,
 	 N_("RECONNECT [<host>] [<port>] [<password>], Can be called just as /RECONNECT to reconnect to the current server or with /RECONNECT ALL to reconnect to all the open servers")},
 #endif
-	{"RECV", cmd_recv, 1, 0, 1, N_("RECV <text>, send raw data to xchat, as if it was received from the irc server")},
+	{"RECV", cmd_recv, 1, 0, 1, N_("RECV <text>, send raw data to HexChat, as if it was received from the IRC server")},
 
-#if 0
-	{"SAVECONF", cmd_saveconf, 0, 0, 1, N_("SAVECONF, saves the current settings to disk")},
-#endif
 	{"SAY", cmd_say, 0, 0, 1,
 	 N_("SAY <text>, sends the text to the object in the current window")},
 	{"SEND", cmd_send, 0, 0, 1, N_("SEND <nick> [<file>]")},
@@ -3668,7 +3734,7 @@ const struct commands xc_cmds[] = {
 #endif
 #ifdef USE_OPENSSL
 	{"SERVER", cmd_server, 0, 0, 1,
-	 N_("SERVER [-ssl] <host> [<port>] [<password>], connects to a server, the default port is 6667 for normal connections, and 9999 for ssl connections")},
+	 N_("SERVER [-ssl] <host> [<port>] [<password>], connects to a server, the default port is 6667 for normal connections, and 6697 for ssl connections")},
 #else
 	{"SERVER", cmd_server, 0, 0, 1,
 	 N_("SERVER <host> [<port>] [<password>], connects to a server, the default port is 6667")},
@@ -3844,7 +3910,7 @@ auto_insert (char *dest, int destlen, unsigned char *src, char *word[],
 				case 'h':
 					utf = h; break;
 				case 'm':
-					utf = get_cpu_str (); break;
+					utf = get_sys_str (1); break;
 				case 'n':
 					utf = n; break;
 				case 's':
@@ -4033,7 +4099,7 @@ perform_nick_completion (struct session *sess, char *cmd, char *tbuf)
 	char *space = strchr (cmd, ' ');
 	if (space && space != cmd)
 	{
-		if (space[-1] == prefs.nick_suffix[0] && space - 1 != cmd)
+		if (space[-1] == prefs.hex_completion_suffix[0] && space - 1 != cmd)
 		{
 			len = space - cmd - 1;
 			if (len < NICKLEN)
@@ -4082,7 +4148,7 @@ user_command (session * sess, char *tbuf, char *cmd, char *word[],
 	handle_command (sess, tbuf, TRUE);
 }
 
-/* handle text entered without a CMDchar prefix */
+/* handle text entered without a hex_input_command_char prefix */
 
 static void
 handle_say (session *sess, char *text, int check_spch)
@@ -4099,7 +4165,7 @@ handle_say (session *sess, char *text, int check_spch)
 
 	if (strcmp (sess->channel, "(lastlog)") == 0)
 	{
-		lastlog (sess->lastlog_sess, text, sess->lastlog_regexp);
+		lastlog (sess->lastlog_sess, text, sess->lastlog_flags);
 		return;
 	}
 
@@ -4110,8 +4176,8 @@ handle_say (session *sess, char *text, int check_spch)
 	if (len + NICKLEN >= newcmdlen)
 		newcmd = malloc (newcmdlen = len + NICKLEN + 1);
 
-	if (check_spch && prefs.perc_color)
-		check_special_chars (text, prefs.perc_ascii);
+	if (check_spch && prefs.hex_input_perc_color)
+		check_special_chars (text, prefs.hex_input_perc_ascii);
 
 	/* Python relies on this */
 	word[PDIWORDS] = NULL;
@@ -4134,7 +4200,7 @@ handle_say (session *sess, char *text, int check_spch)
 		goto xit;
 	}
 
-	if (prefs.nickcompletion)
+	if (prefs.hex_completion_auto)
 		perform_nick_completion (sess, text, newcmd);
 	else
 		safe_strcpy (newcmd, text, newcmdlen);
@@ -4175,7 +4241,8 @@ handle_say (session *sess, char *text, int check_spch)
 
 		if (strlen (text) > max)
 		{
-			int i = 0, size;
+			unsigned int i = 0;
+			int size;
 
 			/* traverse the utf8 string and find the nearest cut point that
 				doesn't split 1 char in half */
@@ -4265,8 +4332,8 @@ handle_command (session *sess, char *cmd, int check_spch)
 	if (int_cmd && !int_cmd->handle_quotes)
 		process_data_init (pdibuf, cmd, word, word_eol, FALSE, FALSE);
 
-	if (check_spch && prefs.perc_color)
-		check_special_chars (cmd, prefs.perc_ascii);
+	if (check_spch && prefs.hex_input_perc_color)
+		check_special_chars (cmd, prefs.hex_input_perc_ascii);
 
 	if (plugin_emit_command (sess, word[1], word, word_eol))
 		goto xit;
@@ -4347,20 +4414,20 @@ handle_user_input (session *sess, char *text, int history, int nocommand)
 		history_add (&sess->history, text);
 
 	/* is it NOT a command, just text? */
-	if (nocommand || text[0] != prefs.cmdchar[0])
+	if (nocommand || text[0] != prefs.hex_input_command_char[0])
 	{
 		handle_say (sess, text, TRUE);
 		return 1;
 	}
 
 	/* check for // */
-	if (text[0] == prefs.cmdchar[0] && text[1] == prefs.cmdchar[0])
+	if (text[0] == prefs.hex_input_command_char[0] && text[1] == prefs.hex_input_command_char[0])
 	{
 		handle_say (sess, text + 1, TRUE);
 		return 1;
 	}
 
-	if (prefs.cmdchar[0] == '/')
+	if (prefs.hex_input_command_char[0] == '/')
 	{
 		int i;
 		const char *unix_dirs [] = {
