@@ -29,7 +29,7 @@
 #include <unistd.h>
 #endif
 
-#include "xchat.h"
+#include "hexchat.h"
 #include "fe.h"
 #include "util.h"
 #include "outbound.h"
@@ -41,12 +41,13 @@
 #include "notify.h"
 #include "text.h"
 #define PLUGIN_C
-typedef struct session xchat_context;
-#include "xchat-plugin.h"
+typedef struct session hexchat_context;
+#include "hexchat-plugin.h"
 #include "plugin.h"
+#include "typedef.h"
 
 
-#include "xchatc.h"
+#include "hexchatc.h"
 
 /* the USE_PLUGIN define only removes libdl stuff */
 
@@ -61,9 +62,9 @@ typedef struct session xchat_context;
 #define DEBUG(x) {x;}
 
 /* crafted to be an even 32 bytes */
-struct _xchat_hook
+struct _hexchat_hook
 {
-	xchat_plugin *pl;	/* the plugin to which it belongs */
+	hexchat_plugin *pl;	/* the plugin to which it belongs */
 	char *name;			/* "xdcc" */
 	void *callback;	/* pointer to xdcc_callback */
 	char *help_text;	/* help_text for commands only */
@@ -73,7 +74,7 @@ struct _xchat_hook
 	int pri;	/* fd */	/* priority / fd for HOOK_FD only */
 };
 
-struct _xchat_list
+struct _hexchat_list
 {
 	int type;			/* LIST_* */
 	GSList *pos;		/* current pos */
@@ -82,13 +83,13 @@ struct _xchat_list
 	struct notify_per_server *notifyps;	/* notify_per_server * */
 };
 
-typedef int (xchat_cmd_cb) (char *word[], char *word_eol[], void *user_data);
-typedef int (xchat_serv_cb) (char *word[], char *word_eol[], void *user_data);
-typedef int (xchat_print_cb) (char *word[], void *user_data);
-typedef int (xchat_fd_cb) (int fd, int flags, void *user_data);
-typedef int (xchat_timer_cb) (void *user_data);
-typedef int (xchat_init_func) (xchat_plugin *, char **, char **, char **, char *);
-typedef int (xchat_deinit_func) (xchat_plugin *);
+typedef int (hexchat_cmd_cb) (char *word[], char *word_eol[], void *user_data);
+typedef int (hexchat_serv_cb) (char *word[], char *word_eol[], void *user_data);
+typedef int (hexchat_print_cb) (char *word[], void *user_data);
+typedef int (hexchat_fd_cb) (int fd, int flags, void *user_data);
+typedef int (hexchat_timer_cb) (void *user_data);
+typedef int (hexchat_init_func) (hexchat_plugin *, char **, char **, char **, char *);
+typedef int (hexchat_deinit_func) (hexchat_plugin *);
 
 enum
 {
@@ -118,13 +119,13 @@ extern const struct prefs vars[];	/* cfgfiles.c */
 /* unload a plugin and remove it from our linked list */
 
 static int
-plugin_free (xchat_plugin *pl, int do_deinit, int allow_refuse)
+plugin_free (hexchat_plugin *pl, int do_deinit, int allow_refuse)
 {
 	GSList *list, *next;
-	xchat_hook *hook;
-	xchat_deinit_func *deinit_func;
+	hexchat_hook *hook;
+	hexchat_deinit_func *deinit_func;
 
-	/* fake plugin added by xchat_plugingui_add() */
+	/* fake plugin added by hexchat_plugingui_add() */
 	if (pl->fake)
 		goto xit;
 
@@ -143,7 +144,7 @@ plugin_free (xchat_plugin *pl, int do_deinit, int allow_refuse)
 		hook = list->data;
 		next = list->next;
 		if (hook->pl == pl)
-			xchat_unhook (NULL, hook);
+			hexchat_unhook (NULL, hook);
 		list = next;
 	}
 
@@ -179,14 +180,14 @@ xit:
 	return TRUE;
 }
 
-static xchat_plugin *
-plugin_list_add (xchat_context *ctx, char *filename, const char *name,
+static hexchat_plugin *
+plugin_list_add (hexchat_context *ctx, char *filename, const char *name,
 					  const char *desc, const char *version, void *handle,
 					  void *deinit_func, int fake, int free_strings)
 {
-	xchat_plugin *pl;
+	hexchat_plugin *pl;
 
-	pl = malloc (sizeof (xchat_plugin));
+	pl = malloc (sizeof (hexchat_plugin));
 	pl->handle = handle;
 	pl->filename = filename;
 	pl->context = ctx;
@@ -203,14 +204,14 @@ plugin_list_add (xchat_context *ctx, char *filename, const char *name,
 }
 
 static void *
-xchat_dummy (xchat_plugin *ph)
+hexchat_dummy (hexchat_plugin *ph)
 {
 	return NULL;
 }
 
 #ifdef WIN32
 static int
-xchat_read_fd (xchat_plugin *ph, GIOChannel *source, char *buf, int *len)
+hexchat_read_fd (hexchat_plugin *ph, GIOChannel *source, char *buf, int *len)
 {
 	GError *error = NULL;
 
@@ -234,7 +235,7 @@ void
 plugin_add (session *sess, char *filename, void *handle, void *init_func,
 				void *deinit_func, char *arg, int fake)
 {
-	xchat_plugin *pl;
+	hexchat_plugin *pl;
 	char *file;
 
 	file = NULL;
@@ -247,56 +248,56 @@ plugin_add (session *sess, char *filename, void *handle, void *init_func,
 	if (!fake)
 	{
 		/* win32 uses these because it doesn't have --export-dynamic! */
-		pl->xchat_hook_command = xchat_hook_command;
-		pl->xchat_hook_server = xchat_hook_server;
-		pl->xchat_hook_print = xchat_hook_print;
-		pl->xchat_hook_timer = xchat_hook_timer;
-		pl->xchat_hook_fd = xchat_hook_fd;
-		pl->xchat_unhook = xchat_unhook;
-		pl->xchat_print = xchat_print;
-		pl->xchat_printf = xchat_printf;
-		pl->xchat_command = xchat_command;
-		pl->xchat_commandf = xchat_commandf;
-		pl->xchat_nickcmp = xchat_nickcmp;
-		pl->xchat_set_context = xchat_set_context;
-		pl->xchat_find_context = xchat_find_context;
-		pl->xchat_get_context = xchat_get_context;
-		pl->xchat_get_info = xchat_get_info;
-		pl->xchat_get_prefs = xchat_get_prefs;
-		pl->xchat_list_get = xchat_list_get;
-		pl->xchat_list_free = xchat_list_free;
-		pl->xchat_list_fields = xchat_list_fields;
-		pl->xchat_list_str = xchat_list_str;
-		pl->xchat_list_next = xchat_list_next;
-		pl->xchat_list_int = xchat_list_int;
-		pl->xchat_plugingui_add = xchat_plugingui_add;
-		pl->xchat_plugingui_remove = xchat_plugingui_remove;
-		pl->xchat_emit_print = xchat_emit_print;
+		pl->hexchat_hook_command = hexchat_hook_command;
+		pl->hexchat_hook_server = hexchat_hook_server;
+		pl->hexchat_hook_print = hexchat_hook_print;
+		pl->hexchat_hook_timer = hexchat_hook_timer;
+		pl->hexchat_hook_fd = hexchat_hook_fd;
+		pl->hexchat_unhook = hexchat_unhook;
+		pl->hexchat_print = hexchat_print;
+		pl->hexchat_printf = hexchat_printf;
+		pl->hexchat_command = hexchat_command;
+		pl->hexchat_commandf = hexchat_commandf;
+		pl->hexchat_nickcmp = hexchat_nickcmp;
+		pl->hexchat_set_context = hexchat_set_context;
+		pl->hexchat_find_context = hexchat_find_context;
+		pl->hexchat_get_context = hexchat_get_context;
+		pl->hexchat_get_info = hexchat_get_info;
+		pl->hexchat_get_prefs = hexchat_get_prefs;
+		pl->hexchat_list_get = hexchat_list_get;
+		pl->hexchat_list_free = hexchat_list_free;
+		pl->hexchat_list_fields = hexchat_list_fields;
+		pl->hexchat_list_str = hexchat_list_str;
+		pl->hexchat_list_next = hexchat_list_next;
+		pl->hexchat_list_int = hexchat_list_int;
+		pl->hexchat_plugingui_add = hexchat_plugingui_add;
+		pl->hexchat_plugingui_remove = hexchat_plugingui_remove;
+		pl->hexchat_emit_print = hexchat_emit_print;
 #ifdef WIN32
-		pl->xchat_read_fd = (void *) xchat_read_fd;
+		pl->hexchat_read_fd = (void *) hexchat_read_fd;
 #else
-		pl->xchat_read_fd = xchat_dummy;
+		pl->hexchat_read_fd = hexchat_dummy;
 #endif
-		pl->xchat_list_time = xchat_list_time;
-		pl->xchat_gettext = xchat_gettext;
-		pl->xchat_send_modes = xchat_send_modes;
-		pl->xchat_strip = xchat_strip;
-		pl->xchat_free = xchat_free;
-		pl->xchat_pluginpref_set_str = xchat_pluginpref_set_str;
-		pl->xchat_pluginpref_get_str = xchat_pluginpref_get_str;
-		pl->xchat_pluginpref_set_int = xchat_pluginpref_set_int;
-		pl->xchat_pluginpref_get_int = xchat_pluginpref_get_int;
-		pl->xchat_pluginpref_delete = xchat_pluginpref_delete;
-		pl->xchat_pluginpref_list = xchat_pluginpref_list;
+		pl->hexchat_list_time = hexchat_list_time;
+		pl->hexchat_gettext = hexchat_gettext;
+		pl->hexchat_send_modes = hexchat_send_modes;
+		pl->hexchat_strip = hexchat_strip;
+		pl->hexchat_free = hexchat_free;
+		pl->hexchat_pluginpref_set_str = hexchat_pluginpref_set_str;
+		pl->hexchat_pluginpref_get_str = hexchat_pluginpref_get_str;
+		pl->hexchat_pluginpref_set_int = hexchat_pluginpref_set_int;
+		pl->hexchat_pluginpref_get_int = hexchat_pluginpref_get_int;
+		pl->hexchat_pluginpref_delete = hexchat_pluginpref_delete;
+		pl->hexchat_pluginpref_list = hexchat_pluginpref_list;
 
-		/* incase new plugins are loaded on older xchat */
-		pl->xchat_dummy4 = xchat_dummy;
-		pl->xchat_dummy3 = xchat_dummy;
-		pl->xchat_dummy2 = xchat_dummy;
-		pl->xchat_dummy1 = xchat_dummy;
+		/* incase new plugins are loaded on older HexChat */
+		pl->hexchat_dummy4 = hexchat_dummy;
+		pl->hexchat_dummy3 = hexchat_dummy;
+		pl->hexchat_dummy2 = hexchat_dummy;
+		pl->hexchat_dummy1 = hexchat_dummy;
 
-		/* run xchat_plugin_init, if it returns 0, close the plugin */
-		if (((xchat_init_func *)init_func) (pl, &pl->name, &pl->desc, &pl->version, arg) == 0)
+		/* run hexchat_plugin_init, if it returns 0, close the plugin */
+		if (((hexchat_init_func *)init_func) (pl, &pl->name, &pl->desc, &pl->version, arg) == 0)
 		{
 			plugin_free (pl, FALSE, FALSE);
 			return;
@@ -314,7 +315,7 @@ int
 plugin_kill (char *name, int by_filename)
 {
 	GSList *list;
-	xchat_plugin *pl;
+	hexchat_plugin *pl;
 
 	list = plugin_list;
 	while (list)
@@ -345,7 +346,7 @@ void
 plugin_kill_all (void)
 {
 	GSList *list, *next;
-	xchat_plugin *pl;
+	hexchat_plugin *pl;
 
 	list = plugin_list;
 	while (list)
@@ -366,8 +367,8 @@ char *
 plugin_load (session *sess, char *filename, char *arg)
 {
 	void *handle;
-	xchat_init_func *init_func;
-	xchat_deinit_func *deinit_func;
+	hexchat_init_func *init_func;
+	hexchat_deinit_func *deinit_func;
 
 #ifdef USE_GMODULE
 	/* load the plugin */
@@ -375,15 +376,15 @@ plugin_load (session *sess, char *filename, char *arg)
 	if (handle == NULL)
 		return (char *)g_module_error ();
 
-	/* find the init routine xchat_plugin_init */
-	if (!g_module_symbol (handle, "xchat_plugin_init", (gpointer *)&init_func))
+	/* find the init routine hexchat_plugin_init */
+	if (!g_module_symbol (handle, "hexchat_plugin_init", (gpointer *)&init_func))
 	{
 		g_module_close (handle);
-		return _("No xchat_plugin_init symbol; is this really an xchat plugin?");
+		return _("No hexchat_plugin_init symbol; is this really a HexChat plugin?");
 	}
 
 	/* find the plugin's deinit routine, if any */
-	if (!g_module_symbol (handle, "xchat_plugin_deinit", (gpointer *)&deinit_func))
+	if (!g_module_symbol (handle, "hexchat_plugin_deinit", (gpointer *)&deinit_func))
 		deinit_func = NULL;
 
 #else
@@ -414,17 +415,17 @@ plugin_load (session *sess, char *filename, char *arg)
 		return (char *)dlerror ();
 	dlerror ();		/* Clear any existing error */
 
-	/* find the init routine xchat_plugin_init */
-	init_func = dlsym (handle, "xchat_plugin_init");
+	/* find the init routine hexchat_plugin_init */
+	init_func = dlsym (handle, "hexchat_plugin_init");
 	error = (char *)dlerror ();
 	if (error != NULL)
 	{
 		dlclose (handle);
-		return _("No xchat_plugin_init symbol; is this really an xchat plugin?");
+		return _("No hexchat_plugin_init symbol; is this really a HexChat plugin?");
 	}
 
 	/* find the plugin's deinit routine, if any */
-	deinit_func = dlsym (handle, "xchat_plugin_deinit");
+	deinit_func = dlsym (handle, "hexchat_plugin_deinit");
 	error = (char *)dlerror ();
 #endif
 
@@ -457,48 +458,43 @@ plugin_auto_load_cb (char *filename)
 void
 plugin_auto_load (session *sess)
 {
-	/* let's do it the Perl way */
-	const char *xdir;
 	char *sub_dir;
 	ps = sess;
 
-	xdir = get_xdir_fs ();
-	sub_dir = malloc (strlen (xdir) + 8);
-	strcpy (sub_dir, xdir);
-	strcat (sub_dir, "/addons");
+	sub_dir = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "addons", get_xdir ());
 
 #ifdef WIN32
 	/* a long list of bundled plugins that should be loaded automatically,
 	 * user plugins should go to <config>, leave Program Files alone! */
-	for_files ("./plugins", "hcchecksum.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcdns.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcdoat.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcexec.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcfishlim.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hclua.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcmpcinfo.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcperl.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcpython.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcsasl.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hctcl.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcupd.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcwinamp.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcwinsys.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hcwmpa.dll", plugin_auto_load_cb);
-	for_files ("./plugins", "hextray.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcchecksum.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcdns.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcdoat.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcexec.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcfishlim.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hchextray.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hclua.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcmpcinfo.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcperl.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcpython.dll", plugin_auto_load_cb);
+	/* for_files (".\\plugins", "hcsasl.dll", plugin_auto_load_cb); we have this built-in */
+	for_files (".\\plugins", "hctcl.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcupd.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcwinamp.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcsysinfo.dll", plugin_auto_load_cb);
+	for_files (".\\plugins", "hcwmpa.dll", plugin_auto_load_cb);
 
 	for_files (sub_dir, "*.dll", plugin_auto_load_cb);
 #else
 #if defined(__hpux)
-	for_files (HEXCHATLIBDIR"/plugins", "*.sl", plugin_auto_load_cb);
+	for_files (HEXCHATLIBDIR "/plugins", "*.sl", plugin_auto_load_cb);
 	for_files (sub_dir, "*.sl", plugin_auto_load_cb);
 #else
-	for_files (HEXCHATLIBDIR"/plugins", "*.so", plugin_auto_load_cb);
+	for_files (HEXCHATLIBDIR "/plugins", "*.so", plugin_auto_load_cb);
 	for_files (sub_dir, "*.so", plugin_auto_load_cb);
 #endif
 #endif
 
-	free (sub_dir);
+	g_free (sub_dir);
 }
 
 #endif
@@ -506,7 +502,7 @@ plugin_auto_load (session *sess)
 static GSList *
 plugin_hook_find (GSList *list, int type, char *name)
 {
-	xchat_hook *hook;
+	hexchat_hook *hook;
 
 	while (list)
 	{
@@ -534,7 +530,7 @@ static int
 plugin_hook_run (session *sess, char *name, char *word[], char *word_eol[], int type)
 {
 	GSList *list, *next;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	int ret, eat = 0;
 
 	list = hook_list;
@@ -552,24 +548,24 @@ plugin_hook_run (session *sess, char *name, char *word[], char *word_eol[], int
 		switch (type)
 		{
 		case HOOK_COMMAND:
-			ret = ((xchat_cmd_cb *)hook->callback) (word, word_eol, hook->userdata);
+			ret = ((hexchat_cmd_cb *)hook->callback) (word, word_eol, hook->userdata);
 			break;
 		case HOOK_SERVER:
-			ret = ((xchat_serv_cb *)hook->callback) (word, word_eol, hook->userdata);
+			ret = ((hexchat_serv_cb *)hook->callback) (word, word_eol, hook->userdata);
 			break;
 		default: /*case HOOK_PRINT:*/
-			ret = ((xchat_print_cb *)hook->callback) (word, hook->userdata);
+			ret = ((hexchat_print_cb *)hook->callback) (word, hook->userdata);
 			break;
 		}
 
-		if ((ret & XCHAT_EAT_XCHAT) && (ret & XCHAT_EAT_PLUGIN))
+		if ((ret & HEXCHAT_EAT_HEXCHAT) && (ret & HEXCHAT_EAT_PLUGIN))
 		{
 			eat = 1;
 			goto xit;
 		}
-		if (ret & XCHAT_EAT_PLUGIN)
+		if (ret & HEXCHAT_EAT_PLUGIN)
 			goto xit;	/* stop running plugins */
-		if (ret & XCHAT_EAT_XCHAT)
+		if (ret & HEXCHAT_EAT_HEXCHAT)
 			eat = 1;	/* eventually we'll return 1, but continue running plugins */
 
 		list = next;
@@ -659,7 +655,7 @@ plugin_emit_keypress (session *sess, unsigned int state, unsigned int keyval,
 }
 
 static int
-plugin_timeout_cb (xchat_hook *hook)
+plugin_timeout_cb (hexchat_hook *hook)
 {
 	int ret;
 
@@ -667,7 +663,7 @@ plugin_timeout_cb (xchat_hook *hook)
 	hook->pl->context = current_sess;
 
 	/* call the plugin's timeout function */
-	ret = ((xchat_timer_cb *)hook->callback) (hook->userdata);
+	ret = ((hexchat_timer_cb *)hook->callback) (hook->userdata);
 
 	/* the callback might have already unhooked it! */
 	if (!g_slist_find (hook_list, hook) || hook->type == HOOK_DELETED)
@@ -676,7 +672,7 @@ plugin_timeout_cb (xchat_hook *hook)
 	if (ret == 0)
 	{
 		hook->tag = 0;	/* avoid fe_timeout_remove, returning 0 is enough! */
-		xchat_unhook (hook->pl, hook);
+		hexchat_unhook (hook->pl, hook);
 	}
 
 	return ret;
@@ -685,10 +681,10 @@ plugin_timeout_cb (xchat_hook *hook)
 /* insert a hook into hook_list according to its priority */
 
 static void
-plugin_insert_hook (xchat_hook *new_hook)
+plugin_insert_hook (hexchat_hook *new_hook)
 {
 	GSList *list;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 
 	list = hook_list;
 	while (list)
@@ -706,19 +702,19 @@ plugin_insert_hook (xchat_hook *new_hook)
 }
 
 static gboolean
-plugin_fd_cb (GIOChannel *source, GIOCondition condition, xchat_hook *hook)
+plugin_fd_cb (GIOChannel *source, GIOCondition condition, hexchat_hook *hook)
 {
 	int flags = 0, ret;
-	typedef int (xchat_fd_cb2) (int fd, int flags, void *user_data, GIOChannel *);
+	typedef int (hexchat_fd_cb2) (int fd, int flags, void *user_data, GIOChannel *);
 
 	if (condition & G_IO_IN)
-		flags |= XCHAT_FD_READ;
+		flags |= HEXCHAT_FD_READ;
 	if (condition & G_IO_OUT)
-		flags |= XCHAT_FD_WRITE;
+		flags |= HEXCHAT_FD_WRITE;
 	if (condition & G_IO_PRI)
-		flags |= XCHAT_FD_EXCEPTION;
+		flags |= HEXCHAT_FD_EXCEPTION;
 
-	ret = ((xchat_fd_cb2 *)hook->callback) (hook->pri, flags, hook->userdata, source);
+	ret = ((hexchat_fd_cb2 *)hook->callback) (hook->pri, flags, hook->userdata, source);
 
 	/* the callback might have already unhooked it! */
 	if (!g_slist_find (hook_list, hook) || hook->type == HOOK_DELETED)
@@ -727,7 +723,7 @@ plugin_fd_cb (GIOChannel *source, GIOCondition condition, xchat_hook *hook)
 	if (ret == 0)
 	{
 		hook->tag = 0; /* avoid fe_input_remove, returning 0 is enough! */
-		xchat_unhook (hook->pl, hook);
+		hexchat_unhook (hook->pl, hook);
 	}
 
 	return ret;
@@ -735,14 +731,14 @@ plugin_fd_cb (GIOChannel *source, GIOCondition condition, xchat_hook *hook)
 
 /* allocate and add a hook to our list. Used for all 4 types */
 
-static xchat_hook *
-plugin_add_hook (xchat_plugin *pl, int type, int pri, const char *name,
+static hexchat_hook *
+plugin_add_hook (hexchat_plugin *pl, int type, int pri, const char *name,
 					  const  char *help_text, void *callb, int timeout, void *userdata)
 {
-	xchat_hook *hook;
+	hexchat_hook *hook;
 
-	hook = malloc (sizeof (xchat_hook));
-	memset (hook, 0, sizeof (xchat_hook));
+	hook = malloc (sizeof (hexchat_hook));
+	memset (hook, 0, sizeof (hexchat_hook));
 
 	hook->type = type;
 	hook->pri = pri;
@@ -766,7 +762,7 @@ plugin_add_hook (xchat_plugin *pl, int type, int pri, const char *name,
 GList *
 plugin_command_list(GList *tmp_list)
 {
-	xchat_hook *hook;
+	hexchat_hook *hook;
 	GSList *list = hook_list;
 
 	while (list)
@@ -784,7 +780,7 @@ plugin_command_foreach (session *sess, void *userdata,
 			void (*cb) (session *sess, void *userdata, char *name, char *help))
 {
 	GSList *list;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 
 	list = hook_list;
 	while (list)
@@ -802,7 +798,7 @@ int
 plugin_show_help (session *sess, char *cmd)
 {
 	GSList *list;
-	xchat_hook *hook;
+	hexchat_hook *hook;
 
 	list = plugin_hook_find (hook_list, HOOK_COMMAND, cmd);
 	if (list)
@@ -823,7 +819,7 @@ plugin_show_help (session *sess, char *cmd)
 /* ========================================================= */
 
 void *
-xchat_unhook (xchat_plugin *ph, xchat_hook *hook)
+hexchat_unhook (hexchat_plugin *ph, hexchat_hook *hook)
 {
 	/* perl.c trips this */
 	if (!g_slist_find (hook_list, hook) || hook->type == HOOK_DELETED)
@@ -845,40 +841,40 @@ xchat_unhook (xchat_plugin *ph, xchat_hook *hook)
 	return hook->userdata;
 }
 
-xchat_hook *
-xchat_hook_command (xchat_plugin *ph, const char *name, int pri,
-						  xchat_cmd_cb *callb, const char *help_text, void *userdata)
+hexchat_hook *
+hexchat_hook_command (hexchat_plugin *ph, const char *name, int pri,
+						  hexchat_cmd_cb *callb, const char *help_text, void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_COMMAND, pri, name, help_text, callb, 0,
 									userdata);
 }
 
-xchat_hook *
-xchat_hook_server (xchat_plugin *ph, const char *name, int pri,
-						 xchat_serv_cb *callb, void *userdata)
+hexchat_hook *
+hexchat_hook_server (hexchat_plugin *ph, const char *name, int pri,
+						 hexchat_serv_cb *callb, void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_SERVER, pri, name, 0, callb, 0, userdata);
 }
 
-xchat_hook *
-xchat_hook_print (xchat_plugin *ph, const char *name, int pri,
-						xchat_print_cb *callb, void *userdata)
+hexchat_hook *
+hexchat_hook_print (hexchat_plugin *ph, const char *name, int pri,
+						hexchat_print_cb *callb, void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_PRINT, pri, name, 0, callb, 0, userdata);
 }
 
-xchat_hook *
-xchat_hook_timer (xchat_plugin *ph, int timeout, xchat_timer_cb *callb,
+hexchat_hook *
+hexchat_hook_timer (hexchat_plugin *ph, int timeout, hexchat_timer_cb *callb,
 					   void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_TIMER, 0, 0, 0, callb, timeout, userdata);
 }
 
-xchat_hook *
-xchat_hook_fd (xchat_plugin *ph, int fd, int flags,
-					xchat_fd_cb *callb, void *userdata)
+hexchat_hook *
+hexchat_hook_fd (hexchat_plugin *ph, int fd, int flags,
+					hexchat_fd_cb *callb, void *userdata)
 {
-	xchat_hook *hook;
+	hexchat_hook *hook;
 
 	hook = plugin_add_hook (ph, HOOK_FD, 0, 0, 0, callb, 0, userdata);
 	hook->pri = fd;
@@ -889,11 +885,11 @@ xchat_hook_fd (xchat_plugin *ph, int fd, int flags,
 }
 
 void
-xchat_print (xchat_plugin *ph, const char *text)
+hexchat_print (hexchat_plugin *ph, const char *text)
 {
 	if (!is_session (ph->context))
 	{
-		DEBUG(PrintTextf(0, "%s\txchat_print called without a valid context.\n", ph->name));
+		DEBUG(PrintTextf(0, "%s\thexchat_print called without a valid context.\n", ph->name));
 		return;
 	}
 
@@ -901,7 +897,7 @@ xchat_print (xchat_plugin *ph, const char *text)
 }
 
 void
-xchat_printf (xchat_plugin *ph, const char *format, ...)
+hexchat_printf (hexchat_plugin *ph, const char *format, ...)
 {
 	va_list args;
 	char *buf;
@@ -910,19 +906,19 @@ xchat_printf (xchat_plugin *ph, const char *format, ...)
 	buf = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	xchat_print (ph, buf);
+	hexchat_print (ph, buf);
 	g_free (buf);
 }
 
 void
-xchat_command (xchat_plugin *ph, const char *command)
+hexchat_command (hexchat_plugin *ph, const char *command)
 {
 	char *conv;
 	int len = -1;
 
 	if (!is_session (ph->context))
 	{
-		DEBUG(PrintTextf(0, "%s\txchat_command called without a valid context.\n", ph->name));
+		DEBUG(PrintTextf(0, "%s\thexchat_command called without a valid context.\n", ph->name));
 		return;
 	}
 
@@ -933,7 +929,7 @@ xchat_command (xchat_plugin *ph, const char *command)
 }
 
 void
-xchat_commandf (xchat_plugin *ph, const char *format, ...)
+hexchat_commandf (hexchat_plugin *ph, const char *format, ...)
 {
 	va_list args;
 	char *buf;
@@ -942,24 +938,24 @@ xchat_commandf (xchat_plugin *ph, const char *format, ...)
 	buf = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	xchat_command (ph, buf);
+	hexchat_command (ph, buf);
 	g_free (buf);
 }
 
 int
-xchat_nickcmp (xchat_plugin *ph, const char *s1, const char *s2)
+hexchat_nickcmp (hexchat_plugin *ph, const char *s1, const char *s2)
 {
 	return ((session *)ph->context)->server->p_cmp (s1, s2);
 }
 
-xchat_context *
-xchat_get_context (xchat_plugin *ph)
+hexchat_context *
+hexchat_get_context (hexchat_plugin *ph)
 {
 	return ph->context;
 }
 
 int
-xchat_set_context (xchat_plugin *ph, xchat_context *context)
+hexchat_set_context (hexchat_plugin *ph, hexchat_context *context)
 {
 	if (is_session (context))
 	{
@@ -969,8 +965,8 @@ xchat_set_context (xchat_plugin *ph, xchat_context *context)
 	return 0;
 }
 
-xchat_context *
-xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
+hexchat_context *
+hexchat_find_context (hexchat_plugin *ph, const char *servname, const char *channel)
 {
 	GSList *slist, *clist, *sessions = NULL;
 	server *serv;
@@ -1030,7 +1026,7 @@ xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 }
 
 const char *
-xchat_get_info (xchat_plugin *ph, const char *id)
+hexchat_get_info (hexchat_plugin *ph, const char *id)
 {
 	session *sess;
 	guint32 hash;
@@ -1047,23 +1043,22 @@ xchat_get_info (xchat_plugin *ph, const char *id)
 	/* do the session independant ones first */
 	switch (hash)
 	{
-	case 0x325acab5:	/* libdirfs */
-		return HEXCHATLIBDIR;
+		case 0x325acab5:	/* libdirfs */
+			return HEXCHATLIBDIR;
 
-	case 0x14f51cd8: /* version */
-		return PACKAGE_VERSION;
+		case 0x14f51cd8: /* version */
+			return PACKAGE_VERSION;
 
-	case 0xdd9b1abd:	/* xchatdir */
-		return get_xdir_utf8 ();
-
-	case 0xe33f6c4a:	/* xchatdirfs */
-		return get_xdir_fs ();
+		case 0xdd9b1abd:	/* xchatdir */
+		case 0xe33f6c4a:	/* xchatdirfs */
+		case 0xd00d220b:	/* configdir */
+			return get_xdir ();
 	}
 
 	sess = ph->context;
 	if (!is_session (sess))
 	{
-		DEBUG(PrintTextf(0, "%s\txchat_get_info called without a valid context.\n", ph->name));
+		DEBUG(PrintTextf(0, "%s\thexchat_get_info called without a valid context.\n", ph->name));
 		return NULL;
 	}
 
@@ -1137,7 +1132,7 @@ xchat_get_info (xchat_plugin *ph, const char *id)
 }
 
 int
-xchat_get_prefs (xchat_plugin *ph, const char *name, const char **string, int *integer)
+hexchat_get_prefs (hexchat_plugin *ph, const char *name, const char **string, int *integer)
 {
 	int i = 0;
 
@@ -1183,12 +1178,12 @@ xchat_get_prefs (xchat_plugin *ph, const char *name, const char **string, int *i
 	return 0;
 }
 
-xchat_list *
-xchat_list_get (xchat_plugin *ph, const char *name)
+hexchat_list *
+hexchat_list_get (hexchat_plugin *ph, const char *name)
 {
-	xchat_list *list;
+	hexchat_list *list;
 
-	list = malloc (sizeof (xchat_list));
+	list = malloc (sizeof (hexchat_list));
 	list->pos = NULL;
 
 	switch (str_hash (name))
@@ -1232,7 +1227,7 @@ xchat_list_get (xchat_plugin *ph, const char *name)
 }
 
 void
-xchat_list_free (xchat_plugin *ph, xchat_list *xlist)
+hexchat_list_free (hexchat_plugin *ph, hexchat_list *xlist)
 {
 	if (xlist->type == LIST_USERS)
 		g_slist_free (xlist->head);
@@ -1240,7 +1235,7 @@ xchat_list_free (xchat_plugin *ph, xchat_list *xlist)
 }
 
 int
-xchat_list_next (xchat_plugin *ph, xchat_list *xlist)
+hexchat_list_next (hexchat_plugin *ph, hexchat_list *xlist)
 {
 	if (xlist->next == NULL)
 		return 0;
@@ -1262,7 +1257,7 @@ xchat_list_next (xchat_plugin *ph, xchat_list *xlist)
 }
 
 const char * const *
-xchat_list_fields (xchat_plugin *ph, const char *name)
+hexchat_list_fields (hexchat_plugin *ph, const char *name)
 {
 	static const char * const dcc_fields[] =
 	{
@@ -1312,7 +1307,7 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 }
 
 time_t
-xchat_list_time (xchat_plugin *ph, xchat_list *xlist, const char *name)
+hexchat_list_time (hexchat_plugin *ph, hexchat_list *xlist, const char *name)
 {
 	guint32 hash = str_hash (name);
 	gpointer data;
@@ -1346,7 +1341,7 @@ xchat_list_time (xchat_plugin *ph, xchat_list *xlist, const char *name)
 }
 
 const char *
-xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
+hexchat_list_str (hexchat_plugin *ph, hexchat_list *xlist, const char *name)
 {
 	guint32 hash = str_hash (name);
 	gpointer data = ph->context;
@@ -1430,7 +1425,7 @@ xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
 }
 
 int
-xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
+hexchat_list_int (hexchat_plugin *ph, hexchat_list *xlist, const char *name)
 {
 	guint32 hash = str_hash (name);
 	gpointer data = ph->context;
@@ -1547,7 +1542,7 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 }
 
 void *
-xchat_plugingui_add (xchat_plugin *ph, const char *filename,
+hexchat_plugingui_add (hexchat_plugin *ph, const char *filename,
 							const char *name, const char *desc,
 							const char *version, char *reserved)
 {
@@ -1561,7 +1556,7 @@ xchat_plugingui_add (xchat_plugin *ph, const char *filename,
 }
 
 void
-xchat_plugingui_remove (xchat_plugin *ph, void *handle)
+hexchat_plugingui_remove (hexchat_plugin *ph, void *handle)
 {
 #ifdef USE_PLUGIN
 	plugin_free (handle, FALSE, FALSE);
@@ -1569,7 +1564,7 @@ xchat_plugingui_remove (xchat_plugin *ph, void *handle)
 }
 
 int
-xchat_emit_print (xchat_plugin *ph, const char *event_name, ...)
+hexchat_emit_print (hexchat_plugin *ph, const char *event_name, ...)
 {
 	va_list args;
 	/* currently only 4 because no events use more than 4.
@@ -1596,15 +1591,15 @@ xchat_emit_print (xchat_plugin *ph, const char *event_name, ...)
 }
 
 char *
-xchat_gettext (xchat_plugin *ph, const char *msgid)
+hexchat_gettext (hexchat_plugin *ph, const char *msgid)
 {
-	/* so that plugins can use xchat's internal gettext strings. */
+	/* so that plugins can use HexChat's internal gettext strings. */
 	/* e.g. The EXEC plugin uses this on Windows. */
 	return _(msgid);
 }
 
 void
-xchat_send_modes (xchat_plugin *ph, const char **targets, int ntargets, int modes_per_line, char sign, char mode)
+hexchat_send_modes (hexchat_plugin *ph, const char **targets, int ntargets, int modes_per_line, char sign, char mode)
 {
 	char tbuf[514];	/* modes.c needs 512 + null */
 
@@ -1612,63 +1607,73 @@ xchat_send_modes (xchat_plugin *ph, const char **targets, int ntargets, int mode
 }
 
 char *
-xchat_strip (xchat_plugin *ph, const char *str, int len, int flags)
+hexchat_strip (hexchat_plugin *ph, const char *str, int len, int flags)
 {
 	return strip_color ((char *)str, len, flags);
 }
 
 void
-xchat_free (xchat_plugin *ph, void *ptr)
+hexchat_free (hexchat_plugin *ph, void *ptr)
 {
 	g_free (ptr);
 }
 
 static int
-xchat_pluginpref_set_str_real (xchat_plugin *pl, const char *var, const char *value, int mode) /* mode: 0 = delete, 1 = save */
+hexchat_pluginpref_set_str_real (hexchat_plugin *pl, const char *var, const char *value, int mode) /* mode: 0 = delete, 1 = save */
 {
 	FILE *fpIn;
 	int fhOut;
 	int prevSetting;
-	char confname[64];
-	char confname_tmp[69];
-	char buffer[512];		/* the same as in cfg_put_str */
-	char buffer_tmp[512];
+	char *confname;
+	char *confname_tmp;
+	char *buffer;
+	char *buffer_tmp;
+	char line_buffer[512];		/* the same as in cfg_put_str */
 	char *canon;
 
 	canon = g_strdup (pl->name);
 	canonalize_key (canon);
-	sprintf (confname, "addon_%s.conf", canon);
+	confname = g_strdup_printf ("addon_%s.conf", canon);
 	g_free (canon);
-	sprintf (confname_tmp, "%s.new", confname);
+	confname_tmp = g_strdup_printf ("%s.new", confname);
 
-	fhOut = xchat_open_file (confname_tmp, O_TRUNC | O_WRONLY | O_CREAT, 0600, XOF_DOMODE);
-	fpIn = xchat_fopen_file (confname, "r", 0);
+	fhOut = hexchat_open_file (confname_tmp, O_TRUNC | O_WRONLY | O_CREAT, 0600, XOF_DOMODE);
+	fpIn = hexchat_fopen_file (confname, "r", 0);
 
 	if (fhOut == -1)		/* unable to save, abort */
 	{
+		g_free (confname);
+		g_free (confname_tmp);
 		return 0;
 	}
 	else if (fpIn == NULL)	/* no previous config file, no parsing */
 	{
 		if (mode)
 		{
-			sprintf (buffer, "%s = %s\n", var, value);
+			buffer = g_strdup_printf ("%s = %s\n", var, value);
 			write (fhOut, buffer, strlen (buffer));
+			g_free (buffer);
 			close (fhOut);
 
-			sprintf (buffer, "%s/%s", get_xdir_fs (), confname);
-			sprintf (buffer_tmp, "%s/%s", get_xdir_fs (), confname_tmp);
+			buffer = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", get_xdir (), confname);
+			g_free (confname);
+			buffer_tmp = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", get_xdir (), confname_tmp);
+			g_free (confname_tmp);
 
 #ifdef WIN32
-			unlink (buffer);
+			g_unlink (buffer);
 #endif
 
-			if (rename (buffer_tmp, buffer) == 0)
+			if (g_rename (buffer_tmp, buffer) == 0)
 			{
+				g_free (buffer);
+				g_free (buffer_tmp);
 				return 1;
 			}
 			else
 			{
+				g_free (buffer);
+				g_free (buffer_tmp);
 				return 0;
 			}
 		}
@@ -1676,6 +1681,8 @@ xchat_pluginpref_set_str_real (xchat_plugin *pl, const char *var, const char *va
 		{
 			/* mode = 0, we want to delete but the config file and thus the given setting does not exist, we're ready */
 			close (fhOut);
+			g_free (confname);
+			g_free (confname_tmp);
 			return 1;
 		}
 	}
@@ -1683,67 +1690,77 @@ xchat_pluginpref_set_str_real (xchat_plugin *pl, const char *var, const char *va
 	{
 		prevSetting = 0;
 
-		while (fscanf (fpIn, " %[^\n]", &buffer) != EOF)	/* read whole lines including whitespaces */
+		while (fscanf (fpIn, " %[^\n]", &line_buffer) != EOF)	/* read whole lines including whitespaces */
 		{
-			sprintf (buffer_tmp, "%s ", var);				/* add one space, this way it works against var - var2 checks too */
+			buffer_tmp = g_strdup_printf ("%s ", var);	/* add one space, this way it works against var - var2 checks too */
 
-			if (strncmp (buffer_tmp, buffer, strlen (var) + 1) == 0)	/* given setting already exists */
+			if (strncmp (buffer_tmp, line_buffer, strlen (var) + 1) == 0)	/* given setting already exists */
 			{
 				if (mode)									/* overwrite the existing matching setting if we are in save mode */
 				{
-					sprintf (buffer, "%s = %s\n", var, value);
+					buffer = g_strdup_printf ("%s = %s\n", var, value);
 				}
 				else										/* erase the setting in delete mode */
 				{
-					strcpy (buffer, "");
+					buffer = g_strdup ("");
 				}
 
 				prevSetting = 1;
 			}
 			else
 			{
-				strcat (buffer, "\n");						/* preserve the existing different settings */
+				buffer = g_strdup_printf ("%s\n", line_buffer);	/* preserve the existing different settings */
 			}
 
 			write (fhOut, buffer, strlen (buffer));
+
+			g_free (buffer);
+			g_free (buffer_tmp);
 		}
 
 		fclose (fpIn);
 
 		if (!prevSetting && mode)	/* var doesn't exist currently, append if we're in save mode */
 		{
-			sprintf (buffer, "%s = %s\n", var, value);
+			buffer = g_strdup_printf ("%s = %s\n", var, value);
 			write (fhOut, buffer, strlen (buffer));
+			g_free (buffer);
 		}
 
 		close (fhOut);
 
-		sprintf (buffer, "%s/%s", get_xdir_fs (), confname);
-		sprintf (buffer_tmp, "%s/%s", get_xdir_fs (), confname_tmp);
+		buffer = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", get_xdir (), confname);
+		g_free (confname);
+		buffer_tmp = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", get_xdir (), confname_tmp);
+		g_free (confname_tmp);
 
 #ifdef WIN32
-		unlink (buffer);
+		g_unlink (buffer);
 #endif
 
-		if (rename (buffer_tmp, buffer) == 0)
+		if (g_rename (buffer_tmp, buffer) == 0)
 		{
+			g_free (buffer);
+			g_free (buffer_tmp);
 			return 1;
 		}
 		else
 		{
+			g_free (buffer);
+			g_free (buffer_tmp);
 			return 0;
 		}
 	}
 }
 
 int
-xchat_pluginpref_set_str (xchat_plugin *pl, const char *var, const char *value)
+hexchat_pluginpref_set_str (hexchat_plugin *pl, const char *var, const char *value)
 {
-	return xchat_pluginpref_set_str_real (pl, var, value, 1);
+	return hexchat_pluginpref_set_str_real (pl, var, value, 1);
 }
 
 int
-xchat_pluginpref_get_str (xchat_plugin *pl, const char *var, char *dest)
+hexchat_pluginpref_get_str (hexchat_plugin *pl, const char *var, char *dest)
 {
 	int fh;
 	int l;
@@ -1758,7 +1775,7 @@ xchat_pluginpref_get_str (xchat_plugin *pl, const char *var, char *dest)
 	g_free (canon);
 
 	/* partly borrowed from palette.c */
-	fh = xchat_open_file (confname, O_RDONLY, 0, 0);
+	fh = hexchat_open_file (confname, O_RDONLY, 0, 0);
 
 	if (fh == -1)
 	{
@@ -1795,20 +1812,20 @@ xchat_pluginpref_get_str (xchat_plugin *pl, const char *var, char *dest)
 }
 
 int
-xchat_pluginpref_set_int (xchat_plugin *pl, const char *var, int value)
+hexchat_pluginpref_set_int (hexchat_plugin *pl, const char *var, int value)
 {
 	char buffer[12];
 
 	sprintf (buffer, "%d", value);
-	return xchat_pluginpref_set_str_real (pl, var, buffer, 1);
+	return hexchat_pluginpref_set_str_real (pl, var, buffer, 1);
 }
 
 int
-xchat_pluginpref_get_int (xchat_plugin *pl, const char *var)
+hexchat_pluginpref_get_int (hexchat_plugin *pl, const char *var)
 {
 	char buffer[12];
 
-	if (xchat_pluginpref_get_str (pl, var, buffer))
+	if (hexchat_pluginpref_get_str (pl, var, buffer))
 	{
 		return atoi (buffer);
 	}
@@ -1819,13 +1836,13 @@ xchat_pluginpref_get_int (xchat_plugin *pl, const char *var)
 }
 
 int
-xchat_pluginpref_delete (xchat_plugin *pl, const char *var)
+hexchat_pluginpref_delete (hexchat_plugin *pl, const char *var)
 {
-	return xchat_pluginpref_set_str_real (pl, var, 0, 0);
+	return hexchat_pluginpref_set_str_real (pl, var, 0, 0);
 }
 
 int
-xchat_pluginpref_list (xchat_plugin *pl, char* dest)
+hexchat_pluginpref_list (hexchat_plugin *pl, char* dest)
 {
 	FILE *fpIn;
 	char confname[64];
@@ -1837,7 +1854,7 @@ xchat_pluginpref_list (xchat_plugin *pl, char* dest)
 	sprintf (confname, "addon_%s.conf", token);
 	g_free (token);
 
-	fpIn = xchat_fopen_file (confname, "r", 0);
+	fpIn = hexchat_fopen_file (confname, "r", 0);
 
 	if (fpIn == NULL)										/* no existing config file, no parsing */
 	{
