@@ -28,7 +28,7 @@
 #include <unistd.h>
 #endif
 
-#include "xchat.h"
+#include "hexchat.h"
 #include "ctcp.h"
 #include "fe.h"
 #include "ignore.h"
@@ -40,14 +40,19 @@
 #include "text.h"
 #include "outbound.h"
 #include "util.h"
-#include "xchatc.h"
+#include "hexchatc.h"
+#include "url.h"
 
 
 static void
 irc_login (server *serv, char *user, char *realname)
 {
+	tcp_sendf (serv, "CAP LS\r\n");		/* start with CAP LS as Charybdis sasl.txt suggests */
+
 	if (serv->password[0])
+	{
 		tcp_sendf (serv, "PASS %s\r\n", serv->password);
+	}
 
 	tcp_sendf (serv,
 				  "NICK %s\r\n"
@@ -455,7 +460,7 @@ process_numeric (session * sess, int n,
 	session *whois_sess = serv->server_session;
 
 	/* unless this setting is on */
-	if (prefs.irc_whois_front)
+	if (prefs.hex_irc_whois_front)
 		whois_sess = serv->front_session;
 
 	switch (n)
@@ -470,7 +475,7 @@ process_numeric (session * sess, int n,
 			(strrchr(word[10], '@') != NULL))
 		{
 			serv->use_who = FALSE;
-			if (prefs.ip_from_server)
+			if (prefs.hex_dcc_ip_from_server)
 				inbound_foundip (sess, strrchr(word[10], '@')+1);
 		}
 
@@ -509,7 +514,7 @@ process_numeric (session * sess, int n,
 		if (fe_is_chanwindow (sess->server))
 		{
 			fe_chan_list_end (sess->server);
-			fe_message (word_eol[5] + 1, FE_MSG_ERROR);
+			fe_message (word_eol[4] + 1, FE_MSG_ERROR);
 		}
 		goto def;
 
@@ -824,7 +829,7 @@ process_numeric (session * sess, int n,
 
 	case 372:	/* motd text */
 	case 375:	/* motd start */
-		if (!prefs.skipmotd || serv->motd_skipped)
+		if (!prefs.hex_irc_skip_motd || serv->motd_skipped)
 			EMIT_SIGNAL (XP_TE_MOTD, serv->server_session, text, NULL, NULL,
 							 NULL, 0);
 		break;
@@ -876,6 +881,15 @@ process_numeric (session * sess, int n,
 		notify_set_online (serv, word[4]);
 		break;
 
+	case 903:	/* successful SASL auth */
+	case 904:	/* aborted SASL auth */
+	case 905:	/* failed SASL auth */
+	case 906:	/* registration completes before SASL auth */
+	case 907:	/* attempting to re-auth after a successful auth */
+		EMIT_SIGNAL (XP_TE_SASLRESPONSE, serv->server_session, word[1], word[2], word[3], ++word_eol[4], 0);
+		tcp_send_len (serv, "CAP END\r\n", 9);
+		break;
+
 	default:
 
 		if (serv->inside_whois && word[4][0])
@@ -1113,6 +1127,87 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[])
 		}
 	}
 
+	else if (len == 3)
+	{
+		guint32 t;
+		guint32 want_cap;		/* format the CAP REQ string based on previous capabilities being requested or not */
+		guint32 want_sasl;		/* CAP END shouldn't be sent when SASL is requested, it needs further responses */
+		char *pass;				/* buffer for SASL password */
+		char buffer[256];		/* buffer for requesting capabilities and emitting the signal */
+
+		t = WORDL((guint8)type[0], (guint8)type[1], (guint8)type[2], (guint8)type[3]);
+		switch (t)
+		{
+			case WORDL('C','A','P','\0'):
+				if (strncasecmp (word[4], "ACK", 3) == 0)
+				{
+					EMIT_SIGNAL (XP_TE_CAPACK, sess->server->server_session, word[1], word[5][0]==':' ? ++word_eol[5] : word_eol[5], NULL, NULL, 0);
+
+					if (strstr (word_eol[5], "identify-msg") != 0)
+					{
+						serv->have_idmsg = TRUE;
+					}
+
+					if (strstr (word_eol[5], "multi-prefix") != 0)
+					{
+						serv->have_namesx = TRUE;
+					}
+
+					if (strstr (word_eol[5], "sasl") != 0)
+					{
+						serv->have_sasl = TRUE;
+						EMIT_SIGNAL (XP_TE_SASLAUTH, serv->server_session, sess->server->sasluser, NULL, NULL, NULL, 0);
+						tcp_send_len (serv, "AUTHENTICATE PLAIN\r\n", 20);
+
+						pass = encode_sasl_pass (sess->server->sasluser, sess->server->saslpassword);
+						tcp_sendf (sess->server, "AUTHENTICATE %s\r\n", pass);
+						free (pass);
+					}
+				}
+				else if (strncasecmp (word[4], "LS", 2) == 0)
+				{
+					EMIT_SIGNAL (XP_TE_CAPLIST, serv->server_session, word[1], word[5][0]==':' ? ++word_eol[5] : word_eol[5], NULL, NULL, 0);
+					want_cap = 0;
+					want_sasl = 0;
+
+					if (strstr (word_eol[5], "identify-msg") != 0)
+					{
+						strcpy (buffer, "CAP REQ :identify-msg");
+						want_cap = 1;
+					}
+					if (strstr (word_eol[5], "multi-prefix") != 0)
+					{
+						want_cap ? strcat (buffer, " multi-prefix") : strcpy (buffer, "CAP REQ :multi-prefix");
+						want_cap = 1;
+					}
+					/* if the SASL password is set, request SASL auth */
+					if (strstr (word_eol[5], "sasl") != 0 && strlen (sess->server->saslpassword) != 0)
+					{
+						want_cap ? strcat (buffer, " sasl") : strcpy (buffer, "CAP REQ :sasl");
+						want_sasl = 1;
+					}
+
+					if (want_cap)
+					{
+						/* buffer + 9 = emit buffer without "CAP REQ :" */
+						EMIT_SIGNAL (XP_TE_CAPREQ, sess->server->server_session, buffer + 9, NULL, NULL, NULL, 0);
+						tcp_sendf (serv, "%s\r\n", buffer);
+					}
+					if (!want_sasl)
+					{
+						/* if we use SASL, CAP END is dealt via raw numerics */
+						tcp_send_len (serv, "CAP END\r\n", 9);
+					}
+				}
+				else if (strncasecmp (word[4], "NAK", 3) == 0)
+				{
+					tcp_send_len (serv, "CAP END\r\n", 9);
+				}
+
+				return;
+		}
+	}
+
 garbage:
 	/* unknown message */
 	PrintTextf (sess, "GARBAGE: %s\n", word_eol[1]);
@@ -1143,6 +1238,10 @@ process_named_servermsg (session *sess, char *buf, char *rawname, char *word_eol
 		EMIT_SIGNAL (XP_TE_SERVNOTICE, sess, buf, sess->server->servername, NULL, NULL, 0);
 		return;
 	}
+	if (!strncmp (buf, "AUTHENTICATE +", 14))	/* omit SASL "empty" responses */
+	{
+		return;
+	}
 
 	EMIT_SIGNAL (XP_TE_SERVTEXT, sess, buf, sess->server->servername, rawname, NULL, 0);
 }
@@ -1192,7 +1291,7 @@ irc_inline (server *serv, char *buf, int len)
 		if (plugin_emit_server (sess, type, word, word_eol))
 			goto xit;
 		word[1]++;
-		word_eol[1] = buf + 1;	/* but not for xchat internally */
+		word_eol[1] = buf + 1;	/* but not for HexChat internally */
 
 	} else
 	{
