@@ -26,7 +26,7 @@
 #include <unistd.h>
 #endif
 
-#include "xchat.h"
+#include "hexchat.h"
 #include <glib.h>
 
 #include "cfgfiles.h"
@@ -34,7 +34,7 @@
 #include "server.h"
 #include "text.h"
 #include "util.h" /* token_foreach */
-#include "xchatc.h"
+#include "hexchatc.h"
 
 #include "servlist.h"
 
@@ -516,6 +516,12 @@ static const struct defaultserver def[] =
 	{0,			"tahoma.starchat.net"},
 	{0,			"neo.starchat.net"},
 
+	{"SwiftIRC", 0},
+#ifdef USE_OPENSSL
+	{0,			"irc.swiftirc.net/+6697"},
+#endif
+	{0,			"irc.swiftirc.net/6667"},
+
 /*	{"TNI3",			0},
 	{0,			"irc.tni3.com"},*/
 
@@ -602,13 +608,33 @@ servlist_connect (session *sess, ircnet *net, gboolean join)
 	}
 
 	serv->password[0] = 0;
+	serv->sasluser[0] = 0;
+	serv->saslpassword[0] = 0;
+
 	if (net->pass)
+	{
 		safe_strcpy (serv->password, net->pass, sizeof (serv->password));
+	}
 
 	if (net->flags & FLAG_USE_GLOBAL)
 	{
-		strcpy (serv->nick, prefs.nick1);
-	} else
+		strcpy (serv->sasluser, prefs.hex_irc_user_name);
+	}
+	else if (net->user != NULL)
+	{
+		safe_strcpy (serv->sasluser, net->user, sizeof (serv->sasluser));
+	}
+
+	if (net->saslpass)
+	{
+		safe_strcpy (serv->saslpassword, net->saslpass, sizeof (serv->saslpassword));
+	}
+
+	if (net->flags & FLAG_USE_GLOBAL)
+	{
+		strcpy (serv->nick, prefs.hex_irc_nick1);
+	}
+	else
 	{
 		if (net->nick)
 			strcpy (serv->nick, net->nick);
@@ -745,7 +771,7 @@ servlist_cycle (server *serv)
 					net->selected = 0;
 			}
 
-			del = prefs.recon_delay * 1000;
+			del = prefs.hex_net_reconnect_delay * 1000;
 			if (del < 1000)
 				del = 500;				  /* so it doesn't block the gui */
 
@@ -895,6 +921,7 @@ servlist_cleanup (void)
 	{
 		net = list->data;
 		free_and_clear (net->pass);
+		free_and_clear (net->saslpass);
 		free_and_clear (net->nickserv);
 	}
 }
@@ -917,6 +944,7 @@ servlist_net_remove (ircnet *net)
 	if (net->real)
 		free (net->real);
 	free_and_clear (net->pass);
+	free_and_clear (net->saslpass);
 	if (net->autojoin)
 		free (net->autojoin);
 	if (net->command)
@@ -964,6 +992,7 @@ servlist_load_defaults (void)
 {
 	int i = 0, j = 0;
 	ircnet *net = NULL;
+	guint def_hash = g_str_hash ("freenode");
 
 	while (1)
 	{
@@ -972,21 +1001,27 @@ servlist_load_defaults (void)
 			net = servlist_net_add (def[i].network, def[i].host, FALSE);
 			net->encoding = strdup (IRC_DEFAULT_CHARSET);
 			if (def[i].channel)
+			{
 				net->autojoin = strdup (def[i].channel);
+			}
 			if (def[i].charset)
 			{
 				free (net->encoding);
 				net->encoding = strdup (def[i].charset);
 			}
-			/* 0x8e1b96f7 = ChatJunkies, 0xa82686ae = FreeNode */
-			if (g_str_hash (def[i].network) == 0xa82686ae)
-				prefs.slist_select = j;
+			if (g_str_hash (def[i].network) == def_hash)
+			{
+				prefs.hex_gui_slist_select = j;
+			}
 			j++;
-		} else
+		}
+		else
 		{
 			servlist_server_add (net, def[i].host);
 			if (!def[i+1].host && !def[i+1].network)
+			{
 				break;
+			}
 		}
 		i++;
 	}
@@ -1001,7 +1036,7 @@ servlist_load (void)
 	char *tmp;
 	ircnet *net = NULL;
 
-	fp = xchat_fopen_file ("servlist_.conf", "r", 0);
+	fp = hexchat_fopen_file ("servlist_.conf", "r", 0);
 	if (!fp)
 		return FALSE;
 
@@ -1029,6 +1064,9 @@ servlist_load (void)
 			case 'P':
 				net->pass = strdup (buf + 2);
 				break;
+			case 'A':
+				net->saslpass = strdup (buf + 2);
+				break;
 			case 'J':
 				net->autojoin = strdup (buf + 2);
 				break;
@@ -1121,7 +1159,7 @@ int
 servlist_save (void)
 {
 	FILE *fp;
-	char buf[256];
+	char *buf;
 	ircnet *net;
 	ircserver *serv;
 	GSList *list;
@@ -1129,20 +1167,27 @@ servlist_save (void)
 #ifndef WIN32
 	int first = FALSE;
 
-	snprintf (buf, sizeof (buf), "%s/servlist_.conf", get_xdir_fs ());
-	if (access (buf, F_OK) != 0)
+	buf = g_strdup_printf ("%s/servlist_.conf", get_xdir ());
+	if (g_access (buf, F_OK) != 0)
 		first = TRUE;
 #endif
 
-	fp = xchat_fopen_file ("servlist_.conf", "w", 0);
+	fp = hexchat_fopen_file ("servlist_.conf", "w", 0);
 	if (!fp)
+	{
+#ifndef WIN32
+		g_free (buf);
+#endif
 		return FALSE;
+	}
 
 #ifndef WIN32
 	if (first)
-		chmod (buf, 0600);
+		g_chmod (buf, 0600);
+
+	g_free (buf);
 #endif
-	fprintf (fp, "v="PACKAGE_VERSION"\n\n");
+	fprintf (fp, "v=" PACKAGE_VERSION "\n\n");
 
 	list = network_list;
 	while (list)
@@ -1160,6 +1205,8 @@ servlist_save (void)
 			fprintf (fp, "R=%s\n", net->real);
 		if (net->pass)
 			fprintf (fp, "P=%s\n", net->pass);
+		if (net->saslpass)
+			fprintf (fp, "A=%s\n", net->saslpass);
 		if (net->autojoin)
 			fprintf (fp, "J=%s\n", net->autojoin);
 		if (net->nickserv)
@@ -1170,9 +1217,10 @@ servlist_save (void)
 			fprintf (fp, "E=%s\n", net->encoding);
 			if (!servlist_check_encoding (net->encoding))
 			{
-				snprintf (buf, sizeof (buf), _("Warning: \"%s\" character set is unknown. No conversion will be applied for network %s."),
+				buf = g_strdup_printf (_("Warning: \"%s\" character set is unknown. No conversion will be applied for network %s."),
 							 net->encoding, net->name);
 				fe_message (buf, FE_MSG_WARN);
+				g_free (buf);
 			}
 		}
 
