@@ -32,7 +32,7 @@
 #include <sys/mman.h>
 #endif
 
-#include "xchat.h"
+#include "hexchat.h"
 #include <glib.h>
 #include "cfgfiles.h"
 #include "chanopt.h"
@@ -41,8 +41,9 @@
 #include "server.h"
 #include "util.h"
 #include "outbound.h"
-#include "xchatc.h"
+#include "hexchatc.h"
 #include "text.h"
+#include "typedef.h"
 #ifdef WIN32
 #include <windows.h>
 #endif
@@ -55,24 +56,24 @@ struct pevt_stage1
 };
 
 
-static void mkdir_p (char *dir);
+static void mkdir_p (char *filename);
 static char *log_create_filename (char *channame);
 
-
 static char *
-scrollback_get_filename (session *sess, char *buf, int max)
+scrollback_get_filename (session *sess)
 {
-	char *net, *chan;
+	char *net, *chan, *buf;
 
 	net = server_get_network (sess->server, FALSE);
 	if (!net)
 		return NULL;
 
-	snprintf (buf, max, "%s/scrollback/%s/%s.txt", get_xdir_fs (), net, "");
+	buf = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "scrollback" G_DIR_SEPARATOR_S "%s" G_DIR_SEPARATOR_S "%s.txt", get_xdir (), net, "");
 	mkdir_p (buf);
+	g_free (buf);
 
 	chan = log_create_filename (sess->channel);
-	snprintf (buf, max, "%s/scrollback/%s/%s.txt", get_xdir_fs (), net, chan);
+	buf = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "scrollback" G_DIR_SEPARATOR_S "%s" G_DIR_SEPARATOR_S "%s.txt", get_xdir (), net, chan);
 	free (chan);
 
 	return buf;
@@ -125,44 +126,12 @@ scrollback_close (session *sess)
 	}
 }
 
-static char *
-file_to_buffer (char *file, int *len)
-{
-	int fh;
-	char *buf;
-	struct stat st;
-
-	fh = open (file, O_RDONLY | OFLAGS);
-	if (fh == -1)
-		return NULL;
-
-	fstat (fh, &st);
-
-	buf = malloc (st.st_size);
-	if (!buf)
-	{
-		close (fh);
-		return NULL;
-	}
-
-	if (read (fh, buf, st.st_size) != st.st_size)
-	{
-		free (buf);
-		close (fh);
-		return NULL;
-	}
-
-	*len = st.st_size;
-	close (fh);
-	return buf;
-}
-
-/* shrink the file to roughly prefs.max_lines */
+/* shrink the file to roughly prefs.hex_text_max_lines */
 
 static void
 scrollback_shrink (session *sess)
 {
-	char file[1024];
+	char *file;
 	char *buf;
 	int fh;
 	int lines;
@@ -174,12 +143,17 @@ scrollback_shrink (session *sess)
 	sess->scrollwritten = 0;
 	lines = 0;
 
-	if (scrollback_get_filename (sess, file, sizeof (file)) == NULL)
+	if ((file = scrollback_get_filename (sess)) == NULL)
+	{
+		g_free (file);
 		return;
+	}
 
-	buf = file_to_buffer (file, &len);
-	if (!buf)
+	if (!g_file_get_contents (file, &buf, &len, NULL))
+	{
+		g_free (file);
 		return;
+	}
 
 	/* count all lines */
 	p = buf;
@@ -190,7 +164,8 @@ scrollback_shrink (session *sess)
 		p++;
 	}
 
-	fh = open (file, O_CREAT | O_TRUNC | O_APPEND | O_WRONLY, 0644);
+	fh = g_open (file, O_CREAT | O_TRUNC | O_APPEND | O_WRONLY, 0644);
+	g_free (file);
 	if (fh == -1)
 	{
 		free (buf);
@@ -204,7 +179,7 @@ scrollback_shrink (session *sess)
 		if (*p == '\n')
 		{
 			line++;
-			if (line >= lines - prefs.max_lines &&
+			if (line >= lines - prefs.hex_text_max_lines &&
 				 p + 1 != buf + len)
 			{
 				p++;
@@ -222,7 +197,7 @@ scrollback_shrink (session *sess)
 static void
 scrollback_save (session *sess, char *text)
 {
-	char buf[512 * 4];
+	char *buf;
 	time_t stamp;
 	int len;
 
@@ -231,7 +206,7 @@ scrollback_save (session *sess, char *text)
 
 	if (sess->text_scrollback == SET_DEFAULT)
 	{
-		if (!prefs.text_replay)
+		if (!prefs.hex_text_replay)
 			return;
 	}
 	else
@@ -242,19 +217,22 @@ scrollback_save (session *sess, char *text)
 
 	if (sess->scrollfd == -1)
 	{
-		if (scrollback_get_filename (sess, buf, sizeof (buf)) == NULL)
+		if ((buf = scrollback_get_filename (sess)) == NULL)
 			return;
 
-		sess->scrollfd = open (buf, O_CREAT | O_APPEND | O_WRONLY, 0644);
+		sess->scrollfd = g_open (buf, O_CREAT | O_APPEND | O_WRONLY, 0644);
+		g_free (buf);
 		if (sess->scrollfd == -1)
 			return;
 	}
 
 	stamp = time (0);
 	if (sizeof (stamp) == 4)	/* gcc will optimize one of these out */
-		write (sess->scrollfd, buf, snprintf (buf, sizeof (buf), "T %d ", (int)stamp));
+		buf = g_strdup_printf ("T %d ", (int) stamp);
 	else
-		write (sess->scrollfd, buf, snprintf (buf, sizeof (buf), "T %"G_GINT64_FORMAT" ", (gint64)stamp));
+		buf = g_strdup_printf ("T %" G_GINT64_FORMAT " ", (gint64)stamp);
+	write (sess->scrollfd, buf, strlen (buf));
+	g_free (buf);
 
 	len = strlen (text);
 	write (sess->scrollfd, text, len);
@@ -263,7 +241,7 @@ scrollback_save (session *sess, char *text)
 
 	sess->scrollwritten++;
 
-	if ((sess->scrollwritten * 2 > prefs.max_lines && prefs.max_lines > 0) ||
+	if ((sess->scrollwritten * 2 > prefs.hex_text_max_lines && prefs.hex_text_max_lines > 0) ||
        sess->scrollwritten > 32000)
 		scrollback_shrink (sess);
 }
@@ -271,24 +249,17 @@ scrollback_save (session *sess, char *text)
 void
 scrollback_load (session *sess)
 {
-	int fh;
-	char buf[512 * 4];
+	char *buf;
 	char *text;
 	time_t stamp;
 	int lines;
-
-#ifdef WIN32
-	char *cleaned_text;
-	int cleaned_len;
-#else
-	char *map, *end_map;
-	struct stat statbuf;
-	const char *begin, *eol;
-#endif
+	GIOChannel *io;
+	GError *file_error = NULL;
+	GError *io_err = NULL;
 
 	if (sess->text_scrollback == SET_DEFAULT)
 	{
-		if (!prefs.text_replay)
+		if (!prefs.hex_text_replay)
 			return;
 	}
 	else
@@ -297,126 +268,88 @@ scrollback_load (session *sess)
 			return;
 	}
 
-	if (scrollback_get_filename (sess, buf, sizeof (buf)) == NULL)
+	if ((buf = scrollback_get_filename (sess)) == NULL)
 		return;
 
-	fh = open (buf, O_RDONLY | OFLAGS);
-	if (fh == -1)
+	io = g_io_channel_new_file (buf, "r", &file_error);
+	g_free (buf);
+	if (!io)
 		return;
 
-#ifndef WIN32
-	if (fstat (fh, &statbuf) < 0)
-		return;
-
-	map = mmap (NULL, statbuf.st_size, PROT_READ, MAP_PRIVATE, fh, 0);
-	if (map == MAP_FAILED)
-		return;
-
-	end_map = map + statbuf.st_size;
-
 	lines = 0;
-	begin = map;
-	while (begin < end_map)
+
+	while (1)
 	{
-		int n_bytes;
+		gsize n_bytes;
+		GIOStatus io_status;
 
-		eol = memchr (begin, '\n', end_map - begin);
-
-		if (!eol)
-			eol = end_map;
-
-		n_bytes = MIN (eol - begin, sizeof (buf) - 1);
-
-		strncpy (buf, begin, n_bytes);
-
-		buf[n_bytes] = 0;
-
-		if (buf[0] == 'T')
+		io_status = g_io_channel_read_line (io, &buf, &n_bytes, NULL, &io_err);
+		
+		if (io_status == G_IO_STATUS_NORMAL)
 		{
-			if (sizeof (time_t) == 4)
-				stamp = strtoul (buf + 2, NULL, 10);
-			else
-				stamp = strtoull (buf + 2, NULL, 10); /* just incase time_t is 64 bits */
-			text = strchr (buf + 3, ' ');
-			if (text)
+			char *buf_tmp;
+
+			n_bytes--;
+			buf_tmp = buf;
+			buf = g_strndup (buf_tmp, n_bytes);
+			g_free (buf_tmp);
+
+			if (buf[0] == 'T')
 			{
-				if (prefs.text_replay_strip_color)
+				if (sizeof (time_t) == 4)
+					stamp = strtoul (buf + 2, NULL, 10);
+				else
+					stamp = strtoull (buf + 2, NULL, 10); /* in case time_t is 64 bits */
+				text = strchr (buf + 3, ' ');
+				if (text)
 				{
-					text = strip_color (text + 1, -1, STRIP_COLOR);
-				}
-				fe_print_text (sess, text, stamp);
-				if (prefs.text_replay_strip_color)
-				{
-					g_free (text);
-				}
-			}
-			lines++;
-		}
-
-		begin = eol + 1;
-	}
-
-	sess->scrollwritten = lines;
-
-	if (lines)
-	{
-		text = ctime (&stamp);
-		text[24] = 0;	/* get rid of the \n */
-		snprintf (buf, sizeof (buf), "\n*\t%s %s\n\n", _("Loaded log from"), text);
-		fe_print_text (sess, buf, 0);
-		/*EMIT_SIGNAL (XP_TE_GENMSG, sess, "*", buf, NULL, NULL, NULL, 0);*/
-	}
-
-	munmap (map, statbuf.st_size);
-#else
-	lines = 0;
-	while (waitline (fh, buf, sizeof buf, FALSE) != -1)
-	{
-		if (buf[0] == 'T')
-		{
-			if (sizeof (time_t) == 4)
-				stamp = strtoul (buf + 2, NULL, 10);
-			else
-				stamp = strtoull (buf + 2, NULL, 10); /* just incase time_t is 64 bits */
-			text = strchr (buf + 3, ' ');
-			if (text)
-			{
-				if (prefs.text_replay_strip_color)
-				{
-					text = strip_color (text + 1, -1, STRIP_COLOR);
-				}
-				cleaned_text = text_replace_non_bmp (text, -1, &cleaned_len);
-				if (cleaned_text != NULL)
-				{
-					if (prefs.text_replay_strip_color)
+					if (prefs.hex_text_stripcolor_replay)
+					{
+						text = strip_color (text + 1, -1, STRIP_COLOR);
+					}
+#ifdef WIN32
+#if 0
+					cleaned_text = text_replace_non_bmp (text, -1, &cleaned_len);
+					if (cleaned_text != NULL)
+					{
+						if (prefs.hex_text_stripcolor_replay)
+						{
+							g_free (text);
+						}
+						text = cleaned_text;
+					}
+#endif
+					text_replace_non_bmp2 (text);
+#endif
+					fe_print_text (sess, text, stamp);
+					if (prefs.hex_text_stripcolor_replay)
 					{
 						g_free (text);
 					}
-					text = cleaned_text;
-				}
-				fe_print_text (sess, text, stamp);
-				if (prefs.text_replay_strip_color)
-				{
-					g_free (text);
 				}
+				lines++;
 			}
-			lines++;
+
+			g_free (buf);
 		}
+
+		else
+			break;
 	}
 
+	g_io_channel_unref (io);
+
 	sess->scrollwritten = lines;
 
 	if (lines)
 	{
 		text = ctime (&stamp);
 		text[24] = 0;	/* get rid of the \n */
-		snprintf (buf, sizeof (buf), "\n*\t%s %s\n\n", _("Loaded log from"), text);
+		buf = g_strdup_printf ("\n*\t%s %s\n\n", _("Loaded log from"), text);
 		fe_print_text (sess, buf, 0);
+		g_free (buf);
 		/*EMIT_SIGNAL (XP_TE_GENMSG, sess, "*", buf, NULL, NULL, NULL, 0);*/
 	}
-#endif
-
-	close (fh);
 }
 
 void
@@ -437,32 +370,15 @@ log_close (session *sess)
 }
 
 static void
-mkdir_p (char *dir)	/* like "mkdir -p" from a shell, FS encoding */
+mkdir_p (char *filename)
 {
-	char *start = dir;
+	char *dirname;
+	
+	dirname = g_path_get_dirname (filename);
 
-	/* the whole thing already exists? */
-	if (access (dir, F_OK) == 0)
-		return;
+	g_mkdir_with_parents (dirname, 0700);
 
-	while (*dir)
-	{
-#ifdef WIN32
-		if (dir != start && (*dir == '/' || *dir == '\\'))
-#else
-		if (dir != start && *dir == '/')
-#endif
-		{
-			*dir = 0;
-#ifdef WIN32
-			mkdir (start);
-#else
-			mkdir (start, S_IRUSR | S_IWUSR | S_IXUSR);
-#endif
-			*dir = '/';
-		}
-		dir++;
-	}
+	g_free (dirname);
 }
 
 static char *
@@ -570,24 +486,58 @@ log_insert_vars (char *buf, int bufsize, char *fmt, char *c, char *n, char *s)
 	}
 }
 
+static int
+logmask_is_fullpath ()
+{
+	/* Check if final path/filename is absolute or relative.
+	 * If one uses log mask variables, such as "%c/...", %c will be empty upon
+	 * connecting since there's no channel name yet, so we have to make sure
+	 * we won't try to write to the FS root. On Windows we can be sure it's
+	 * full path if the 2nd character is a colon since Windows doesn't allow
+	 * colons in filenames.
+	 */
+#ifdef WIN32
+	/* Treat it as full path if it
+	 * - starts with '\' which denotes the root directory of the current drive letter
+	 * - starts with a drive letter and followed by ':'
+	 */
+	if (prefs.hex_irc_logmask[0] == '\\' || (((prefs.hex_irc_logmask[0] >= 'A' && prefs.hex_irc_logmask[0] <= 'Z') || (prefs.hex_irc_logmask[0] >= 'a' && prefs.hex_irc_logmask[0] <= 'z')) && prefs.hex_irc_logmask[1] == ':'))
+#else
+	if (prefs.hex_irc_logmask[0] == '/')
+#endif
+	{
+		return 1;
+	}
+	else
+	{
+		return 0;
+	}
+}
+
 static char *
 log_create_pathname (char *servname, char *channame, char *netname)
 {
 	char fname[384];
 	char fnametime[384];
-	char *fs;
 	struct tm *tm;
 	time_t now;
 
 	if (!netname)
+	{
 		netname = "NETWORK";
+	}
 
 	/* first, everything is in UTF-8 */
 	if (!rfc_casecmp (channame, servname))
+	{
 		channame = strdup ("server");
+	}
 	else
+	{
 		channame = log_create_filename (channame);
-	log_insert_vars (fname, sizeof (fname), prefs.logmask, channame, netname, servname);
+	}
+
+	log_insert_vars (fname, sizeof (fname), prefs.hex_irc_logmask, channame, netname, servname);
 	free (channame);
 
 	/* insert time/date */
@@ -596,23 +546,19 @@ log_create_pathname (char *servname, char *channame, char *netname)
 	strftime (fnametime, sizeof (fnametime), fname, tm);
 
 	/* create final path/filename */
-#ifdef WIN32
-	if (fnametime[0] == '/' || (fnametime[0] >= 'A' && fnametime[1] == ':'))
-#else
-	if (fnametime[0] == '/')	/* is it fullpath already? */
-#endif
+	if (logmask_is_fullpath ())
+	{
 		snprintf (fname, sizeof (fname), "%s", fnametime);
-	else
-		snprintf (fname, sizeof (fname), "%s/logs/%s", get_xdir_utf8 (), fnametime);
-
-	/* now we need it in FileSystem encoding */
-	fs = xchat_filename_from_utf8 (fname, -1, 0, 0, 0);
+	}
+	else	/* relative path */
+	{
+		snprintf (fname, sizeof (fname), "%s" G_DIR_SEPARATOR_S "logs" G_DIR_SEPARATOR_S "%s", get_xdir (), fnametime);
+	}
 
 	/* create all the subdirectories */
-	if (fs)
-		mkdir_p (fs);
+	mkdir_p (fname);
 
-	return fs;
+	return g_strdup(fname);
 }
 
 static int
@@ -628,9 +574,9 @@ log_open_file (char *servname, char *channame, char *netname)
 		return -1;
 
 #ifdef WIN32
-	fd = open (file, O_CREAT | O_APPEND | O_WRONLY, S_IREAD|S_IWRITE);
+	fd = g_open (file, O_CREAT | O_APPEND | O_WRONLY, S_IREAD|S_IWRITE);
 #else
-	fd = open (file, O_CREAT | O_APPEND | O_WRONLY, 0644);
+	fd = g_open (file, O_CREAT | O_APPEND | O_WRONLY, 0644);
 #endif
 	g_free (file);
 
@@ -655,12 +601,14 @@ log_open (session *sess)
 
 	if (!log_error && sess->logfd == -1)
 	{
-		char message[512];
-		snprintf (message, sizeof (message),
-					_("* Can't open log file(s) for writing. Check the\n" \
-					  "  permissions on %s/logs"), get_xdir_utf8 ());
+		char *message;
+
+		message = g_strdup_printf (_("* Can't open log file(s) for writing. Check the\npermissions on %s"),
+			log_create_pathname (sess->server->servername, sess->channel, server_get_network (sess->server, FALSE)));
+
 		fe_message (message, FE_MSG_WAIT | FE_MSG_ERROR);
 
+		g_free (message);
 		log_error = TRUE;
 	}
 }
@@ -670,7 +618,7 @@ log_open_or_close (session *sess)
 {
 	if (sess->text_logging == SET_DEFAULT)
 	{
-		if (prefs.logging)
+		if (prefs.hex_irc_logging)
 			log_open (sess);
 		else
 			log_close (sess);
@@ -707,7 +655,7 @@ get_stamp_str (char *fmt, time_t tim, char **ret)
 	if (!len)
 	{
 		/* use failsafe format until a correct one is specified */
-		len = strftime (dest, sizeof (dest), "[%H:%M]", localtime (&tim));
+		len = strftime (dest, sizeof (dest), "[%H:%M:%S]", localtime (&tim));
 	}
 #endif
 	if (len)
@@ -734,7 +682,7 @@ log_write (session *sess, char *text)
 
 	if (sess->text_logging == SET_DEFAULT)
 	{
-		if (!prefs.logging)
+		if (!prefs.hex_irc_logging)
 			return;
 	}
 	else
@@ -751,7 +699,7 @@ log_write (session *sess, char *text)
 										 server_get_network (sess->server, FALSE));
 	if (file)
 	{
-		if (access (file, F_OK) != 0)
+		if (g_access (file, F_OK) != 0)
 		{
 			close (sess->logfd);
 			sess->logfd = log_open_file (sess->server->servername, sess->channel,
@@ -760,9 +708,9 @@ log_write (session *sess, char *text)
 		g_free (file);
 	}
 
-	if (prefs.timestamp_logs)
+	if (prefs.hex_stamp_log)
 	{
-		len = get_stamp_str (prefs.timestamp_log_format, time (0), &stamp);
+		len = get_stamp_str (prefs.hex_stamp_log_format, time (0), &stamp);
 		if (len)
 		{
 			write (sess->logfd, stamp, len);
@@ -888,6 +836,7 @@ iso_8859_1_to_utf8 (unsigned char *text, int len, gsize *bytes_written)
 #ifdef WIN32
 /* replace characters outside of the Basic Multilingual Plane with
  * replacement characters (0xFFFD) */
+#if 0
 char *
 text_replace_non_bmp (char *utf8_input, int input_length, glong *output_length)
 {
@@ -925,6 +874,30 @@ text_replace_non_bmp (char *utf8_input, int input_length, glong *output_length)
 }
 #endif
 
+void
+text_replace_non_bmp2 (char *utf8_input)
+{
+	char *tmp = utf8_input, *next;
+	gunichar suspect;
+
+	while (tmp != NULL && *tmp)
+	{
+		next = g_utf8_next_char(tmp);
+		suspect = g_utf8_get_char_validated(tmp, next - tmp);
+		if ((suspect >= 0x1D173 && suspect <= 0x1D17A) || (suspect >= 0xE0001 && suspect <= 0xE007F))
+		{
+			/* 0xFFFD - replacement character */
+			*tmp = 0xEF;
+			*(++tmp) = 0xBF;
+			*(++tmp) = 0xBD;
+			*(++tmp) = 0x1A;	/* ASCII Sub to fill the 4th non-BMP byte */
+		}
+
+		tmp = next;
+	}
+}
+#endif
+
 char *
 text_validate (char **text, int *len)
 {
@@ -1075,6 +1048,13 @@ static char * const pevt_genmsg_help[] = {
 	N_("Right message"),
 };
 
+#if 0
+static char * const pevt_identd_help[] = {
+	N_("IP address"),
+	N_("Username")
+};
+#endif
+
 static char * const pevt_join_help[] = {
 	N_("The nick of the joining person"),
 	N_("The channel being joined"),
@@ -1101,6 +1081,20 @@ static char * const pevt_privmsg_help[] = {
 	N_("Identified text")
 };
 
+static char * const pevt_capack_help[] = {
+	N_("Server Name"),
+	N_("Acknowledged Capabilities")
+};
+
+static char * const pevt_caplist_help[] = {
+	N_("Server Name"),
+	N_("Server Capabilities")
+};
+
+static char * const pevt_capreq_help[] = {
+	N_("Requested Capabilities")
+};
+
 static char * const pevt_changenick_help[] = {
 	N_("Old nickname"),
 	N_("New nickname"),
@@ -1343,6 +1337,17 @@ static char * const pevt_generic_channel_help[] = {
 	N_("Channel Name"),
 };
 
+static char * const pevt_saslauth_help[] = {
+	N_("Username")
+};
+
+static char * const pevt_saslresponse_help[] = {
+	N_("Server Name"),
+	N_("Raw Numeric or Identifier"),
+	N_("Username"),
+	N_("Message")
+};
+
 static char * const pevt_servertext_help[] = {
 	N_("Text"),
 	N_("Server Name"),
@@ -1604,7 +1609,7 @@ pevent_make_pntevts ()
 			if (pevt_build_string (pntevts_text[i], &(pntevts[i]), &m) != 0)
 			{
 				fprintf (stderr,
-							"XChat CRITICAL *** default event text failed to build!\n");
+							"HexChat CRITICAL *** default event text failed to build!\n");
 				abort ();
 			}
 		}
@@ -1679,9 +1684,9 @@ pevent_load (char *filename)
 	char *ofs;
 
 	if (filename == NULL)
-		fd = xchat_open_file ("pevents.conf", O_RDONLY, 0, 0);
+		fd = hexchat_open_file ("pevents.conf", O_RDONLY, 0, 0);
 	else
-		fd = xchat_open_file (filename, O_RDONLY, 0, XOF_FULLPATH);
+		fd = hexchat_open_file (filename, O_RDONLY, 0, XOF_FULLPATH);
 
 	if (fd == -1)
 		return 1;
@@ -1774,7 +1779,7 @@ pevent_check_all_loaded ()
 		if (pntevts_text[i] == NULL)
 		{
 			/*printf ("%s\n", te[i].name);
-			snprintf(out, sizeof(out), "The data for event %s failed to load. Reverting to defaults.\nThis may be because a new version of XChat is loading an old config file.\n\nCheck all print event texts are correct", evtnames[i]);
+			snprintf(out, sizeof(out), "The data for event %s failed to load. Reverting to defaults.\nThis may be because a new version of HexChat is loading an old config file.\n\nCheck all print event texts are correct", evtnames[i]);
 			   gtkutil_simpledialog(out); */
 			/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
 			if (te[i].num_args & 128)
@@ -1799,7 +1804,7 @@ load_text_events ()
 
 /*
 	CL: format_event now handles filtering of arguments:
-	1) if prefs.stripcolor is set, filter all style control codes from arguments
+	1) if prefs.hex_text_stripcolor_msg is set, filter all style control codes from arguments
 	2) always strip \010 (ATTR_HIDDEN) from arguments: it is only for use in the format string itself
 */
 #define ARG_FLAG(argn) (1 << (argn))
@@ -1842,7 +1847,7 @@ format_event (session *sess, int index, char **args, char *o, int sizeofo, unsig
 			if (a > numargs)
 			{
 				fprintf (stderr,
-							"XChat DEBUG: display_event: arg > numargs (%d %d %s)\n",
+							"HexChat DEBUG: display_event: arg > numargs (%d %d %s)\n",
 							a, numargs, i);
 				break;
 			}
@@ -1871,7 +1876,7 @@ format_event (session *sess, int index, char **args, char *o, int sizeofo, unsig
 					o[oi++] = ' ';
 			} else
 			{*/
-				if (prefs.indent_nicks)
+				if (prefs.hex_text_indent)
 					o[oi++] = '\t';
 				else
 					o[oi++] = ' ';
@@ -2095,10 +2100,10 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 {
 	char *word[PDIWORDS];
 	int i;
-	unsigned int stripcolor_args = (prefs.stripcolor ? 0xFFFFFFFF : 0);
+	unsigned int stripcolor_args = (prefs.hex_text_stripcolor_msg ? 0xFFFFFFFF : 0);
 	char tbuf[NICKLEN + 4];
 
-	if (prefs.colorednicks && (index == XP_TE_CHANACTION || index == XP_TE_CHANMSG))
+	if (prefs.hex_text_color_nicks && (index == XP_TE_CHANACTION || index == XP_TE_CHANMSG))
 	{
 		snprintf (tbuf, sizeof (tbuf), "\003%d%s", color_of (a), a);
 		a = tbuf;
@@ -2127,7 +2132,7 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	case XP_TE_PARTREASON:
 	case XP_TE_QUIT:
 		/* implement ConfMode / Hide Join and Part Messages */
-		if (chanopt_is_set (prefs.confmode, sess->text_hidejoinpart))
+		if (chanopt_is_set (prefs.hex_irc_conf_mode, sess->text_hidejoinpart))
 			return;
 		break;
 
@@ -2136,9 +2141,9 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	case XP_TE_DPRIVMSG:
 	case XP_TE_PRIVACTION:
 	case XP_TE_DPRIVACTION:
-		if (chanopt_is_set_a (prefs.input_beep_priv, sess->alert_beep))
+		if (chanopt_is_set_a (prefs.hex_input_beep_priv, sess->alert_beep) && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 			sound_beep (sess);
-		if (chanopt_is_set_a (prefs.input_flash_priv, sess->alert_taskbar))
+		if (chanopt_is_set_a (prefs.hex_input_flash_priv, sess->alert_taskbar) && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 			fe_flash_window (sess);
 		/* why is this one different? because of plugin-tray.c's hooks! ugly */
 		if (sess->alert_tray == SET_ON)
@@ -2148,9 +2153,9 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	/* ===Highlighted message=== */
 	case XP_TE_HCHANACTION:
 	case XP_TE_HCHANMSG:
-		if (chanopt_is_set_a (prefs.input_beep_hilight, sess->alert_beep))
+		if (chanopt_is_set_a (prefs.hex_input_beep_hilight, sess->alert_beep) && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 			sound_beep (sess);
-		if (chanopt_is_set_a (prefs.input_flash_hilight, sess->alert_taskbar))
+		if (chanopt_is_set_a (prefs.hex_input_flash_hilight, sess->alert_taskbar) && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 			fe_flash_window (sess);
 		if (sess->alert_tray == SET_ON)
 			fe_tray_set_icon (FE_ICON_MESSAGE);
@@ -2159,9 +2164,9 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	/* ===Channel message=== */
 	case XP_TE_CHANACTION:
 	case XP_TE_CHANMSG:
-		if (chanopt_is_set_a (prefs.input_beep_chans, sess->alert_beep))
+		if (chanopt_is_set_a (prefs.hex_input_beep_chans, sess->alert_beep) && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 			sound_beep (sess);
-		if (chanopt_is_set_a (prefs.input_flash_chans, sess->alert_taskbar))
+		if (chanopt_is_set_a (prefs.hex_input_flash_chans, sess->alert_taskbar) && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 			fe_flash_window (sess);
 		if (sess->alert_tray == SET_ON)
 			fe_tray_set_icon (FE_ICON_MESSAGE);
@@ -2206,10 +2211,10 @@ pevent_save (char *fn)
 	char buf[1024];
 
 	if (!fn)
-		fd = xchat_open_file ("pevents.conf", O_CREAT | O_TRUNC | O_WRONLY,
+		fd = hexchat_open_file ("pevents.conf", O_CREAT | O_TRUNC | O_WRONLY,
 									 0x180, XOF_DOMODE);
 	else
-		fd = xchat_open_file (fn, O_CREAT | O_TRUNC | O_WRONLY, 0x180,
+		fd = hexchat_open_file (fn, O_CREAT | O_TRUNC | O_WRONLY, 0x180,
 									 XOF_FULLPATH | XOF_DOMODE);
 	if (fd == -1)
 	{
@@ -2259,8 +2264,8 @@ sound_find_command (void)
 	char *cmd;
 	int i = 0;
 
-	if (prefs.soundcmd[0])
-		return g_strdup (prefs.soundcmd);
+	if (prefs.hex_sound_command[0])
+		return g_strdup (prefs.hex_sound_command);
 
 	while (progs[i])
 	{
@@ -2276,9 +2281,8 @@ sound_find_command (void)
 void
 sound_play (const char *file, gboolean quiet)
 {
-	char buf[512];
-	char wavfile[512];
-	char *file_fs;
+	char *buf;
+	char *wavfile;
 	char *cmd;
 #if 0
 	LPSTR lpRes;
@@ -2290,34 +2294,27 @@ sound_play (const char *file, gboolean quiet)
 		return;
 
 #ifdef WIN32
-	/* check for fullpath, windows style */
-	if (strlen (file) > 3 &&
-		 file[1] == ':' && (file[2] == '\\' || file[2] == '/') )
-	{
-		strncpy (wavfile, file, sizeof (wavfile));
-	} else
-#endif
+	/* check for fullpath */
+	if (file[0] == '\\' || (((file[0] >= 'A' && file[0] <= 'Z') || (file[0] >= 'a' && file[0] <= 'z')) && file[1] == ':'))
+#else
 	if (file[0] != '/')
+#endif
 	{
-		snprintf (wavfile, sizeof (wavfile), "%s/%s", prefs.sounddir, file);
-	} else
+		wavfile = g_strdup (file);
+	}
+	else
 	{
-		strncpy (wavfile, file, sizeof (wavfile));
+		wavfile = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", prefs.hex_sound_dir, file);
 	}
-	wavfile[sizeof (wavfile) - 1] = 0;	/* ensure termination */
 
-	file_fs = xchat_filename_from_utf8 (wavfile, -1, 0, 0, 0);
-	if (!file_fs)
-		return;
-
-	if (access (file_fs, R_OK) == 0)
+	if (g_access (wavfile, R_OK) == 0)
 	{
 		cmd = sound_find_command ();
 
 #ifdef WIN32
 		if (cmd == NULL || strcmp (cmd, "esdplay") == 0)
 		{
-			PlaySound (file_fs, NULL, SND_NODEFAULT|SND_FILENAME|SND_ASYNC);
+			PlaySound (wavfile, NULL, SND_NODEFAULT|SND_FILENAME|SND_ASYNC);
 #if 0			/* this would require the wav file to be added to the executable as resource */
 			hResInfo = FindResource (NULL, file_fs, "WAVE");
 			if (hResInfo != NULL)
@@ -2339,33 +2336,33 @@ sound_play (const char *file, gboolean quiet)
 				}
 			}
 #endif
-		} else
+		}
+		else
 #endif
 		{
 			if (cmd)
 			{
-				if (strchr (file_fs, ' '))
-					snprintf (buf, sizeof (buf), "%s \"%s\"", cmd, file_fs);
-				else
-					snprintf (buf, sizeof (buf), "%s %s", cmd, file_fs);
-				buf[sizeof (buf) - 1] = '\0';
-				xchat_exec (buf);
+				buf = g_strdup_printf ("%s \"%s\"", cmd, wavfile);
+				hexchat_exec (buf);
+				g_free (buf);
 			}
 		}
 
 		if (cmd)
 			g_free (cmd);
 
-	} else
+	}
+	else
 	{
 		if (!quiet)
 		{
-			snprintf (buf, sizeof (buf), _("Cannot read sound file:\n%s"), wavfile);
+			buf = g_strdup_printf (_("Cannot read sound file:\n%s"), wavfile);
 			fe_message (buf, FE_MSG_ERROR);
+			g_free (buf);
 		}
 	}
 
-	g_free (file_fs);
+	g_free (wavfile);
 }
 
 void
@@ -2397,7 +2394,7 @@ sound_load ()
 
 	memset (&sound_files, 0, sizeof (char *) * (NUM_XP));
 
-	fd = xchat_open_file ("sound.conf", O_RDONLY, 0, 0);
+	fd = hexchat_open_file ("sound.conf", O_RDONLY, 0, 0);
 	if (fd == -1)
 		return;
 
@@ -2427,7 +2424,7 @@ sound_save ()
 	int fd, i;
 	char buf[512];
 
-	fd = xchat_open_file ("sound.conf", O_CREAT | O_TRUNC | O_WRONLY, 0x180,
+	fd = hexchat_open_file ("sound.conf", O_CREAT | O_TRUNC | O_WRONLY, 0x180,
 								 XOF_DOMODE);
 	if (fd == -1)
 		return;
