@@ -44,8 +44,8 @@
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkversion.h>
 
-#include "../common/xchat.h"
-#include "../common/xchatc.h"
+#include "../common/hexchat.h"
+#include "../common/hexchatc.h"
 #include "../common/fe.h"
 #include "../common/util.h"
 #include "../common/network.h"
@@ -165,7 +165,7 @@ fe_dcc_send_filereq (struct session *sess, char *nick, int maxcps, int passive)
 	mdc->passive = passive;
 
 	snprintf (tbuf, sizeof tbuf, _("Send file to %s"), nick);
-	gtkutil_file_req (tbuf, dcc_send_filereq_file, mdc, NULL, FRF_MULTIPLE);
+	gtkutil_file_req (tbuf, dcc_send_filereq_file, mdc, prefs.hex_dcc_dir, NULL, FRF_MULTIPLE|FRF_FILTERISINITIAL);
 }
 
 static void
@@ -562,10 +562,10 @@ browse_folder (char *dir)
 static void
 browse_dcc_folder (void)
 {
-	if (prefs.dcc_completed_dir[0])
-		browse_folder (prefs.dcc_completed_dir);
+	if (prefs.hex_dcc_completed_dir[0])
+		browse_folder (prefs.hex_dcc_completed_dir);
 	else
-		browse_folder (prefs.dccdir);
+		browse_folder (prefs.hex_dcc_dir);
 }
 
 static void
@@ -776,7 +776,7 @@ fe_dcc_open_recv_win (int passive)
 	view_mode = VIEW_BOTH;
 	gtk_tree_selection_set_mode (dccfwin.sel, GTK_SELECTION_MULTIPLE);
 
-	if (!prefs.windows_as_tabs)
+	if (!prefs.hex_gui_tab_utils)
 		g_signal_connect (G_OBJECT (dccfwin.window), "configure_event",
 								G_CALLBACK (dcc_configure_cb), 0);
 	g_signal_connect (G_OBJECT (dccfwin.sel), "changed",
