@@ -37,12 +37,12 @@
 #include <unistd.h>
 #endif
 
-#include "../common/xchat.h"
+#include "../common/hexchat.h"
 #include "../common/fe.h"
 #include "../common/util.h"
 #include "../common/text.h"
 #include "../common/cfgfiles.h"
-#include "../common/xchatc.h"
+#include "../common/hexchatc.h"
 #include "../common/plugin.h"
 #include "../common/server.h"
 #include "../common/url.h"
@@ -132,38 +132,42 @@ static const GOptionEntry gopt_entries[] =
  {"no-auto",	'a', 0, G_OPTION_ARG_NONE,	&arg_dont_autoconnect, N_("Don't auto connect to servers"), NULL},
  {"cfgdir",	'd', 0, G_OPTION_ARG_STRING,	&arg_cfgdir, N_("Use a different config directory"), "PATH"},
  {"no-plugins",	'n', 0, G_OPTION_ARG_NONE,	&arg_skip_plugins, N_("Don't auto load any plugins"), NULL},
- {"plugindir",	'p', 0, G_OPTION_ARG_NONE,	&arg_show_autoload, N_("Show plugin auto-load directory"), NULL},
+ {"plugindir",	'p', 0, G_OPTION_ARG_NONE,	&arg_show_autoload, N_("Show plugin/script auto-load directory"), NULL},
  {"configdir",	'u', 0, G_OPTION_ARG_NONE,	&arg_show_config, N_("Show user config directory"), NULL},
  {"url",	 0,  0, G_OPTION_ARG_STRING,	&arg_url, N_("Open an irc://server:port/channel URL"), "URL"},
 #ifndef WIN32	/* uses DBUS */
  {"command",	'c', 0, G_OPTION_ARG_STRING,	&arg_command, N_("Execute command:"), "COMMAND"},
- {"existing",	'e', 0, G_OPTION_ARG_NONE,	&arg_existing, N_("Open URL or execute command in an existing XChat"), NULL},
+ {"existing",	'e', 0, G_OPTION_ARG_NONE,	&arg_existing, N_("Open URL or execute command in an existing HexChat"), NULL},
 #endif
  {"minimize",	 0,  0, G_OPTION_ARG_INT,	&arg_minimize, N_("Begin minimized. Level 0=Normal 1=Iconified 2=Tray"), N_("level")},
  {"version",	'v', 0, G_OPTION_ARG_NONE,	&arg_show_version, N_("Show version information"), NULL},
  {NULL}
 };
 
-#ifdef WIN32
 static void
 create_msg_dialog (gchar *title, gchar *message)
 {
 	GtkWidget *dialog;
+
 	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, message);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
+
+/* On Win32 we automatically have the icon. If we try to load it explicitly, it will look ugly for some reason. */
+#ifndef WIN32
+	pixmaps_init ();
+	gtk_window_set_icon (GTK_WINDOW (dialog), pix_hexchat);
+#endif
+
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
-#endif
 
 int
 fe_args (int argc, char *argv[])
 {
 	GError *error = NULL;
 	GOptionContext *context;
-#ifdef WIN32
-	char *buffer[2048];
-#endif
+	char *buffer;
 
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
@@ -186,27 +190,26 @@ fe_args (int argc, char *argv[])
 		{
 			if (strstr (error->message, "--help-all") != NULL)
 			{
-				if (snprintf (buffer, 2048, g_option_context_get_help (context, FALSE, NULL)))
-				{
-					gtk_init (&argc, &argv);
-					create_msg_dialog ("Long Help", buffer);
-				}
+				buffer = g_strdup_printf (g_option_context_get_help (context, FALSE, NULL));
+				gtk_init (&argc, &argv);
+				create_msg_dialog ("Long Help", buffer);
+				g_free (buffer);
 				return 0;
-			} else if (strstr (error->message, "--help") != NULL || strstr (error->message, "-?") != NULL)
+			}
+			else if (strstr (error->message, "--help") != NULL || strstr (error->message, "-?") != NULL)
 			{
-				if (snprintf (buffer, 2048, g_option_context_get_help (context, TRUE, NULL)))
-				{
-					gtk_init (&argc, &argv);
-					create_msg_dialog ("Help", buffer);
-				}
+				buffer = g_strdup_printf (g_option_context_get_help (context, TRUE, NULL));
+				gtk_init (&argc, &argv);
+				create_msg_dialog ("Help", buffer);
+				g_free (buffer);
 				return 0;
-			} else 
+			}
+			else 
 			{
-				if (snprintf (buffer, 2048, "%s\n", error->message))
-				{
-					gtk_init (&argc, &argv);
-					create_msg_dialog ("Error", buffer);
-				}
+				buffer = g_strdup_printf ("%s\n", error->message);
+				gtk_init (&argc, &argv);
+				create_msg_dialog ("Error", buffer);
+				g_free (buffer);
 				return 1;
 			}
 		}
@@ -224,57 +227,31 @@ fe_args (int argc, char *argv[])
 
 	if (arg_show_version)
 	{
-#ifdef WIN32
-		if (snprintf (buffer, 2048, DISPLAY_NAME" "PACKAGE_VERSION"\n"))
-		{
-			gtk_init (&argc, &argv);
-			create_msg_dialog ("Version Information", buffer);
-		}
-#else
-		printf (PACKAGE_TARNAME" "PACKAGE_VERSION"\n");
-#endif
+		buffer = g_strdup_printf (DISPLAY_NAME " " PACKAGE_VERSION "\n");
+		gtk_init (&argc, &argv);
+		create_msg_dialog ("Version Information", buffer);
+		g_free (buffer);
+
 		return 0;
 	}
 
 	if (arg_show_autoload)
 	{
-#ifdef WIN32
-		/* see the chdir() below */
-		char *sl, *exe = strdup (argv[0]);
-		sl = strrchr (exe, '\\');
-		if (sl)
-		{
-			*sl = 0;
-			if (snprintf (buffer, 2048, "%s\\plugins\n", exe))
-			{
-				gtk_init (&argc, &argv);
-				create_msg_dialog ("Plugin Auto-load Directory", buffer);
-			}
-		} else
-		{
-			if (snprintf (buffer, 2048, ".\\plugins\n"))
-			{
-				gtk_init (&argc, &argv);
-				create_msg_dialog ("Plugin Auto-load Directory", buffer);
-			}
-		}
-#else
-		printf ("%s\n", HEXCHATLIBDIR"/plugins");
-#endif
+		buffer = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "addons\n", get_xdir ());
+		gtk_init (&argc, &argv);
+		create_msg_dialog ("Plugin/Script Auto-load Directory", buffer);
+		g_free (buffer);
+
 		return 0;
 	}
 
 	if (arg_show_config)
 	{
-#ifdef WIN32
-		if (snprintf (buffer, 2048, "%s\n", get_xdir_fs ()))
-		{
-			gtk_init (&argc, &argv);
-			create_msg_dialog ("User Config Directory", buffer);
-		}
-#else
-		printf ("%s\n", get_xdir_fs ());
-#endif
+		buffer = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "\n", get_xdir ());
+		gtk_init (&argc, &argv);
+		create_msg_dialog ("User Config Directory", buffer);
+		g_free (buffer);
+
 		return 0;
 	}
 
@@ -287,7 +264,7 @@ fe_args (int argc, char *argv[])
 		char *tmp = strdup (argv[0]);
 		char *sl;
 
-		sl = strrchr (tmp, '\\');
+		sl = strrchr (tmp, G_DIR_SEPARATOR);
 		if (sl)
 		{
 			*sl = 0;
@@ -297,20 +274,11 @@ fe_args (int argc, char *argv[])
 	}
 #endif
 
-	if (arg_cfgdir)	/* we want filesystem encoding */
-	{
-		xdir_fs = strdup (arg_cfgdir);
-		if (xdir_fs[strlen (xdir_fs) - 1] == '/')
-			xdir_fs[strlen (xdir_fs) - 1] = 0;
-		g_free (arg_cfgdir);
-	}
-
 	gtk_init (&argc, &argv);
 
 #ifdef USE_XLIB
 	gdk_window_set_events (gdk_get_default_root_window (), GDK_PROPERTY_CHANGE_MASK);
-	gdk_window_add_filter (gdk_get_default_root_window (),
-								  (GdkFilterFunc)root_event_cb, NULL);
+	gdk_window_add_filter (gdk_get_default_root_window (), (GdkFilterFunc)root_event_cb, NULL);
 #endif
 
 	return -1;
@@ -325,7 +293,7 @@ const char cursor_color_rc[] =
 		"GtkEntry::cursor-color=\"#%02x%02x%02x\""
 #endif
 	"}"
-	"widget \"*.xchat-inputbox\" style : application \"xc-ib-st\"";
+	"widget \"*.hexchat-inputbox\" style : application \"xc-ib-st\"";
 
 GtkStyle *
 create_input_style (GtkStyle *style)
@@ -334,18 +302,18 @@ create_input_style (GtkStyle *style)
 	static int done_rc = FALSE;
 
 	pango_font_description_free (style->font_desc);
-	style->font_desc = pango_font_description_from_string (prefs.font_normal);
+	style->font_desc = pango_font_description_from_string (prefs.hex_text_font);
 
 	/* fall back */
 	if (pango_font_description_get_size (style->font_desc) == 0)
 	{
-		snprintf (buf, sizeof (buf), _("Failed to open font:\n\n%s"), prefs.font_normal);
+		snprintf (buf, sizeof (buf), _("Failed to open font:\n\n%s"), prefs.hex_text_font);
 		fe_message (buf, FE_MSG_ERROR);
 		pango_font_description_free (style->font_desc);
 		style->font_desc = pango_font_description_from_string ("sans 11");
 	}
 
-	if (prefs.style_inputbox && !done_rc)
+	if (prefs.hex_gui_input_style && !done_rc)
 	{
 		done_rc = TRUE;
 		sprintf (buf, cursor_color_rc, (colors[COL_FG].red >> 8),
@@ -367,7 +335,7 @@ fe_init (void)
 	key_init ();
 	pixmaps_init ();
 
-	channelwin_pix = pixmap_load_from_file (prefs.background);
+	channelwin_pix = pixmap_load_from_file (prefs.hex_text_background);
 	input_style = create_input_style (gtk_style_new ());
 }
 
@@ -376,10 +344,10 @@ fe_main (void)
 {
 	gtk_main ();
 
-	/* sleep for 3 seconds so any QUIT messages are not lost. The  */
+	/* sleep for 2 seconds so any QUIT messages are not lost. The  */
 	/* GUI is closed at this point, so the user doesn't even know! */
 	if (prefs.wait_on_exit)
-		sleep (3);
+		sleep (2);
 }
 
 void
@@ -417,7 +385,7 @@ log_handler (const gchar   *log_domain,
 {
 	session *sess;
 
-	/* if (getenv ("XCHAT_WARNING_IGNORE")) this gets ignored sometimes, so simply just disable all warnings */
+	/* if (getenv ("HEXCHAT_WARNING_IGNORE")) this gets ignored sometimes, so simply just disable all warnings */
 		return;
 
 	sess = find_dialog (serv_list->data, "(warnings)");
@@ -425,7 +393,7 @@ log_handler (const gchar   *log_domain,
 		sess = new_ircwindow (serv_list->data, "(warnings)", SESS_DIALOG, 0);
 
 	PrintTextf (sess, "%s\t%s\n", log_domain, message);
-	if (getenv ("XCHAT_WARNING_ABORT"))
+	if (getenv ("HEXCHAT_WARNING_ABORT"))
 		abort ();
 }
 
@@ -455,11 +423,11 @@ fe_new_window (session *sess, int focus)
 
 	if (sess->type == SESS_DIALOG)
 	{
-		if (prefs.privmsgtab)
+		if (prefs.hex_gui_tab_dialogs)
 			tab = TRUE;
 	} else
 	{
-		if (prefs.tabchannels)
+		if (prefs.hex_gui_tab_chans)
 			tab = TRUE;
 	}
 
@@ -553,7 +521,7 @@ fe_set_topic (session *sess, char *topic, char *stripped_topic)
 {
 	if (!sess->gui->is_tab || sess == current_tab)
 	{
-		if (prefs.text_stripcolor_topic)
+		if (prefs.hex_text_stripcolor_topic)
 		{
 			gtk_entry_set_text (GTK_ENTRY (sess->gui->topic_entry), stripped_topic);
 		}
@@ -570,7 +538,7 @@ fe_set_topic (session *sess, char *topic, char *stripped_topic)
 			free (sess->res->topic_text);
 		}
 
-		if (prefs.text_stripcolor_topic)
+		if (prefs.hex_text_stripcolor_topic)
 		{
 			sess->res->topic_text = strdup (stripped_topic);
 		}
@@ -587,7 +555,7 @@ fe_set_hilight (struct session *sess)
 	if (sess->gui->is_tab)
 		fe_set_tab_color (sess, 3);	/* set tab to blue */
 
-	if (prefs.input_flash_hilight && !prefs.away_omit_alerts)
+	if (prefs.hex_input_flash_hilight && (!prefs.hex_away_omit_alerts || !sess->server->is_away))
 		fe_flash_window (sess); /* taskbar flash */
 }
 
@@ -700,7 +668,7 @@ fe_progressbar_end (server *serv)
 void
 fe_print_text (struct session *sess, char *text, time_t stamp)
 {
-	PrintTextRaw (sess->res->buffer, (unsigned char *)text, prefs.indent_nicks, stamp);
+	PrintTextRaw (sess->res->buffer, (unsigned char *)text, prefs.hex_text_indent, stamp);
 
 	if (!sess->new_data && sess != current_tab &&
 		 sess->gui->is_tab && !sess->nick_said && stamp == 0)
@@ -919,7 +887,7 @@ fe_confirm (const char *message, void (*yesproc)(void *), void (*noproc)(void *)
 
 	if (dcc->file)
 		gtkutil_file_req (message, dcc_saveas_cb, ud, dcc->file, NULL,
-								FRF_WRITE|FRF_FILTERISINITIAL|FRF_NOASKOVERWRITE);
+								FRF_WRITE|FRF_NOASKOVERWRITE);
 }
 
 int
@@ -1038,7 +1006,7 @@ try_browser (const char *browser, const char *arg, const char *url)
 		argv[2] = url;
 		argv[3] = NULL;
 	}
-	xchat_execv (argv);
+	hexchat_execv (argv);
 	g_free (path);
 	return 1;
 }
@@ -1050,6 +1018,8 @@ fe_open_url_inner (const char *url)
 {
 #ifdef WIN32
 	ShellExecute (0, "open", url, NULL, NULL, SW_SHOWNORMAL);
+#elif defined __APPLE__
+	try_browser ("open", NULL, url);				/* on Mac you can just 'open http://foo.bar/' */
 #else
 	/* universal desktop URL opener (from xdg-utils). Supports gnome,kde,xfce4. */
 	if (try_browser ("xdg-open", NULL, url))
