@@ -24,12 +24,15 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-#ifndef WIN32
+#ifdef WIN32
+#include <io.h>
+#else
 #include <unistd.h>
 #endif
 
 #include "fe-gtk.h"
 
+#include <glib.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkeditable.h>
 #include <gtk/gtkmenu.h>
@@ -43,8 +46,8 @@
 #include <gtk/gtkentry.h>
 #include <gtk/gtkvscrollbar.h>
 
-#include "../common/xchat.h"
-#include "../common/xchatc.h"
+#include "../common/hexchat.h"
+#include "../common/hexchatc.h"
 #include "../common/cfgfiles.h"
 #include "../common/fe.h"
 #include "../common/userlist.h"
@@ -52,6 +55,7 @@
 #include "../common/util.h"
 #include "../common/text.h"
 #include "../common/plugin.h"
+#include "../common/typedef.h"
 #include <gdk/gdkkeysyms.h>
 #include "gtkutil.h"
 #include "menu.h"
@@ -84,10 +88,6 @@ void key_action_tab_clean (void);
 
 /* Remember that the *number* of actions is this *plus* 1 --AGL */
 #define KEY_MAX_ACTIONS 14
-/* These are cp'ed from history.c --AGL */
-#define STATE_SHIFT     GDK_SHIFT_MASK
-#define	STATE_ALT	GDK_MOD1_MASK
-#define STATE_CTRL	GDK_CONTROL_MASK
 
 struct key_binding
 {
@@ -322,7 +322,7 @@ key_handle_key_press (GtkWidget *wid, GdkEventKey *evt, session *sess)
 	/* gtktextview has no 'activate' event, so we trap ENTER here */
 	case GDK_Return:
 	case GDK_KP_Enter:
-		if (!(evt->state & GDK_CONTROL_MASK))
+		if (!(evt->state & STATE_CTRL))
 		{
 			g_signal_stop_emission_by_name (G_OBJECT (wid), "key_press_event");
 			mg_inputbox_cb (wid, sess->gui);
@@ -428,7 +428,7 @@ key_load_defaults ()
 		"None\nF9\nRun Command\nD1:/GUI MENU TOGGLE\nD2!\n\n"
 	int fd;
 
-	fd = xchat_open_file ("keybindings.conf", O_CREAT | O_TRUNC | O_WRONLY, 0x180, XOF_DOMODE);
+	fd = hexchat_open_file ("keybindings.conf", O_CREAT | O_TRUNC | O_WRONLY, 0x180, XOF_DOMODE);
 	if (fd < 0)
 		/* ???!!! */
 		return;
@@ -503,7 +503,7 @@ key_dialog_delete (GtkWidget * button, GtkCList * list)
 			cur = cur->next;
 		}
 		printf ("*** key_dialog_delete: couldn't find kb in list!\n");
-		/*if (getenv ("XCHAT_DEBUG"))
+		/*if (getenv ("HEXCHAT_DEBUG"))
 			abort ();*/
 	}
 }
@@ -511,11 +511,11 @@ key_dialog_delete (GtkWidget * button, GtkCList * list)
 static void
 key_print_text (GtkXText *xtext, char *text)
 {
-	unsigned int old = prefs.timestamp;
-	prefs.timestamp = 0;	/* temporarily disable stamps */
+	unsigned int old = prefs.hex_stamp_text;
+	prefs.hex_stamp_text = 0;	/* temporarily disable stamps */
 	gtk_xtext_clear (GTK_XTEXT (xtext)->buffer, 0);
 	PrintTextRaw (GTK_XTEXT (xtext)->buffer, text, 0, 0);
-	prefs.timestamp = old;
+	prefs.hex_stamp_text = old;
 }
 
 static void
@@ -818,13 +818,13 @@ key_dialog_show ()
 	gtk_box_pack_end (GTK_BOX (vbox), hbox2, 0, 0, 1);
 
 	wid = gtk_xtext_new (colors, 0);
-	gtk_xtext_set_tint (GTK_XTEXT (wid), prefs.tint_red, prefs.tint_green, prefs.tint_blue);
+	gtk_xtext_set_tint (GTK_XTEXT (wid), prefs.hex_text_tint_red, prefs.hex_text_tint_green, prefs.hex_text_tint_blue);
 	gtk_xtext_set_background (GTK_XTEXT (wid),
 									  channelwin_pix,
-									  prefs.transparent);
+									  prefs.hex_text_transparent);
 	gtk_widget_set_usize (wid, 0, 75);
 	gtk_box_pack_start (GTK_BOX (hbox2), wid, 1, 1, 1);
-	gtk_xtext_set_font (GTK_XTEXT (wid), prefs.font_normal);
+	gtk_xtext_set_font (GTK_XTEXT (wid), prefs.hex_text_font);
 	gtk_widget_show (wid);
 
 	wid2 = gtk_vscrollbar_new (GTK_XTEXT (wid)->adj);
@@ -845,10 +845,10 @@ key_save_kbs (char *fn)
 	struct key_binding *kb;
 
 	if (!fn)
-		fd = xchat_open_file ("keybindings.conf", O_CREAT | O_TRUNC | O_WRONLY,
+		fd = hexchat_open_file ("keybindings.conf", O_CREAT | O_TRUNC | O_WRONLY,
 									 0x180, XOF_DOMODE);
 	else
-		fd = xchat_open_file (fn, O_CREAT | O_TRUNC | O_WRONLY,
+		fd = hexchat_open_file (fn, O_CREAT | O_TRUNC | O_WRONLY,
 									 0x180, XOF_DOMODE | XOF_FULLPATH);
 	if (fd < 0)
 	{
@@ -856,7 +856,7 @@ key_save_kbs (char *fn)
 		return;
 	}
 	write (fd, buf,
-			 snprintf (buf, 510, "# XChat key bindings config file\n\n"));
+			 snprintf (buf, 510, "# HexChat key bindings config file\n\n"));
 
 	kb = keys_root;
 	i = 0;
@@ -910,7 +910,7 @@ key_save_kbs (char *fn)
 }
 
 /* I just know this is going to be a nasty parse, if you think it's bugged
-   it almost certainly is so contact the XChat dev team --AGL */
+   it almost certainly is so contact the HexChat dev team --AGL */
 
 static inline int
 key_load_kbs_helper_mod (char *in, int *out)
@@ -973,9 +973,9 @@ key_load_kbs (char *filename)
 	int fd, len, pnt = 0, state = 0, n;
 
 	if (filename == NULL)
-		fd = xchat_open_file ("keybindings.conf", O_RDONLY, 0, 0);
+		fd = hexchat_open_file ("keybindings.conf", O_RDONLY, 0, 0);
 	else
-		fd = xchat_open_file (filename, O_RDONLY, 0, XOF_FULLPATH);
+		fd = hexchat_open_file (filename, O_RDONLY, 0, XOF_FULLPATH);
 	if (fd < 0)
 		return 1;
 	if (fstat (fd, &st) != 0)
@@ -1019,8 +1019,8 @@ key_load_kbs (char *filename)
 				free (ibuf);
 				ibuf = malloc (1024);
 				snprintf (ibuf, 1024,
-							 _("Unknown keyname %s in key bindings config file\nLoad aborted, please fix %s/keybindings.conf\n"),
-							 buf, get_xdir_utf8 ());
+							 _("Unknown keyname %s in key bindings config file\nLoad aborted, please fix %s" G_DIR_SEPARATOR_S "keybindings.conf\n"),
+							 buf, get_xdir ());
 				fe_message (ibuf, FE_MSG_ERROR);
 				free (ibuf);
 				return 2;
@@ -1057,8 +1057,8 @@ key_load_kbs (char *filename)
 				free (ibuf);
 				ibuf = malloc (1024);
 				snprintf (ibuf, 1024,
-							 _("Unknown action %s in key bindings config file\nLoad aborted, Please fix %s/keybindings\n"),
-							 buf, get_xdir_utf8 ());
+							 _("Unknown action %s in key bindings config file\nLoad aborted, Please fix %s" G_DIR_SEPARATOR_S "keybindings\n"),
+							 buf, get_xdir ());
 				fe_message (ibuf, FE_MSG_ERROR);
 				free (ibuf);
 				return 3;
@@ -1078,8 +1078,8 @@ key_load_kbs (char *filename)
 				free (ibuf);
 				ibuf = malloc (1024);
 				snprintf (ibuf, 1024,
-							 _("Expecting Data line (beginning Dx{:|!}) but got:\n%s\n\nLoad aborted, Please fix %s/keybindings\n"),
-							 buf, get_xdir_utf8 ());
+							 _("Expecting Data line (beginning Dx{:|!}) but got:\n%s\n\nLoad aborted, Please fix %s" G_DIR_SEPARATOR_S "keybindings\n"),
+							 buf, get_xdir ());
 				fe_message (ibuf, FE_MSG_ERROR);
 				free (ibuf);
 				return 4;
@@ -1144,12 +1144,12 @@ key_load_kbs (char *filename)
 	return 0;
 
  corrupt_file:
-	/*if (getenv ("XCHAT_DEBUG"))
+	/*if (getenv ("HEXCHAT_DEBUG"))
 		abort ();*/
 	snprintf (ibuf, 1024,
 						_("Key bindings config file is corrupt, load aborted\n"
-								 "Please fix %s/keybindings.conf\n"),
-						 get_xdir_utf8 ());
+								 "Please fix %s" G_DIR_SEPARATOR_S "keybindings.conf\n"),
+						 get_xdir ());
 	fe_message (ibuf, FE_MSG_ERROR);
 	free (ibuf);
 	return 5;
@@ -1459,7 +1459,7 @@ key_action_tab_comp (GtkWidget *t, GdkEventKey *entry, char *d1, char *d2,
 		cursor_pos = g_utf8_pointer_to_offset(text, ch);
 		if (cursor_pos && (g_utf8_get_char_validated(ch, -1) == ':' || 
 					g_utf8_get_char_validated(ch, -1) == ',' ||
-					g_utf8_get_char_validated(ch, -1) == prefs.nick_suffix[0]))
+					g_utf8_get_char_validated(ch, -1) == prefs.hex_completion_suffix[0]))
 		{
 			skip_len++;
 		}
@@ -1482,7 +1482,7 @@ key_action_tab_comp (GtkWidget *t, GdkEventKey *entry, char *d1, char *d2,
 			break;
 	}
 
-	if (ent_start == 0 && text[0] == prefs.cmdchar[0])
+	if (ent_start == 0 && text[0] == prefs.hex_input_command_char[0])
 	{
 		ent_start++;
 		is_cmd = 1;
@@ -1512,7 +1512,7 @@ key_action_tab_comp (GtkWidget *t, GdkEventKey *entry, char *d1, char *d2,
 		{
 			gcomp = g_completion_new((GCompletionFunc)gcomp_nick_func);
 			tmp_list = userlist_double_list(sess); /* create a temp list so we can free the memory */
-			if (prefs.completion_sort == 1)	/* sort in last-talk order? */
+			if (prefs.hex_completion_sort == 1)	/* sort in last-talk order? */
 				tmp_list = g_list_sort (tmp_list, (void *)talked_recent_cmp);
 		}
 		else
@@ -1544,11 +1544,7 @@ key_action_tab_comp (GtkWidget *t, GdkEventKey *entry, char *d1, char *d2,
 			comp = 0;
 		}
 	
-#if GLIB_CHECK_VERSION(2,4,0)
 		list = g_completion_complete_utf8 (gcomp, comp ? old_gcomp.data : ent, &result);
-#else
-		list = g_completion_complete (gcomp, comp ? old_gcomp.data : ent, &result);
-#endif
 		
 		if (result == NULL) /* No matches found */
 		{
@@ -1600,7 +1596,7 @@ key_action_tab_comp (GtkWidget *t, GdkEventKey *entry, char *d1, char *d2,
 			old_gcomp.elen = elen;
 
 			/* Get the first nick and put out the data for future nickcompletes */
-			if (prefs.completion_amount && g_list_length (list) <= prefs.completion_amount)
+			if (prefs.hex_completion_amount && g_list_length (list) <= prefs.hex_completion_amount)
 			{
 				g_free(result);
 				result = (char*)list->data;
@@ -1663,7 +1659,7 @@ key_action_tab_comp (GtkWidget *t, GdkEventKey *entry, char *d1, char *d2,
 			g_utf8_strncpy(buf, text, prefix_len);
 		strncat (buf, result, COMP_BUF - (prefix_len + 3)); /* make sure nicksuffix and space fits */
 		if(!prefix_len && is_nick)
-			strcat (buf, &prefs.nick_suffix[0]);
+			strcat (buf, &prefs.hex_completion_suffix[0]);
 		strcat (buf, " ");
 		cursor_pos = strlen (buf);
 		if (postfix)
@@ -1739,11 +1735,6 @@ key_action_put_history (GtkWidget * wid, GdkEventKey * ent, char *d1,
 
 /* -------- */
 
-
-#define STATE_SHIFT	GDK_SHIFT_MASK
-#define STATE_ALT		GDK_MOD1_MASK
-#define STATE_CTRL	GDK_CONTROL_MASK
-
 static void
 replace_handle (GtkWidget *t)
 {
