@@ -31,59 +31,60 @@
 #include "fe-gtk.h"
 #include "palette.h"
 
-#include "../common/xchat.h"
+#include "../common/hexchat.h"
 #include "../common/util.h"
 #include "../common/cfgfiles.h"
+#include "../common/typedef.h"
 
 
 GdkColor colors[] = {
 	/* colors for xtext */
-	{0, 0xcccc, 0xcccc, 0xcccc}, /* 16 white */
-	{0, 0x0000, 0x0000, 0x0000}, /* 17 black */
-	{0, 0x35c2, 0x35c2, 0xb332}, /* 18 blue */
-	{0, 0x2a3d, 0x8ccc, 0x2a3d}, /* 19 green */
-	{0, 0xc3c3, 0x3b3b, 0x3b3b}, /* 20 red */
-	{0, 0xc7c7, 0x3232, 0x3232}, /* 21 light red */
-	{0, 0x8000, 0x2666, 0x7fff}, /* 22 purple */
-	{0, 0x6666, 0x3636, 0x1f1f}, /* 23 orange */
-	{0, 0xd999, 0xa6d3, 0x4147}, /* 24 yellow */
-	{0, 0x3d70, 0xcccc, 0x3d70}, /* 25 green */
-	{0, 0x199a, 0x5555, 0x5555}, /* 26 aqua */
-	{0, 0x2eef, 0x8ccc, 0x74df}, /* 27 light aqua */
-	{0, 0x451e, 0x451e, 0xe666}, /* 28 blue */
-	{0, 0xb0b0, 0x3737, 0xb0b0}, /* 29 light purple */
-	{0, 0x4c4c, 0x4c4c, 0x4c4c}, /* 30 grey */
-	{0, 0x9595, 0x9595, 0x9595}, /* 31 light grey */
+	{0, 0xd3d3, 0xd7d7, 0xcfcf}, /* 16 white */
+	{0, 0x2e2e, 0x3434, 0x3636}, /* 17 black */
+	{0, 0x3434, 0x6565, 0xa4a4}, /* 18 blue */
+	{0, 0x4e4e, 0x9a9a, 0x0606}, /* 19 green */
+	{0, 0xcccc, 0x0000, 0x0000}, /* 20 red */
+	{0, 0x8f8f, 0x3939, 0x0202}, /* 21 light red */
+	{0, 0x5c5c, 0x3535, 0x6666}, /* 22 purple */
+	{0, 0xcece, 0x5c5c, 0x0000}, /* 23 orange */
+	{0, 0xc4c4, 0xa0a0, 0x0000}, /* 24 yellow */
+	{0, 0x7373, 0xd2d2, 0x1616}, /* 25 green */
+	{0, 0x1111, 0xa8a8, 0x7979}, /* 26 aqua */
+	{0, 0x5858, 0xa1a1, 0x9d9d}, /* 27 light aqua */
+	{0, 0x5757, 0x7979, 0x9e9e}, /* 28 blue */
+	{0, 0xa0d0, 0x42d4, 0x6562}, /* 29 light purple */
+	{0, 0x5555, 0x5757, 0x5353}, /* 30 grey */
+	{0, 0x8888, 0x8a8a, 0x8585}, /* 31 light grey */
 
-	{0, 0xcccc, 0xcccc, 0xcccc}, /* 16 white */
-	{0, 0x0000, 0x0000, 0x0000}, /* 17 black */
-	{0, 0x35c2, 0x35c2, 0xb332}, /* 18 blue */
-	{0, 0x2a3d, 0x8ccc, 0x2a3d}, /* 19 green */
-	{0, 0xc3c3, 0x3b3b, 0x3b3b}, /* 20 red */
-	{0, 0xc7c7, 0x3232, 0x3232}, /* 21 light red */
-	{0, 0x8000, 0x2666, 0x7fff}, /* 22 purple */
-	{0, 0x6666, 0x3636, 0x1f1f}, /* 23 orange */
-	{0, 0xd999, 0xa6d3, 0x4147}, /* 24 yellow */
-	{0, 0x3d70, 0xcccc, 0x3d70}, /* 25 green */
-	{0, 0x199a, 0x5555, 0x5555}, /* 26 aqua */
-	{0, 0x2eef, 0x8ccc, 0x74df}, /* 27 light aqua */
-	{0, 0x451e, 0x451e, 0xe666}, /* 28 blue */
-	{0, 0xb0b0, 0x3737, 0xb0b0}, /* 29 light purple */
-	{0, 0x4c4c, 0x4c4c, 0x4c4c}, /* 30 grey */
-	{0, 0x9595, 0x9595, 0x9595}, /* 31 light grey */
+	{0, 0xd3d3, 0xd7d7, 0xcfcf}, /* 16 white */
+	{0, 0x2e2e, 0x3434, 0x3636}, /* 17 black */
+	{0, 0x3434, 0x6565, 0xa4a4}, /* 18 blue */
+	{0, 0x4e4e, 0x9a9a, 0x0606}, /* 19 green */
+	{0, 0xcccc, 0x0000, 0x0000}, /* 20 red */
+	{0, 0x8f8f, 0x3939, 0x0202}, /* 21 light red */
+	{0, 0x5c5c, 0x3535, 0x6666}, /* 22 purple */
+	{0, 0xcece, 0x5c5c, 0x0000}, /* 23 orange */
+	{0, 0xc4c4, 0xa0a0, 0x0000}, /* 24 yellow */
+	{0, 0x7373, 0xd2d2, 0x1616}, /* 25 green */
+	{0, 0x1111, 0xa8a8, 0x7979}, /* 26 aqua */
+	{0, 0x5858, 0xa1a1, 0x9d9d}, /* 27 light aqua */
+	{0, 0x5757, 0x7979, 0x9e9e}, /* 28 blue */
+	{0, 0xa0d0, 0x42d4, 0x6562}, /* 29 light purple */
+	{0, 0x5555, 0x5757, 0x5353}, /* 30 grey */
+	{0, 0x8888, 0x8a8a, 0x8585}, /* 31 light grey */
 
-	{0, 0xffff, 0xffff, 0xffff}, /* 32 marktext Fore (white) */
-	{0, 0x3535, 0x6e6e, 0xc1c1}, /* 33 marktext Back (blue) */
-	{0, 0x0000, 0x0000, 0x0000}, /* 34 foreground (black) */
-	{0, 0xf0f0, 0xf0f0, 0xf0f0}, /* 35 background (white) */
-	{0, 0xcccc, 0x1010, 0x1010}, /* 36 marker line (red) */
+	{0, 0xd3d3, 0xd7d7, 0xcfcf}, /* 32 marktext Fore (white) */
+	{0, 0x2020, 0x4a4a, 0x8787}, /* 33 marktext Back (blue) */
+	{0, 0x2512, 0x29e8, 0x2b85}, /* 34 foreground (black) */
+	{0, 0xfae0, 0xfae0, 0xf8c4}, /* 35 background (white) */
+	{0, 0x8f8f, 0x3939, 0x0202}, /* 36 marker line (red) */
 
 	/* colors for GUI */
-	{0, 0x9999, 0x0000, 0x0000}, /* 37 tab New Data (dark red) */
-	{0, 0x0000, 0x0000, 0xffff}, /* 38 tab Nick Mentioned (blue) */
-	{0, 0xffff, 0x0000, 0x0000}, /* 39 tab New Message (red) */
-	{0, 0x9595, 0x9595, 0x9595}, /* 40 away user (grey) */
-	{0, 0xffff, 0x0000, 0x0000}, /* 41 spell checker color (red) */
+	{0, 0x3434, 0x6565, 0xa4a4}, /* 37 tab New Data (dark red) */
+	{0, 0x4e4e, 0x9a9a, 0x0606}, /* 38 tab Nick Mentioned (blue) */
+	{0, 0xcece, 0x5c5c, 0x0000}, /* 39 tab New Message (red) */
+	{0, 0x8888, 0x8a8a, 0x8585}, /* 40 away user (grey) */
+	{0, 0xa4a4, 0x0000, 0x0000}, /* 41 spell checker color (red) */
 };
 #define MAX_COL 41
 
@@ -104,7 +105,7 @@ palette_alloc (GtkWidget * widget)
 	}
 }
 
-/* maps XChat 2.0.x colors to current */
+/* maps HexChat 2.0.x colors to current */
 static const int remap[] =
 {
 	0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,
@@ -128,10 +129,10 @@ palette_load (void)
 	int red, green, blue;
 	int upgrade = FALSE;
 
-	fh = xchat_open_file ("colors.conf", O_RDONLY, 0, 0);
+	fh = hexchat_open_file ("colors.conf", O_RDONLY, 0, 0);
 	if (fh == -1)
 	{
-		fh = xchat_open_file ("palette.conf", O_RDONLY, 0, 0);
+		fh = hexchat_open_file ("palette.conf", O_RDONLY, 0, 0);
 		upgrade = TRUE;
 	}
 
@@ -210,7 +211,7 @@ palette_save (void)
 	int i, j, fh;
 	char prefname[256];
 
-	fh = xchat_open_file ("colors.conf", O_TRUNC | O_WRONLY | O_CREAT, 0600, XOF_DOMODE);
+	fh = hexchat_open_file ("colors.conf", O_TRUNC | O_WRONLY | O_CREAT, 0600, XOF_DOMODE);
 	if (fh != -1)
 	{
 		/* mIRC colors 0-31 are here */
