@@ -22,7 +22,7 @@
 
 #include "fe-gtk.h"
 #include "../common/cfgfiles.h"
-#include "../common/xchat.h"
+#include "../common/hexchat.h"
 #include "../common/fe.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -31,24 +31,24 @@
 
 #include "../pixmaps/inline_pngs.h"
 
-GdkPixbuf *pix_xchat;
+GdkPixbuf *pix_ulist_voice;
+GdkPixbuf *pix_ulist_halfop;
+GdkPixbuf *pix_ulist_op;
+GdkPixbuf *pix_ulist_owner;
+GdkPixbuf *pix_ulist_founder;
+GdkPixbuf *pix_ulist_netop;
+
+GdkPixbuf *pix_tray_fileoffer;
+GdkPixbuf *pix_tray_highlight;
+GdkPixbuf *pix_tray_message;
+
+GdkPixbuf *pix_tree_channel;
+GdkPixbuf *pix_tree_dialog;
+GdkPixbuf *pix_tree_server;
+GdkPixbuf *pix_tree_util;
+
 GdkPixbuf *pix_book;
-
-GdkPixbuf *pix_purple;
-GdkPixbuf *pix_red;
-GdkPixbuf *pix_op;
-GdkPixbuf *pix_hop;
-GdkPixbuf *pix_voice;
-
-GdkPixbuf *pix_tray_msg;
-GdkPixbuf *pix_tray_hilight;
-GdkPixbuf *pix_tray_file;
-
-GdkPixbuf *pix_channel;
-GdkPixbuf *pix_dialog;
-GdkPixbuf *pix_server;
-GdkPixbuf *pix_util;
-
+GdkPixbuf *pix_hexchat;
 
 static GdkPixmap *
 pixmap_load_from_file_real (char *file)
@@ -60,7 +60,7 @@ pixmap_load_from_file_real (char *file)
 	if (!img)
 		return NULL;
 	gdk_pixbuf_render_pixmap_and_mask (img, &pixmap, NULL, 128);
-	gdk_pixbuf_unref (img);
+	g_object_unref (img);
 
 	return pixmap;
 }
@@ -105,7 +105,7 @@ load_pixmap (const char *filename, const char *name, int has_inline)
 	gchar *path;
 	GdkPixbuf *pixbuf;
 
-	path = g_strdup_printf ("%s/icons/%s.png", get_xdir_utf8 (), filename);
+	path = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "icons" G_DIR_SEPARATOR_S "%s.png", get_xdir (), filename);
 	pixbuf = gdk_pixbuf_new_from_file (path, 0);
 	g_free (path);
 
@@ -120,33 +120,34 @@ load_pixmap (const char *filename, const char *name, int has_inline)
 void
 pixmaps_init (void)
 {
-	pix_book = gdk_pixbuf_new_from_inline (-1, bookpng, FALSE, 0);
-
-	/* used in About window, tray icon and WindowManager icon. */
-	pix_xchat = load_pixmap ("hexchat", hexchatpng, 1);
-
 	/* userlist icons, with inlined defaults */
-	pix_hop = load_pixmap ("hop", hoppng, 1);
-	pix_purple = load_pixmap ("purple", purplepng, 1);
-	pix_red = load_pixmap ("red", redpng, 1);
-	pix_op = load_pixmap ("op", oppng, 1);
-	pix_voice = load_pixmap ("voice", voicepng, 1);
+	pix_ulist_voice = load_pixmap ("ulist_voice", png_ulist_voice, 1);
+	pix_ulist_halfop = load_pixmap ("ulist_halfop", png_ulist_halfop, 1);
+	pix_ulist_op = load_pixmap ("ulist_op", png_ulist_op, 1);
+	pix_ulist_owner = load_pixmap ("ulist_owner", png_ulist_owner, 1);
+	pix_ulist_founder = load_pixmap ("ulist_founder", png_ulist_founder, 1);
+	pix_ulist_netop = load_pixmap ("ulist_netop", png_ulist_netop, 1);
 
 	/* tray icons, with inlined defaults */
-	pix_tray_msg = load_pixmap ("message", traymsgpng, 1);
-	pix_tray_hilight = load_pixmap ("highlight", trayhilightpng, 1);
-	pix_tray_file = load_pixmap ("fileoffer", trayfilepng, 1);
+	pix_tray_fileoffer = load_pixmap ("tray_fileoffer", png_tray_fileoffer, 1);
+	pix_tray_highlight = load_pixmap ("highlight", png_tray_highlight, 1);
+	pix_tray_message = load_pixmap ("message", png_tray_message, 1);
 
 #if 0
 	/* treeview icons, no defaults, load from disk only */
-	pix_channel = load_pixmap ("channel", NULL, 0);
-	pix_dialog = load_pixmap ("dialog", NULL, 0);
-	pix_server = load_pixmap ("server", NULL, 0);
-	pix_util = load_pixmap ("util", NULL, 0);
+	pix_tree_channel = load_pixmap ("tree_channel", NULL, 0);
+	pix_tree_dialog = load_pixmap ("tree_dialog", NULL, 0);
+	pix_tree_server = load_pixmap ("tree_server", NULL, 0);
+	pix_tree_util = load_pixmap ("tree_util", NULL, 0);
 #endif
 	/* provide inline defaults for these coz they are nice! */
-	pix_channel = load_pixmap ("channel", channelpng, 1);
-	pix_dialog = load_pixmap ("dialog", dialogpng, 1);
-	pix_server = load_pixmap ("server", serverpng, 1);
-	pix_util = load_pixmap ("util", utilpng, 1);
+	pix_tree_channel = load_pixmap ("tree_channel", png_tree_channel, 1);
+	pix_tree_dialog = load_pixmap ("tree_dialog", png_tree_dialog, 1);
+	pix_tree_server = load_pixmap ("tree_server", png_tree_server, 1);
+	pix_tree_util = load_pixmap ("tree_util", png_tree_util, 1);
+
+	/* non-replaceable book pixmap */
+	pix_book = gdk_pixbuf_new_from_inline (-1, png_book, FALSE, 0);
+	/* used in About window, tray icon and WindowManager icon. */
+	pix_hexchat = load_pixmap ("hexchat", png_hexchat, 1);
 }
