@@ -1,9 +1,9 @@
 /* Copyright (C) 2006-2007 Peter Zelezny. */
 
 #include <string.h>
-#include "../common/xchat-plugin.h"
-#include "../common/xchat.h"
-#include "../common/xchatc.h"
+#include "../common/hexchat-plugin.h"
+#include "../common/hexchat.h"
+#include "../common/hexchatc.h"
 #include "../common/inbound.h"
 #include "../common/server.h"
 #include "../common/fe.h"
@@ -51,16 +51,16 @@ typedef GdkPixbuf* TrayIcon;
 #define tray_icon_from_file(f) gdk_pixbuf_new_from_file(f,NULL)
 #define tray_icon_free(i) g_object_unref(i)
 
-#define ICON_NORMAL pix_xchat
-#define ICON_MSG pix_tray_msg
-#define ICON_HILIGHT pix_tray_hilight
-#define ICON_FILE pix_tray_file
+#define ICON_NORMAL pix_hexchat
+#define ICON_MSG pix_tray_message
+#define ICON_HILIGHT pix_tray_highlight
+#define ICON_FILE pix_tray_fileoffer
 #define TIMEOUT 500
 
 static GtkStatusIcon *sticon;
 static gint flash_tag;
 static TrayStatus tray_status;
-static xchat_plugin *ph;
+static hexchat_plugin *ph;
 
 static TrayIcon custom_icon1;
 static TrayIcon custom_icon2;
@@ -79,7 +79,7 @@ tray_get_window_status (void)
 {
 	const char *st;
 
-	st = xchat_get_info (ph, "win_status");
+	st = hexchat_get_info (ph, "win_status");
 
 	if (!st)
 		return WS_HIDDEN;
@@ -148,7 +148,7 @@ fe_tray_set_balloon (const char *title, const char *text)
 		return;
 
 	/* bit 1 of flags means "no balloons unless hidden/iconified" */
-	if (ws != WS_HIDDEN && (prefs.gui_tray_flags & 2))
+	if (ws != WS_HIDDEN && prefs.hex_gui_tray_quiet)
 		return;
 
 	/* FIXME: this should close the current balloon */
@@ -170,7 +170,7 @@ fe_tray_set_balloon (const char *title, const char *text)
 	g_free ((char *)notify_title);
 	g_free ((char *)notify_text);
 
-	notify_notification_set_timeout (notification, prefs.input_balloon_time*1000);
+	notify_notification_set_timeout (notification, prefs.hex_input_balloon_time*1000);
 	notify_notification_show (notification, NULL);
 
 	g_object_unref (notification);
@@ -374,9 +374,9 @@ tray_toggle_visibility (gboolean force_hide)
 		return FALSE;
 
 	/* ph may have an invalid context now */
-	xchat_set_context (ph, xchat_find_context (ph, NULL, NULL));
+	hexchat_set_context (ph, hexchat_find_context (ph, NULL, NULL));
 
-	win = xchat_get_info (ph, "gtkwin_ptr");
+	win = GTK_WINDOW (hexchat_get_info (ph, "gtkwin_ptr"));
 
 	tray_stop_flash ();
 	tray_reset_counts ();
@@ -507,7 +507,7 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 #endif
 
 	/* ph may have an invalid context now */
-	xchat_set_context (ph, xchat_find_context (ph, NULL, NULL));
+	hexchat_set_context (ph, hexchat_find_context (ph, NULL, NULL));
 
 	menu = gtk_menu_new ();
 	/*gtk_menu_set_screen (GTK_MENU (menu), gtk_widget_get_screen (widget));*/
@@ -520,9 +520,9 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 
 #ifndef WIN32 /* somehow this is broken on win32 */
 	submenu = mg_submenu (menu, _("_Blink on"));
-	blink_item (&prefs.input_tray_chans, submenu, _("Channel Message"));
-	blink_item (&prefs.input_tray_priv, submenu, _("Private Message"));
-	blink_item (&prefs.input_tray_hilight, submenu, _("Highlighted Message"));
+	blink_item (&prefs.hex_input_tray_chans, submenu, _("Channel Message"));
+	blink_item (&prefs.hex_input_tray_priv, submenu, _("Private Message"));
+	blink_item (&prefs.hex_input_tray_hilight, submenu, _("Highlighted Message"));
 	/*blink_item (BIT_FILEOFFER, submenu, _("File Offer"));*/
 
 	submenu = mg_submenu (menu, _("_Change status"));
@@ -576,9 +576,9 @@ static int
 tray_hilight_cb (char *word[], void *userdata)
 {
 	/*if (tray_status == TS_HIGHLIGHT)
-		return XCHAT_EAT_NONE;*/
+		return HEXCHAT_EAT_NONE;*/
 
-	if (prefs.input_tray_hilight && !prefs.away_omit_alerts)
+	if (prefs.hex_input_tray_hilight && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 	{
 		tray_set_flash (ICON_HILIGHT);
 
@@ -586,42 +586,42 @@ tray_hilight_cb (char *word[], void *userdata)
 		tray_hilight_count++;
 		if (tray_hilight_count == 1)
 			tray_set_tipf (_(DISPLAY_NAME": Highlighted message from: %s (%s)"),
-								word[1], xchat_get_info (ph, "channel"));
+								word[1], hexchat_get_info (ph, "channel"));
 		else
 			tray_set_tipf (_(DISPLAY_NAME": %u highlighted messages, latest from: %s (%s)"),
-								tray_hilight_count, word[1], xchat_get_info (ph, "channel"));
+								tray_hilight_count, word[1], hexchat_get_info (ph, "channel"));
 	}
 
-	if (prefs.input_balloon_hilight && !prefs.away_omit_alerts)
+	if (prefs.hex_input_balloon_hilight && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 		tray_set_balloonf (word[2], _(DISPLAY_NAME": Highlighted message from: %s (%s)"),
-								 word[1], xchat_get_info (ph, "channel"));
+								 word[1], hexchat_get_info (ph, "channel"));
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static int
 tray_message_cb (char *word[], void *userdata)
 {
 	if (/*tray_status == TS_MESSAGE ||*/ tray_status == TS_HIGHLIGHT)
-		return XCHAT_EAT_NONE;
+		return HEXCHAT_EAT_NONE;
 
-	if (prefs.input_tray_chans && !prefs.away_omit_alerts)
+	if (prefs.hex_input_tray_chans && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 	{
 		tray_set_flash (ICON_MSG);
 
 		tray_pub_count++;
 		if (tray_pub_count == 1)
 			tray_set_tipf (_(DISPLAY_NAME": New public message from: %s (%s)"),
-								word[1], xchat_get_info (ph, "channel"));
+								word[1], hexchat_get_info (ph, "channel"));
 		else
 			tray_set_tipf (_(DISPLAY_NAME": %u new public messages."), tray_pub_count);
 	}
 
-	if (prefs.input_balloon_chans && !prefs.away_omit_alerts)
+	if (prefs.hex_input_balloon_chans && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 		tray_set_balloonf (word[2], _(DISPLAY_NAME": New public message from: %s (%s)"),
-								 word[1], xchat_get_info (ph, "channel"));
+								 word[1], hexchat_get_info (ph, "channel"));
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static void
@@ -629,14 +629,14 @@ tray_priv (char *from, char *text)
 {
 	const char *network;
 
-	if (alert_match_word (from, prefs.irc_no_hilight))
+	if (alert_match_word (from, prefs.hex_irc_no_hilight))
 		return;
 
 	tray_set_flash (ICON_MSG);
 
-	network = xchat_get_info (ph, "network");
+	network = hexchat_get_info (ph, "network");
 	if (!network)
-		network = xchat_get_info (ph, "server");
+		network = hexchat_get_info (ph, "server");
 
 	tray_priv_count++;
 	if (tray_priv_count == 1)
@@ -646,7 +646,7 @@ tray_priv (char *from, char *text)
 		tray_set_tipf (_(DISPLAY_NAME": %u private messages, latest from: %s (%s)"),
 							tray_priv_count, from, network);
 
-	if (prefs.input_balloon_priv && !prefs.away_omit_alerts)
+	if (prefs.hex_input_balloon_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 		tray_set_balloonf (text, _(DISPLAY_NAME": Private message from: %s (%s)"),
 								 from, network);
 }
@@ -655,24 +655,24 @@ static int
 tray_priv_cb (char *word[], void *userdata)
 {
 	/*if (tray_status == TS_HIGHLIGHT)
-		return XCHAT_EAT_NONE;*/
+		return HEXCHAT_EAT_NONE;*/
 
-	if (prefs.input_tray_priv && !prefs.away_omit_alerts)
+	if (prefs.hex_input_tray_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 		tray_priv (word[1], word[2]);
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static int
 tray_invited_cb (char *word[], void *userdata)
 {
 	/*if (tray_status == TS_HIGHLIGHT)
-		return XCHAT_EAT_NONE;*/
+		return HEXCHAT_EAT_NONE;*/
 
-	if (prefs.input_tray_priv && !prefs.away_omit_alerts)
+	if (prefs.hex_input_tray_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 		tray_priv (word[2], "Invited");
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static int
@@ -681,13 +681,13 @@ tray_dcc_cb (char *word[], void *userdata)
 	const char *network;
 
 /*	if (tray_status == TS_FILEOFFER)
-		return XCHAT_EAT_NONE;*/
+		return HEXCHAT_EAT_NONE;*/
 
-	network = xchat_get_info (ph, "network");
+	network = hexchat_get_info (ph, "network");
 	if (!network)
-		network = xchat_get_info (ph, "server");
+		network = hexchat_get_info (ph, "server");
 
-	if (prefs.input_tray_priv && !prefs.away_omit_alerts)
+	if (prefs.hex_input_tray_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 	{
 		tray_set_flash (ICON_FILE);
 
@@ -700,11 +700,11 @@ tray_dcc_cb (char *word[], void *userdata)
 								tray_file_count, word[1], network);
 	}
 
-	if (prefs.input_balloon_priv && !prefs.away_omit_alerts)
+	if (prefs.hex_input_balloon_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
 		tray_set_balloonf ("", _(DISPLAY_NAME": File offer from: %s (%s)"),
 								word[1], network);
 
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static int
@@ -712,7 +712,7 @@ tray_focus_cb (char *word[], void *userdata)
 {
 	tray_stop_flash ();
 	tray_reset_counts ();
-	return XCHAT_EAT_NONE;
+	return HEXCHAT_EAT_NONE;
 }
 
 static void
@@ -732,51 +732,51 @@ tray_apply_setup (void)
 {
 	if (sticon)
 	{
-		if (!prefs.gui_tray)
+		if (!prefs.hex_gui_tray)
 			tray_cleanup ();
 	}
 	else
 	{
-		if (prefs.gui_tray && !hextray_mode ())
+		if (prefs.hex_gui_tray && !hextray_mode ())
 			tray_init ();
 	}
 }
 
 int
-tray_plugin_init (xchat_plugin *plugin_handle, char **plugin_name,
+tray_plugin_init (hexchat_plugin *plugin_handle, char **plugin_name,
 				char **plugin_desc, char **plugin_version, char *arg)
 {
-	/* we need to save this for use with any xchat_* functions */
+	/* we need to save this for use with any hexchat_* functions */
 	ph = plugin_handle;
 
 	*plugin_name = "";
 	*plugin_desc = "";
 	*plugin_version = "";
 
-	xchat_hook_print (ph, "Channel Msg Hilight", -1, tray_hilight_cb, NULL);
-	xchat_hook_print (ph, "Channel Action Hilight", -1, tray_hilight_cb, NULL);
+	hexchat_hook_print (ph, "Channel Msg Hilight", -1, tray_hilight_cb, NULL);
+	hexchat_hook_print (ph, "Channel Action Hilight", -1, tray_hilight_cb, NULL);
 
-	xchat_hook_print (ph, "Channel Message", -1, tray_message_cb, NULL);
-	xchat_hook_print (ph, "Channel Action", -1, tray_message_cb, NULL);
-	xchat_hook_print (ph, "Channel Notice", -1, tray_message_cb, NULL);
+	hexchat_hook_print (ph, "Channel Message", -1, tray_message_cb, NULL);
+	hexchat_hook_print (ph, "Channel Action", -1, tray_message_cb, NULL);
+	hexchat_hook_print (ph, "Channel Notice", -1, tray_message_cb, NULL);
 
-	xchat_hook_print (ph, "Private Message", -1, tray_priv_cb, NULL);
-	xchat_hook_print (ph, "Private Message to Dialog", -1, tray_priv_cb, NULL);
-	xchat_hook_print (ph, "Notice", -1, tray_priv_cb, NULL);
-	xchat_hook_print (ph, "Invited", -1, tray_invited_cb, NULL);
+	hexchat_hook_print (ph, "Private Message", -1, tray_priv_cb, NULL);
+	hexchat_hook_print (ph, "Private Message to Dialog", -1, tray_priv_cb, NULL);
+	hexchat_hook_print (ph, "Notice", -1, tray_priv_cb, NULL);
+	hexchat_hook_print (ph, "Invited", -1, tray_invited_cb, NULL);
 
-	xchat_hook_print (ph, "DCC Offer", -1, tray_dcc_cb, NULL);
+	hexchat_hook_print (ph, "DCC Offer", -1, tray_dcc_cb, NULL);
 
-	xchat_hook_print (ph, "Focus Window", -1, tray_focus_cb, NULL);
+	hexchat_hook_print (ph, "Focus Window", -1, tray_focus_cb, NULL);
 
-	if (prefs.gui_tray && !hextray_mode ())
+	if (prefs.hex_gui_tray && !hextray_mode ())
 		tray_init ();
 
 	return 1;       /* return 1 for success */
 }
 
 int
-tray_plugin_deinit (xchat_plugin *plugin_handle)
+tray_plugin_deinit (hexchat_plugin *plugin_handle)
 {
 #ifdef WIN32
 	tray_cleanup ();
