@@ -32,16 +32,18 @@
 #include <gtk/gtkwindow.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "../common/xchat.h"
-#include "../common/xchatc.h"
+#include "../common/hexchat.h"
+#include "../common/hexchatc.h"
 #include "../common/servlist.h"
 #include "../common/cfgfiles.h"
 #include "../common/fe.h"
+#include "../common/util.h"
 
 #include "fe-gtk.h"
 #include "gtkutil.h"
 #include "menu.h"
 #include "pixmaps.h"
+#include "fkeys.h"
 
 
 /* servlistgui.c globals */
@@ -71,6 +73,7 @@ static GtkWidget *edit_entry_user;
 static GtkWidget *edit_entry_real;
 static GtkWidget *edit_entry_join;
 static GtkWidget *edit_entry_pass;
+static GtkWidget *edit_entry_saslpass;
 static GtkWidget *edit_entry_cmd;
 static GtkWidget *edit_entry_nickserv;
 static GtkWidget *edit_label_nick;
@@ -91,7 +94,7 @@ static GtkWidget *servlist_open_edit (GtkWidget *parent, ircnet *net);
 static const char *pages[]=
 {
 	"UTF-8 (Unicode)",
-	"IRC (Latin/Unicode Hybrid)",
+	IRC_DEFAULT_CHARSET,
 	"ISO-8859-15 (Western Europe)",
 	"ISO-8859-2 (Central Europe)",
 	"ISO-8859-7 (Greek)",
@@ -185,7 +188,7 @@ servlist_networks_populate_ (GtkWidget *treeview, GSList *netlist, gboolean favo
 				gtk_list_store_insert_with_values (store, &iter, 0x7fffffff, 0, net->name, 1, 1, 2, 400, -1);
 			else
 				gtk_list_store_insert_with_values (store, &iter, 0x7fffffff, 0, net->name, 1, 1, 2, (net->flags & FLAG_FAVORITE) ? 800 : 400, -1);
-			if (i == prefs.slist_select)
+			if (i == prefs.hex_gui_slist_select)
 			{
 				/* select this network */
 				servlist_select_and_show (GTK_TREE_VIEW (treeview), &iter, store);
@@ -200,7 +203,7 @@ servlist_networks_populate_ (GtkWidget *treeview, GSList *netlist, gboolean favo
 static void
 servlist_networks_populate (GtkWidget *treeview, GSList *netlist)
 {
-	servlist_networks_populate_ (treeview, netlist, prefs.slist_fav);
+	servlist_networks_populate_ (treeview, netlist, prefs.hex_gui_slist_fav);
 }
 
 static void
@@ -278,7 +281,7 @@ servlist_addnet_cb (GtkWidget *item, GtkTreeView *treeview)
 	ircnet *net;
 
 	net = servlist_net_add (_("New Network"), "", TRUE);
-	net->encoding = strdup ("IRC (Latin/Unicode Hybrid)");
+	net->encoding = strdup (IRC_DEFAULT_CHARSET);
 	servlist_server_add (net, "newserver/6667");
 
 	store = (GtkListStore *)gtk_tree_view_get_model (treeview);
@@ -351,7 +354,7 @@ servlist_move_network (ircnet *net, int delta)
 		pos += delta;
 		if (pos >= 0)
 		{
-			/*prefs.slist_select += delta;*/
+			/*prefs.hex_gui_slist_select += delta;*/
 			network_list = g_slist_remove (network_list, net);
 			network_list = g_slist_insert (network_list, net, pos);
 			servlist_networks_populate (networks_tree, network_list);
@@ -365,7 +368,7 @@ servlist_net_keypress_cb (GtkWidget *wid, GdkEventKey *evt, gpointer tree)
 	if (!selected_net)
 		return FALSE;
 
-	if (evt->state & GDK_SHIFT_MASK)
+	if (evt->state & STATE_SHIFT)
 	{
 		if (evt->keyval == GDK_Up)
 		{
@@ -386,7 +389,7 @@ servlist_serv_keypress_cb (GtkWidget *wid, GdkEventKey *evt, gpointer userdata)
 	if (!selected_net || !selected_serv)
 		return FALSE;
 
-	if (evt->state & GDK_SHIFT_MASK)
+	if (evt->state & STATE_SHIFT)
 	{
 		if (evt->keyval == GDK_Up)
 		{
@@ -488,6 +491,7 @@ servlist_edit_update (ircnet *net)
 	servlist_update_from_entry (&net->command, edit_entry_cmd);
 	servlist_update_from_entry (&net->nickserv, edit_entry_nickserv);
 	servlist_update_from_entry (&net->pass, edit_entry_pass);
+	servlist_update_from_entry (&net->saslpass, edit_entry_saslpass);
 }
 
 static void
@@ -622,7 +626,7 @@ servlist_find_selected_net (GtkTreeSelection *sel)
 		net = servlist_net_find (netname, &pos, strcmp);
 		g_free (netname);
 		if (net)
-			prefs.slist_select = pos;
+			prefs.hex_gui_slist_select = pos;
 	}
 
 	return net;
@@ -652,14 +656,14 @@ servlist_savegui (void)
 	/* if (GTK_ENTRY (entry_greal)->text[0] == 0)
 		return 1; */
 
-	strcpy (prefs.nick1, GTK_ENTRY (entry_nick1)->text);
-	strcpy (prefs.nick2, GTK_ENTRY (entry_nick2)->text);
-	strcpy (prefs.nick3, GTK_ENTRY (entry_nick3)->text);
-	strcpy (prefs.username, GTK_ENTRY (entry_guser)->text);
-	sp = strchr (prefs.username, ' ');
+	strcpy (prefs.hex_irc_nick1, GTK_ENTRY (entry_nick1)->text);
+	strcpy (prefs.hex_irc_nick2, GTK_ENTRY (entry_nick2)->text);
+	strcpy (prefs.hex_irc_nick3, GTK_ENTRY (entry_nick3)->text);
+	strcpy (prefs.hex_irc_user_name, GTK_ENTRY (entry_guser)->text);
+	sp = strchr (prefs.hex_irc_user_name, ' ');
 	if (sp)
 		sp[0] = 0;	/* spaces will break the login */
-	/* strcpy (prefs.realname, GTK_ENTRY (entry_greal)->text); */
+	/* strcpy (prefs.hex_irc_real_name, GTK_ENTRY (entry_greal)->text); */
 	servlist_save ();
 
 	return 0;
@@ -1220,7 +1224,7 @@ servlist_delete_cb (GtkWidget *win, GdkEventAny *event, gpointer userdata)
 	selected_net = NULL;
 
 	if (sess_list == NULL)
-		xchat_exit ();
+		hexchat_exit ();
 
 	return FALSE;
 }
@@ -1234,7 +1238,7 @@ servlist_close_cb (GtkWidget *button, gpointer userdata)
 	selected_net = NULL;
 
 	if (sess_list == NULL)
-		xchat_exit ();
+		hexchat_exit ();
 }
 
 /* convert "host:port" format to "host/port" */
@@ -1338,18 +1342,18 @@ static void
 no_servlist (GtkWidget * igad, gpointer serv)
 {
 	if (GTK_TOGGLE_BUTTON (igad)->active)
-		prefs.slist_skip = TRUE;
+		prefs.hex_gui_slist_skip = TRUE;
 	else
-		prefs.slist_skip = FALSE;
+		prefs.hex_gui_slist_skip = FALSE;
 }
 
 static void
 fav_servlist (GtkWidget * igad, gpointer serv)
 {
 	if (GTK_TOGGLE_BUTTON (igad)->active)
-		prefs.slist_fav = TRUE;
+		prefs.hex_gui_slist_fav = TRUE;
 	else
-		prefs.slist_fav = FALSE;
+		prefs.hex_gui_slist_fav = FALSE;
 
 	servlist_networks_populate (networks_tree, network_list);
 }
@@ -1498,9 +1502,15 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 					_("Password for the server, if in doubt, leave blank."));
 	gtk_entry_set_visibility (GTK_ENTRY (edit_entry_pass), FALSE);
 
+	edit_entry_saslpass =
+		servlist_create_entry (table3, _("SASL password:"), 19,
+									  net->saslpass, 0,
+					_("Password for SASL authentication, if in doubt, leave blank."));
+	gtk_entry_set_visibility (GTK_ENTRY (edit_entry_saslpass), FALSE);
+
 	label34 = gtk_label_new (_("Character set:"));
 	gtk_widget_show (label34);
-	gtk_table_attach (GTK_TABLE (table3), label34, 1, 2, 19, 20,
+	gtk_table_attach (GTK_TABLE (table3), label34, 1, 2, 20, 21,
 							(GtkAttachOptions) (GTK_FILL),
 							(GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label34), 0, 0.5);
@@ -1510,7 +1520,7 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (comboboxentry_charset)->child), net->encoding ? net->encoding : "System default");
 	ignore_changed = FALSE;
 	gtk_widget_show (comboboxentry_charset);
-	gtk_table_attach (GTK_TABLE (table3), comboboxentry_charset, 2, 3, 19, 20,
+	gtk_table_attach (GTK_TABLE (table3), comboboxentry_charset, 2, 3, 20, 21,
 							(GtkAttachOptions) (GTK_FILL),
 							(GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -1711,35 +1721,35 @@ servlist_open_networks (void)
 	gtk_misc_set_alignment (GTK_MISC (label7), 0, 0.5);*/
 
 	entry_nick1 = entry1 = gtk_entry_new ();
-	gtk_entry_set_text (GTK_ENTRY (entry1), prefs.nick1);
+	gtk_entry_set_text (GTK_ENTRY (entry1), prefs.hex_irc_nick1);
 	gtk_widget_show (entry1);
 	gtk_table_attach (GTK_TABLE (table1), entry1, 1, 2, 0, 1,
 							(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 							(GtkAttachOptions) (0), 0, 0);
 
 	entry_nick2 = entry2 = gtk_entry_new ();
-	gtk_entry_set_text (GTK_ENTRY (entry2), prefs.nick2);
+	gtk_entry_set_text (GTK_ENTRY (entry2), prefs.hex_irc_nick2);
 	gtk_widget_show (entry2);
 	gtk_table_attach (GTK_TABLE (table1), entry2, 1, 2, 1, 2,
 							(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 							(GtkAttachOptions) (0), 0, 0);
 
 	entry_nick3 = entry3 = gtk_entry_new ();
-	gtk_entry_set_text (GTK_ENTRY (entry3), prefs.nick3);
+	gtk_entry_set_text (GTK_ENTRY (entry3), prefs.hex_irc_nick3);
 	gtk_widget_show (entry3);
 	gtk_table_attach (GTK_TABLE (table1), entry3, 1, 2, 2, 3,
 							(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 							(GtkAttachOptions) (0), 0, 0);
 
 	entry_guser = entry4 = gtk_entry_new ();
-	gtk_entry_set_text (GTK_ENTRY (entry4), prefs.username);
+	gtk_entry_set_text (GTK_ENTRY (entry4), prefs.hex_irc_user_name);
 	gtk_widget_show (entry4);
 	gtk_table_attach (GTK_TABLE (table1), entry4, 1, 2, 3, 4,
 							(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 							(GtkAttachOptions) (0), 0, 0);
 
 	/* entry_greal = entry5 = gtk_entry_new ();
-	gtk_entry_set_text (GTK_ENTRY (entry5), prefs.realname);
+	gtk_entry_set_text (GTK_ENTRY (entry5), prefs.hex_irc_real_name);
 	gtk_widget_show (entry5);
 	gtk_table_attach (GTK_TABLE (table1), entry5, 1, 2, 4, 5,
 							(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -1799,7 +1809,7 @@ servlist_open_networks (void)
 	checkbutton_skip =
 		gtk_check_button_new_with_mnemonic (_("Skip network list on startup"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton_skip),
-											prefs.slist_skip);
+											prefs.hex_gui_slist_skip);
 	gtk_container_add (GTK_CONTAINER (hbox), checkbutton_skip);
 	g_signal_connect (G_OBJECT (checkbutton_skip), "toggled",
 							G_CALLBACK (no_servlist), 0);
@@ -1808,7 +1818,7 @@ servlist_open_networks (void)
 	checkbutton_fav =
 		gtk_check_button_new_with_mnemonic (_("Show favorites only"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton_fav),
-											prefs.slist_fav);
+											prefs.hex_gui_slist_fav);
 	gtk_container_add (GTK_CONTAINER (hbox), checkbutton_fav);
 	g_signal_connect (G_OBJECT (checkbutton_fav), "toggled",
 							G_CALLBACK (fav_servlist), 0);
