@@ -34,11 +34,14 @@
 #include "sexy-marshal.h"
 
 #ifdef WIN32
-#include "typedef.h"
+#include "../common/typedef.h"
+#include <io.h>
+#else
+#include <unistd.h>
 #endif
 
 #include "../common/cfgfiles.h"
-#include "../common/xchatc.h"
+#include "../common/hexchatc.h"
 
 /*
  * Bunch of poop to make enchant into a runtime dependency rather than a
@@ -283,7 +286,7 @@ insert_underline(SexySpellEntry *entry, guint start, guint end)
 	PangoAttribute *ucolor;
 	PangoAttribute *unline;
 
-	fh = xchat_open_file ("colors.conf", O_RDONLY, 0, 0);
+	fh = hexchat_open_file ("colors.conf", O_RDONLY, 0, 0);
 
 	if (fh != -1)
 	{
@@ -932,6 +935,7 @@ sexy_spell_entry_changed(GtkEditable *editable, gpointer data)
 	sexy_spell_entry_recheck_all(entry);
 }
 
+#if 0
 static gboolean
 enchant_has_lang(const gchar *lang, GSList *langs) {
 	GSList *i;
@@ -942,6 +946,7 @@ enchant_has_lang(const gchar *lang, GSList *langs) {
 	}
 	return FALSE;
 }
+#endif
 
 /**
  * sexy_spell_entry_activate_default_languages:
@@ -991,7 +996,7 @@ sexy_spell_entry_activate_default_languages(SexySpellEntry *entry)
 
 	for (i = enchant_langs; i; i = g_slist_next (i))
 	{
-		if (strstr (prefs.spell_langs, i->data) != NULL)
+		if (strstr (prefs.hex_text_spell_langs, i->data) != NULL)
 		{
 			sexy_spell_entry_activate_language_internal (entry, i->data, NULL);
 		}
