@@ -34,12 +34,12 @@
 #include <gtk/gtkliststore.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "../common/xchat.h"
+#include "../common/hexchat.h"
 #include "../common/util.h"
 #include "../common/userlist.h"
 #include "../common/modes.h"
 #include "../common/notify.h"
-#include "../common/xchatc.h"
+#include "../common/hexchatc.h"
 #include "../common/fe.h"
 #include "gtkutil.h"
 #include "palette.h"
@@ -47,6 +47,7 @@
 #include "menu.h"
 #include "pixmaps.h"
 #include "userlistgui.h"
+#include "fkeys.h"
 
 #ifdef USE_GTKSPELL
 #include <gtk/gtktextview.h>
@@ -75,10 +76,10 @@ get_user_icon (server *serv, struct User *user)
 	/* these ones are hardcoded */
 	switch (user->prefix[0])
 	{
-	case 0: return NULL;
-	case '@': return pix_op;
-	case '%': return pix_hop;
-	case '+': return pix_voice;
+		case 0: return NULL;
+		case '+': return pix_ulist_voice;
+		case '%': return pix_ulist_halfop;
+		case '@': return pix_ulist_op;
 	}
 
 	/* find out how many levels above Op this user is */
@@ -93,10 +94,11 @@ get_user_icon (server *serv, struct User *user)
 			{
 				switch (level)
 				{
-				case 0: return pix_red;	/* 1 level above op */
-				case 1: return pix_purple;	 /* 2 levels above op */
+					case 0: return pix_ulist_owner;		/* 1 level above op */
+					case 1: return pix_ulist_founder;	/* 2 levels above op */
+					case 2: return pix_ulist_netop;		/* 3 levels above op */
 				}
-				break;	/* 3+, no icons */
+				break;	/* 4+, no icons */
 			}
 			level++;
 			if (pre == serv->nick_prefixes)
@@ -125,7 +127,7 @@ fe_userlist_numbers (session *sess)
 			gtk_label_set_text (GTK_LABEL (sess->gui->namelistinfo), NULL);
 		}
 
-		if (sess->type == SESS_CHANNEL && prefs.gui_tweaks & 1)
+		if (sess->type == SESS_CHANNEL && prefs.hex_gui_win_ucount)
 			fe_set_title (sess);
 	}
 }
@@ -332,7 +334,7 @@ fe_userlist_rehash (session *sess, struct User *user)
 	if (!iter)
 		return;
 
-	if (prefs.away_size_max < 1 || !prefs.away_track)
+	if (prefs.hex_away_size_max < 1 || !prefs.hex_away_track)
 		do_away = FALSE;
 
 	gtk_list_store_set (GTK_LIST_STORE (sess->res->user_model), iter,
@@ -352,11 +354,11 @@ fe_userlist_insert (session *sess, struct User *newuser, int row, int sel)
 	int do_away = TRUE;
 	char *nick;
 
-	if (prefs.away_size_max < 1 || !prefs.away_track)
+	if (prefs.hex_away_size_max < 1 || !prefs.hex_away_track)
 		do_away = FALSE;
 
 	nick = newuser->nick;
-	if (prefs.gui_tweaks & 64)
+	if (!prefs.hex_gui_ulist_icons)
 	{
 		nick = malloc (strlen (newuser->nick) + 2);
 		nick[0] = newuser->prefix[0];
@@ -377,8 +379,10 @@ fe_userlist_insert (session *sess, struct User *newuser, int row, int sel)
 										:	(NULL),
 								  -1);
 
-	if (prefs.gui_tweaks & 64)
+	if (!prefs.hex_gui_ulist_icons)
+	{
 		free (nick);
+	}
 
 	/* is it me? */
 	if (newuser->me && sess->gui->nick_box)
@@ -479,7 +483,7 @@ userlist_add_columns (GtkTreeView * treeview)
 
 	/* icon column */
 	renderer = gtk_cell_renderer_pixbuf_new ();
-	if (prefs.gui_tweaks & 32)
+	if (prefs.hex_gui_compact)
 		g_object_set (G_OBJECT (renderer), "ypad", 0, NULL);
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
 																-1, NULL, renderer,
@@ -487,18 +491,18 @@ userlist_add_columns (GtkTreeView * treeview)
 
 	/* nick column */
 	renderer = gtk_cell_renderer_text_new ();
-	if (prefs.gui_tweaks & 32)
+	if (prefs.hex_gui_compact)
 		g_object_set (G_OBJECT (renderer), "ypad", 0, NULL);
 	gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT (renderer), 1);
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
 																-1, NULL, renderer,
 													"text", 1, "foreground-gdk", 4, NULL);
 
-	if (prefs.showhostname_in_userlist)
+	if (prefs.hex_gui_ulist_show_hosts)
 	{
 		/* hostname column */
 		renderer = gtk_cell_renderer_text_new ();
-		if (prefs.gui_tweaks & 32)
+		if (prefs.hex_gui_compact)
 			g_object_set (G_OBJECT (renderer), "ypad", 0, NULL);
 		gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT (renderer), 1);
 		gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
@@ -518,13 +522,13 @@ userlist_click_cb (GtkWidget *widget, GdkEventButton *event, gpointer userdata)
 	if (!event)
 		return FALSE;
 
-	if (!(event->state & GDK_CONTROL_MASK) &&
-		event->type == GDK_2BUTTON_PRESS && prefs.doubleclickuser[0])
+	if (!(event->state & STATE_CTRL) &&
+		event->type == GDK_2BUTTON_PRESS && prefs.hex_gui_ulist_doubleclick[0])
 	{
 		nicks = userlist_selection_list (widget, &i);
 		if (nicks)
 		{
-			nick_command_parse (current_sess, prefs.doubleclickuser, nicks[0],
+			nick_command_parse (current_sess, prefs.hex_gui_ulist_doubleclick, nicks[0],
 									  nicks[0]);
 			while (i)
 			{
@@ -609,18 +613,18 @@ userlist_create (GtkWidget *box)
 	static const GtkTargetEntry dnd_dest_targets[] =
 	{
 		{"text/uri-list", 0, 1},
-		{"XCHAT_CHANVIEW", GTK_TARGET_SAME_APP, 75 }
+		{"HEXCHAT_CHANVIEW", GTK_TARGET_SAME_APP, 75 }
 	};
 	static const GtkTargetEntry dnd_src_target[] =
 	{
-		{"XCHAT_USERLIST", GTK_TARGET_SAME_APP, 75 }
+		{"HEXCHAT_USERLIST", GTK_TARGET_SAME_APP, 75 }
 	};
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
 													 GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-											  prefs.showhostname_in_userlist ?
+											  prefs.hex_gui_ulist_show_hosts ?
 												GTK_POLICY_AUTOMATIC :
 												GTK_POLICY_NEVER,
 											  GTK_POLICY_AUTOMATIC);
@@ -628,7 +632,7 @@ userlist_create (GtkWidget *box)
 	gtk_widget_show (sw);
 
 	treeview = gtk_tree_view_new ();
-	gtk_widget_set_name (treeview, "xchat-userlist");
+	gtk_widget_set_name (treeview, "hexchat-userlist");
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection
 										  (GTK_TREE_VIEW (treeview)),
